capture log close
log using apptabA2.smcl, replace

/* Appendix table A2:  Summary statistics for individual-level variables */

#delimit;
version 8.0;
pause off;
set more off;
query;
creturn list;
clear;
set mem 64m;
set matsize 800;

do "../../definedirs.do";
quietly do "../moultonprog.do";


*Start with CD data;
* xindivid is the vector of control variables at the individual student level;
 global  cd_ind "lnfaminc female asian black hispanic parscol parcolg";
* xdistrict is the vector of control variables at the district level;
 global cd_dist "lnincmea incgini pctasian pctblack pcthisp herfrace herfethn pctscol pctcolg herfed";
* xmetro is the vector of control variables at the MSA/PMSA level;
 global cd_msa "mpop marea mlnincme mincgini mpctasia mpctblac mpcthisp mherfrac mherfeth mpctscol mpctcolg mherfed";
* xdivision is a vector of division dummies, which we create in this do-file;
 global cd_div "ddiv1 ddiv2 ddiv3 ddiv4 ddiv5 ddiv6 ddiv7 ddiv8 ddiv9";

use ${hoxbydat_confidential}/achievement.regressions.dta;
gen inmsa8=(fipsmsa>0 & fipsmsa<.) if by2xrstd~=.;
gen inmsa12=(fipsmsa>0 & fipsmsa<.) if f22xrstd~=.;
gen sampg12=1;
gen sampg8=1;
foreach v of varlist $cd_ind $cd_dist $cd_msa $cd_div mchoienr mnumrivr mnumstre {;
  replace sampg12=0 if `v'==.;
  replace sampg8=0 if `v'==.;
  };
replace sampg12=0 if pubschf2~=1;
replace sampg12=0 if f2wght==.;
replace sampg12=0 if f22xrstd==.;
replace sampg8=0 if pubschby~=1;
replace sampg8=0 if bywght==.;
replace sampg8=0 if by2xrstd==.;

foreach v of varlist pubschby pubschf2 lnfaminc female asian black hispanic parscol parcolg
                     by2xrstd f22xrstd inmsa8 inmsa12 sampg12 sampg8 fipsmsa leaid bywght f2wght {;
 rename `v' cd_`v';
 };
keep id cd_*;
sort id;
tempfile cddata;
save `cddata';

*Now switch to my replication sample;
use ${mywork_confidential}/nelsdata.dta;
foreach v of varlist pubschby pubschf2 by2xrstd f22xrstd {;
 rename `v' ch_`v';
 gen jr_`v'=ch_`v';
};
keep id ch_pubschby ch_pubschf2 ch_by2xrstd ch_f22xrstd
        jr_pubschby jr_pubschf2 jr_by2xrstd jr_f22xrstd
     ch_lnfaminc ch_female ch_asian ch_black ch_hispanic ch_parscol ch_parcolg
     jr_lnfaminc jr_female jr_asian jr_black jr_hispanic jr_parscol jr_parcolg
     ch_leaid ch_fipsmsa jrAby_leaid jrAf2_leaid jrAby_fipsmsa jrAf2_fipsmsa
     ;
gen ch_inmsa8=(ch_fipsmsa>0 & ch_fipsmsa<.) if ch_by2xrstd<.;
gen ch_inmsa12=(ch_fipsmsa>0 & ch_fipsmsa<.) if ch_f22xrstd<.;
gen jr_inmsa8=(jrAby_fipsmsa>0 & jrAby_fipsmsa<.) if jr_by2xrstd<.;
gen jr_inmsa12=(jrAf2_fipsmsa>0 & jrAf2_fipsmsa<.) if jr_f22xrstd<.;
sort id;
tempfile repdata;
save `repdata';

*And grab sample identifiers;
 global ch_ind "ch_lnfaminc ch_asian ch_hispanic ch_black ch_female ch_parcolg ch_parscol";
 global ch_ma "m_pop_n m_arealand ch_m_avglnmeaninc ch_m_gini ch_m_pop_fas ch_m_pop_fbl ch_m_pop_fhi ch_m_herfrace ch_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global ch_dist "d_lnmeanincA ch_d_gini ch_d_pop_fas ch_d_pop_fbl ch_d_pop_fhi ch_d_herfrace ch_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global ch_div "ch_d_div1 ch_d_div2 ch_d_div3 ch_d_div4 ch_d_div5 ch_d_div6 ch_d_div7 ch_d_div8";
use ${mywork_confidential}/chsample;
 mark ch_cntrls;
 markout ch_cntrls
         $ch_ind $ch_ma $ch_dist $ch_div ch_choice;
 gen samp_8r=1   if byqwt>0 & ch_cntrls==1 & pubschby==1 & by2xrstd<. & ch_nstreams_lg<. & ch_nstreams_sm<.;
 gen samp_12r=1  if f2qwt>0 & ch_cntrls==1 & pubschf2==1 & f22xrstd<. & ch_nstreams_lg<. & ch_nstreams_sm<.;
 egen totwgt_8r  =sum(byqwt) if samp_8r  ==1, by(fipsmsa);
 egen totwgt_12r =sum(f2qwt) if samp_12r ==1, by(fipsmsa);
 gen wgt_8r  =byqwt/totwgt_8r   if samp_8r  ==1;
 gen wgt_12r =f2qwt/totwgt_12r  if samp_12r ==1;
keep id samp_8r samp_12r wgt_8r wgt_12r;
rename samp_8r ch_sampg8;
rename samp_12r ch_sampg12;
rename wgt_8r ch_wgtg8;
rename wgt_12r ch_wgtg12;
sort id;
tempfile chsamp;
save `chsamp';

 use ${mywork_confidential}/jrAbysample.dta, clear;
 global jr_ind "jr_lnfaminc jr_asian jr_hispanic jr_black jr_female jr_parcolg jr_parscol";
 global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
 mark jr_cntrls;
 markout jr_cntrls
         $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
 gen samp_8r=1   if byqwt>0 & jr_cntrls==1 & pubschby==1 & by2xrstd<. & ch_nstreams_lg<. & ch_nstreams_sm<.;
 egen totwgt_8r  =sum(byqwt) if samp_8r  ==1, by(fipsmsa);
 gen wgt_8r  =byqwt/totwgt_8r   if samp_8r  ==1;
 keep id samp_8r wgt_8r;
 rename samp_8r jr_sampg8;
 rename wgt_8r jr_wgtg8;
 sort id;
 tempfile jrsamp8;
 save `jrsamp8';

 use ${mywork_confidential}/jrAf2sample.dta, clear;
 global jr_ind "jr_lnfaminc jr_asian jr_hispanic jr_black jr_female jr_parcolg jr_parscol";
 global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
 mark jr_cntrls;
 markout jr_cntrls
         $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
 gen samp_12r=1   if f2qwt>0 & jr_cntrls==1 & pubschf2==1 & f22xrstd<. & ch_nstreams_lg<. & ch_nstreams_sm<.;
 egen totwgt_12r  =sum(f2qwt) if samp_12r  ==1, by(fipsmsa);
 gen wgt_12r  =f2qwt/totwgt_12r   if samp_12r  ==1;
 keep id samp_12r wgt_12r;
 rename samp_12r jr_sampg12;
 rename wgt_12r jr_wgtg12;
 sort id;
 tempfile jrsamp12;
 save `jrsamp12';

*Bring everything together;
 use `repdata';
 sort id;
 merge id using `cddata', unique _merge(mrg1);
 sort id;
 merge id using `chsamp', unique _merge(mrg2);
 sort id;
 merge id using `jrsamp8', unique _merge(mrg3);
 sort id;
 merge id using `jrsamp12', unique _merge(mrg4);
su mrg*;

rename cd_bywght cd_wgtg8;
rename cd_f2wght cd_wgtg12;
*Concordance of district, MSA assignments;
foreach v of varlist cd_leaid ch_leaid jrAby_leaid jrAf2_leaid cd_fipsmsa ch_fipsmsa jrAby_fipsmsa jrAf2_fipsmsa {;
 replace `v'=. if `v'==0;
};
gen cdch_samelea8=(cd_leaid==ch_leaid);
gen cdjr_samelea8=(cd_leaid==jrAby_leaid);
gen chjr_samelea8=(ch_leaid==jrAby_leaid);
gen cdch_samelea12=(cd_leaid==ch_leaid);
gen cdjr_samelea12=(cd_leaid==jrAf2_leaid);
gen chjr_samelea12=(ch_leaid==jrAf2_leaid);
gen cdch_samemsa8=(cd_fipsmsa==ch_fipsmsa);
gen cdjr_samemsa8=(cd_fipsmsa==jrAby_fipsmsa);
gen chjr_samemsa8=(ch_fipsmsa==jrAby_fipsmsa);
gen cdch_samemsa12=(cd_fipsmsa==ch_fipsmsa);
gen cdjr_samemsa12=(cd_fipsmsa==jrAf2_fipsmsa);
gen chjr_samemsa12=(ch_fipsmsa==jrAf2_fipsmsa);
   su cd_pubschby cd_pubschf2 cd_lnfaminc cd_female cd_asian cd_black cd_hispanic cd_parscol cd_parcolg cd_by2xrstd
   cd_f22xrstd cd_wgtg8 cd_wgtg12
   ch_pubschby ch_pubschf2 ch_lnfaminc ch_female ch_asian ch_black ch_hispanic ch_parscol ch_parcolg ch_by2xrstd
   ch_f22xrstd ch_wgtg8 ch_wgtg12
   jr_pubschby jr_pubschf2 jr_lnfaminc jr_female jr_asian jr_black jr_hispanic jr_parscol jr_parcolg jr_by2xrstd
   jr_f22xrstd jr_wgtg8 jr_wgtg12
   cd_inmsa8 cd_inmsa12 ch_inmsa8 ch_inmsa12 jr_inmsa8 jr_inmsa12
   cdch_samelea8  cdjr_samelea8  chjr_samelea8
   cdch_samelea12 cdjr_samelea12 chjr_samelea12
   cdch_samemsa8  cdjr_samemsa8  chjr_samemsa8
   cdch_samemsa12 cdjr_samemsa12 chjr_samemsa12
   , separator(0);
foreach v in pubschby pubschf2 lnfaminc female asian black hispanic parscol parcolg by2xrstd f22xrstd
             wgtg8 wgtg12 {;
 quietly corr cd_`v' ch_`v';
 local rho1=r(rho);
 quietly corr cd_`v' jr_`v';
 local rho2=r(rho);
 quietly corr ch_`v' jr_`v';
 local rho3=r(rho);
 matrix onerow=`rho1', `rho2', `rho3';
 matrix rownames onerow=`v';
 matrix colnames onerow=CD_CH CD_JR CH_JR;
 if "`v'"=="pubschby" {;
  matrix allcorrs=onerow;
  };
 else {;
  matrix allcorrs=allcorrs \ onerow;
  };
 };
matrix list allcorrs;

*Sample sizes;
count if cd_sampg8==1;
count if cd_sampg12==1;
count if ch_sampg8==1;
count if ch_sampg12==1;
count if jr_sampg8==1;
count if jr_sampg12==1;

log close;