capture log close
log using apptabA3.smcl, replace

/* Appendix table A3: summary stats for district-level variables */

#delimit;
version 8.0;
pause off;
set more off;
query;
creturn list;
clear;
set mem 64m;
set matsize 800;

do "../../definedirs.do";

use ${hoxbydat_confidential}/district.regressions.dta;
keep leaid lnincmea incgini pctasian pctblack pcthisp herfrace herfethn pctscol pctcolg herfed fipsmsa;
gen inmsa=(fipsmsa>0 & fipsmsa<.);
foreach v of varlist _all {;
 rename `v' cd_`v';
 };
rename cd_leaid leaid;
sort leaid;
tempfile cddata;
save `cddata';

use ${mywork_public}/distdata.dta;
global ch_dist "d_lnmeanincA ch_d_gini ch_d_pop_fas ch_d_pop_fbl ch_d_pop_fhi ch_d_herfrace ch_d_herfethn d_ed_scol d_ed_ba d_herfed";
global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
keep leaid $ch_dist $jr_dist fipsmsa *d_lnmeaninc*;
gen jr_inmsa=(fipsmsa>0 & fipsmsa<.);
sort leaid;
merge leaid using `cddata', unique;

replace cd_fipsmsa=. if cd_fipsmsa==0;
replace fipsmsa=. if fipsmsa==0;
gen samemsa=(cd_fipsmsa==fipsmsa);
su cd_pctasian cd_pcthisp cd_pctblack cd_herfrace cd_pctscol cd_pctcolg cd_herfed cd_lnincmea cd_incgini cd_herfethn cd_inmsa
   ch_d_pop_fas ch_d_pop_fhi ch_d_pop_fbl ch_d_herfrace d_ed_scol d_ed_ba d_herfed d_lnmeanincA ch_d_gini ch_d_herfethn jr_inmsa samemsa
   jr_d_pop_fas jr_d_pop_fhi jr_d_pop_fbl jr_d_herfrace jr_d_gini jr_d_herfethn
   , separator(0);

*Again using only the successful merges;
su cd_pctasian cd_pcthisp cd_pctblack cd_herfrace cd_pctscol cd_pctcolg cd_herfed cd_lnincmea cd_incgini cd_herfethn cd_inmsa
   ch_d_pop_fas ch_d_pop_fhi ch_d_pop_fbl ch_d_herfrace d_ed_scol d_ed_ba d_herfed d_lnmeanincA ch_d_gini ch_d_herfethn jr_inmsa samemsa
   jr_d_pop_fas jr_d_pop_fhi jr_d_pop_fbl jr_d_herfrace jr_d_gini jr_d_herfethn
   if _merge==3, separator(0);

global cdvars1 "cd_pctasian cd_pcthisp cd_pctblack cd_herfrace cd_pctscol cd_pctcolg";
global cdvars2 "cd_herfed cd_lnincmea cd_incgini cd_herfethn cd_inmsa";
global chvars1 "ch_d_pop_fas ch_d_pop_fhi ch_d_pop_fbl ch_d_herfrace d_ed_scol d_ed_ba";
global chvars2 "d_herfed d_lnmeanincA ch_d_gini ch_d_herfethn jr_inmsa";
global jrvars1 "jr_d_pop_fas jr_d_pop_fhi jr_d_pop_fbl jr_d_herfrace d_ed_scol d_ed_ba";
global jrvars2 "d_herfed d_lnmeanincA jr_d_gini jr_d_herfethn jr_inmsa";
local n=wordcount("$cdvars1") + wordcount("$cdvars2");
forvalues i=1/`n' {;
 if `i'<=6 {;
  local cdv=word("$cdvars1", `i');
  local chv=word("$chvars1", `i');
  local jrv=word("$jrvars1", `i');
  };
 else {;
  local cdv=word("$cdvars2", `i'-6);
  local chv=word("$chvars2", `i'-6);
  local jrv=word("$jrvars2", `i'-6);
  };
 di "`cdv' `chv' `jrv'";
 quietly corr `cdv' `chv';
 local rho1=r(rho);
 quietly corr `cdv' `jrv';
 local rho2=r(rho);
 quietly corr `chv' `jrv';
 local rho3=r(rho);
 matrix onerow=`rho1', `rho2', `rho3';
 matrix rownames onerow=`jrv';
 matrix colnames onerow=CD_CH CD_JR CH_JR;
 if `i'==1 {;
  matrix allcorrs=onerow;
  };
 else {;
  matrix allcorrs=allcorrs \ onerow;
  };
 };
matrix list allcorrs;

log close;
