capture log close
log using apptabA4.smcl, replace

/* Appendix table A4: summary stats for MSA-level variables 
   (also A5:  Streams summary stats)
   */

#delimit;
version 8.0;
pause off;
set more off;
query;
creturn list;
clear;
set mem 64m;
set matsize 800;

do "../../definedirs.do";
quietly do "../moultonprog.do";


use ${hoxbydat_confidential}/firststage.regression.dta;
foreach v of varlist _all {;
 rename `v' cd_`v';
 };
rename cd_fipsmsa fipsmsa;
sort fipsmsa;
tempfile cddata;
save `cddata';

use ${mywork_public}/msadata;
sort fipsmsa;
merge fipsmsa using `cddata';
gen lpop=ln(m_pop_n);
gen larea=ln(m_arealand);
gen cd_lnmpop=ln(cd_mpop);
gen cd_lnmarea=ln(cd_marea);
gen cd_mnumstre_tot=cd_mnumrivr+cd_mnumstre;
su cd_mchoienr cd_mnumrivr cd_mnumstre cd_mnumstre_tot cd_mpop cd_lnmpop cd_marea cd_lnmarea
               cd_mpctasia cd_mpcthisp cd_mpctblac cd_mherfrac
               cd_mpctscol cd_mpctcolg cd_mherfed cd_mlnincme cd_mincgini cd_mherfeth
   ch_choice ch_nstreams_lg ch_nstreams_sm ch_nstreams_tot m_pop_n lpop m_arealand larea
              ch_m_pop_fas ch_m_pop_fhi ch_m_pop_fbl ch_m_herfrace
               m_ed_scol m_ed_ba m_herfed ch_m_avglnmeaninc ch_m_gini ch_m_herfethn
   jr_choice  jr_m_pop_fas jr_m_pop_fhi jr_m_pop_fbl jr_m_herfrace
              m_lnmeanincA jr_m_gini  jr_m_herfethn
   , separator(0);

global cdvars1 "cd_mchoienr cd_mnumrivr cd_mnumstre cd_mnumstre_tot cd_mpop cd_lnmpop";
global cdvars2 "cd_marea cd_lnmarea cd_mpctasia cd_mpcthisp cd_mpctblac cd_mherfrac";
global cdvars3 "cd_mpctscol cd_mpctcolg cd_mherfed cd_mlnincme cd_mincgini cd_mherfeth";
global chvars1 "ch_choice ch_nstreams_lg ch_nstreams_sm ch_nstreams_tot m_pop_n lpop";
global chvars2 "m_arealand larea ch_m_pop_fas ch_m_pop_fhi ch_m_pop_fbl ch_m_herfrace";
global chvars3 "m_ed_scol m_ed_ba m_herfed ch_m_avglnmeaninc ch_m_gini ch_m_herfethn";
global jrvars1 "jr_choice ch_nstreams_lg ch_nstreams_sm ch_nstreams_tot m_pop_n lpop";
global jrvars2 "m_arealand larea jr_m_pop_fas jr_m_pop_fhi jr_m_pop_fbl jr_m_herfrace";
global jrvars3 "m_ed_scol m_ed_ba m_herfed m_lnmeanincA jr_m_gini jr_m_herfethn";

local n=wordcount("$cdvars1") + wordcount("$cdvars2") + wordcount("$cdvars3");
forvalues i=1/`n' {;
 if `i'<=wordcount("$cdvars1") {;
  local cdv=word("$cdvars1", `i');
  local chv=word("$chvars1", `i');
  local jrv=word("$jrvars1", `i');
  };
 else {;
  if `i'<=wordcount("$cdvars1") + wordcount("$cdvars2") {;
   local cdv=word("$cdvars2", `i'-wordcount("$cdvars1"));
   local chv=word("$chvars2", `i'-wordcount("$cdvars1"));
   local jrv=word("$jrvars2", `i'-wordcount("$cdvars1"));
   };
  else {;
   local cdv=word("$cdvars3", `i'-wordcount("$cdvars1")-wordcount("$cdvars2"));
   local chv=word("$chvars3", `i'-wordcount("$cdvars1")-wordcount("$cdvars2"));
   local jrv=word("$jrvars3", `i'-wordcount("$cdvars1")-wordcount("$cdvars2"));
   };
  };
 di "`cdv' `chv' `jrv'";
 quietly corr `cdv' `chv';
 local rho1=r(rho);
 quietly corr `cdv' `jrv';
 local rho2=r(rho);
 quietly corr `chv' `jrv';
 local rho3=r(rho);
 matrix onerow=`rho1', `rho2', `rho3';
 matrix rownames onerow=`jrv';
 matrix colnames onerow=CD_CH CD_JR CH_JR;
 if `i'==1 {;
  matrix allcorrs=onerow;
  };
 else {;
  matrix allcorrs=allcorrs \ onerow;
  };
 };
matrix list allcorrs;

tab _merge;

*Streams variables;
 *Larger streams;
  su cd_mnumrivr jr_nstreamsB_inter jr_nstreamsB_long;
 *Total streams;
  su cd_mnumstre_tot ch_nstreams_tot jr_nstreamsB_tot;
 *Smaller streams;
  gen jr_nstreamsA_sm=jr_nstreamsA_tot-ch_nstreams_lg;
  gen jr_nstreamsB_sm=jr_nstreamsB_tot-ch_nstreams_lg;
  su cd_mnumstre ch_nstreams_sm jr_nstreamsB_sm jr_nstreamsB_intra jr_nstreamsB_short;

 *Larger streams;
  pwcorr cd_mnumrivr jr_nstreamsB_inter jr_nstreamsB_long, obs;
 *Total streams;
  pwcorr cd_mnumstre_tot ch_nstreams_tot jr_nstreamsB_tot, obs;
 *Smaller streams;
  pwcorr cd_mnumstre ch_nstreams_sm jr_nstreamsB_sm jr_nstreamsB_intra jr_nstreamsB_short, obs;

log close;
