capture log close
log using apptabD4.smcl, replace

*Program to estimate models on all 6 NELS test scores;

#delimit;
version 8.0;
pause off;
set more off;
query;
creturn list;
clear;
set mem 64m;
set matsize 800;

do "../../definedirs.do";
quietly do "../moultonprog.do";

capture program drop onereg;
program define onereg, eclass;
 syntax varlist [if] [in] [using] [fw pw aw],
                depvar(varname numeric) endog(varname numeric) instrum(varlist numeric)
                [cluster(varname) moulton(varlist min=1 max=2) outreg *];
 *Program to run a single IV regression and compute exogeneity tests,
 *with classical, clustered, or Moulton SEs;

 *Start by computing the sample;
  marksample samp;
  markout `samp' `depvar' `endog' `instrum';
 *Estimate first stage;
  quietly reg `endog' `instrum' `varlist' if `samp' [`weight'`exp'];
  tempvar xhat;
  predict `xhat', xb;

 tempname mainmod;
 *Begin with classical case;
  if "`cluster'"=="" & "`moulton'"=="" {;
   *Run exog test;
    quietly reg `depvar' `endog' `varlist' `xhat' if `samp' [`weight'`exp'];
    quietly test `xhat';
    local p_exog=r(p);
   *Run overid test;
    ivreg `depvar' `varlist' (`endog'=`instrum') if `samp' [`weight'`exp'];
    tempvar ivresid;
    predict `ivresid', residuals;
    _estimates hold `mainmod';
    if wordcount("`instrum'")>1 {;
     quietly reg `ivresid' `varlist' `instrum' if `samp' [`weight'`exp'];
     local p_overid=chi2(wordcount("`instrum'")-1, e(N)*e(r2));
     };
    else {;
     local p_overid=-1;
     };
   _estimates unhold `mainmod';
   if "`outreg'"=="outreg" {;
    outreg `using', `options' bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Exog. p", `p_exog', "Overid p", `p_overid', "Error type", 0);
    };
   };
 *Now clustered;
  if "`cluster'"~="" {;
   *Run exog test;
    quietly reg `depvar' `endog' `varlist' `xhat' if `samp' [`weight'`exp'], cluster(`cluster');
    quietly test `xhat';
    local p_exog=r(p);
   *Run IV;
    local p_overid=-1;
    ivreg `depvar' `varlist' (`endog'=`instrum') if `samp' [`weight'`exp'], cluster(`cluster');
    local nclust=e(df_r)+1;
   if "`outreg'"=="outreg" {;
    outreg `using', `options' bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Exog. p", `p_exog', "Overid p", `p_overid', "Error type", 1,
                             "#cluster", `nclust');
    };
   };
 *And finally Moulton;
  if "`moulton'"~="" {;
   *Run exog test;
    quietly olserrcomp `depvar' `endog' `varlist' `xhat' if `samp' [`weight'`exp'], groups(`moulton');
    quietly test `xhat';
    local p_exog=r(p);
   *Run IV;
    local p_overid=-1;
    iverrcomp `depvar' `varlist' (`endog'=`instrum') if `samp' [`weight'`exp'], groups(`moulton');
    local ngroups=e(N_g2);
    local nsubgroups=e(N_g1);
    local sd_ind=e(sigma_0);
    local sd_gp=e(sigma_2);
    local sd_subgp=e(sigma_1);
   if "`outreg'"=="outreg" {;
    outreg `using', `options' bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Exog. p", `p_exog', "Overid p", `p_overid', "Error type", 2,
                             "#Groups", `ngroups', "#Subgroups", `nsubgroups',
                             "SDind", `sd_ind', "SDsubgp", `sd_subgp', "SDgroup", `sd_gp');
    };
   };
end;

local iv1 "ch_nstreams_lg ch_nstreams_sm";
local iv2 "jr_nstreamsB_inter jr_nstreamsB_intra";

*CD sample;
 use ${hoxbydat_confidential}/achievement.regressions.dta;
 replace mpop=mpop/10000000;
 replace marea=marea/100000;
 global cd_ind "lnfaminc asian hispanic black female parcolg parscol";
 global cd_ma "mpop marea mlnincme mincgini mpctasia mpctblac mpcthisp mherfrac mherfeth mpctscol mpctcolg mherfed";
 global cd_dist "lnincmea incgini pctasia pctblac pcthisp herfrac herfeth pctscol pctcolg herfed";
 global cd_div "ddiv1 ddiv2 ddiv3 ddiv4 ddiv5 ddiv6 ddiv7 ddiv8";
 foreach w in by f1 f2 {;
  foreach subj in r m {;
   reg `w'2x`subj'std mchoienr $cd_ind $cd_ma $cd_dist $cd_div [aw=`w'wght] if pubsch`w'==1, cluster(fipsmsa);
   if "`w'"=="by" & "`subj'"=="r" {;
    outreg using apptabD4.txt, replace bdec(8) rdec(8) se noparen noaster nolabel ctitle("CD_`w'`subj'_OLS");
    };
   else {;
    outreg using apptabD4.txt, append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CD_`w'`subj'_OLS");
   };
   onereg $cd_ind $cd_ma $cd_dist $cd_div [aw=`w'wght] if pubsch`w'==1 using apptabD4.txt,
          depvar(`w'2x`subj'std) endog(mchoienr) instrum(mnumrivr mnumstre) cluster(fipsmsa)
          outreg ctitle("CD_`w'`subj'_IV1") append;
  };
 };

*CH sample.  Restandardize weights separately for each model;
 use ${mywork_confidential}/chsample.dta, clear;
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 global ch_ind "ch_lnfaminc ch_asian ch_hispanic ch_black ch_female ch_parcolg ch_parscol";
 global ch_ma "m_pop_n m_arealand ch_m_avglnmeaninc ch_m_gini ch_m_pop_fas ch_m_pop_fbl ch_m_pop_fhi ch_m_herfrace ch_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global ch_dist "d_lnmeanincA ch_d_gini ch_d_pop_fas ch_d_pop_fbl ch_d_pop_fhi ch_d_herfrace ch_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global ch_div "ch_d_div1 ch_d_div2 ch_d_div3 ch_d_div4 ch_d_div5 ch_d_div6 ch_d_div7 ch_d_div8";
 mark ch_cntrls;
 markout ch_cntrls
         $ch_ind $ch_ma $ch_dist $ch_div ch_choice;
 gen ivsamp1=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
 gen ivsamp2=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
 foreach w in by f1 f2 {;
  foreach subj in r m {;
   gen samp_`w'`subj'_ols=1 if `w'qwt>0 & ch_cntrls==1 & pubsch`w'==1 & `w'2x`subj'std<.;
   egen totwgt_`w'`subj'_ols=sum(`w'qwt) if samp_`w'`subj'_ols==1, by(fipsmsa);
   gen wgt_`w'`subj'_ols=`w'qwt/totwgt_`w'`subj'_ols if samp_`w'`subj'_ols==1;
   reg `w'2x`subj'std ch_choice $ch_ind $ch_ma $ch_dist $ch_div [aw=wgt_`w'`subj'_ols], cluster(fipsmsa);
   outreg using apptabD4.txt, append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_`w'`subj'_OLS");
   foreach iv in 1 2 {;
    gen samp_`w'`subj'_iv`iv'=1 if samp_`w'`subj'_ols==1 & ivsamp`iv'==1;
    egen totwgt_`w'`subj'_iv`iv'=sum(`w'qwt) if samp_`w'`subj'_iv`iv'==1, by(fipsmsa);
    gen wgt_`w'`subj'_iv`iv'=`w'qwt/totwgt_`w'`subj'_iv`iv' if samp_`w'`subj'_iv`iv'==1;
    onereg $ch_ind $ch_ma $ch_dist $ch_div [aw=wgt_`w'`subj'_iv`iv'] using apptabD4.txt,
          depvar(`w'2x`subj'std) endog(ch_choice) instrum(`iv`iv'') cluster(fipsmsa) outreg
          ctitle("CH_`w'`subj'_IV`iv'") append;
   };
  };
 };

*JR sample.  Restandardize weights separately for each model;
 use ${mywork_confidential}/jrAbysample.dta, clear;
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 global jr_ind "jr_lnfaminc jr_asian jr_hispanic jr_black jr_female jr_parcolg jr_parscol";
 global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
 mark jr_cntrls;
 markout jr_cntrls
         $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
 gen ivsamp1=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
 gen ivsamp2=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
 tempfile jrby;
 save `jrby';
 use ${mywork_confidential}/jrAf1sample.dta, clear;
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 mark jr_cntrls;
 markout jr_cntrls
         $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
 gen ivsamp1=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
 gen ivsamp2=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
 tempfile jrf1;
 save `jrf1';
 use ${mywork_confidential}/jrAf2sample.dta, clear;
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 mark jr_cntrls;
 markout jr_cntrls
         $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
 gen ivsamp1=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
 gen ivsamp2=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
 tempfile jrf2;
 save `jrf2';

 foreach w in by f1 f2 {;
  use `jr`w'', clear;
  foreach subj in r m {;
   gen samp_`w'`subj'_ols=1 if `w'qwt>0 & jr_cntrls==1 & pubsch`w'==1 & `w'2x`subj'std<.;
   egen totwgt_`w'`subj'_ols=sum(`w'qwt) if samp_`w'`subj'_ols==1, by(fipsmsa);
   gen wgt_`w'`subj'_ols=`w'qwt/totwgt_`w'`subj'_ols if samp_`w'`subj'_ols==1;
   reg `w'2x`subj'std jr_choice $jr_ind $jr_ma $jr_dist $jr_div [aw=wgt_`w'`subj'_ols], cluster(fipsmsa);
   outreg using apptabD4.txt, append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_`w'`subj'_OLS");
   foreach iv in 1 2 {;
    gen samp_`w'`subj'_iv`iv'=1 if samp_`w'`subj'_ols==1 & ivsamp`iv'==1;
    egen totwgt_`w'`subj'_iv`iv'=sum(`w'qwt) if samp_`w'`subj'_iv`iv'==1, by(fipsmsa);
    gen wgt_`w'`subj'_iv`iv'=`w'qwt/totwgt_`w'`subj'_iv`iv' if samp_`w'`subj'_iv`iv'==1;
    onereg $jr_ind $jr_ma $jr_dist $jr_div [aw=wgt_`w'`subj'_iv`iv'] using apptabD4.txt,
          depvar(`w'2x`subj'std) endog(jr_choice) instrum(`iv`iv'') cluster(fipsmsa) outreg
          ctitle("JR_`w'`subj'_IV`iv'") append;
   };
  };
 };

log close;
