capture log close
log using apptabD7.smcl, replace

/* Program to estimate reduced form models in 3 samples for alternative instruments */

#delimit;
version 8.0;
pause off;
set more off;
query;
creturn list;
clear;
set mem 64m;
set matsize 800;

do "../../definedirs.do";
quietly do "../moultonprog.do";

*Start with CD data;
 use ${hoxbydat_confidential}/achievement.regressions.dta, clear;
 replace mpop=mpop/10000000;
 replace marea=marea/100000;
 gen mnumstre_tot=mnumrivr+mnumstre;
 global cd_ind "lnfaminc asian hispanic black female parcolg parscol";
 global cd_ma "mpop marea mlnincme mincgini mpctasia mpctblac mpcthisp mherfrac mherfeth mpctscol mpctcolg mherfed";
 global cd_dist "lnincmea incgini pctasia pctblac pcthisp herfrac herfeth pctscol pctcolg herfed";
 global cd_div "ddiv1 ddiv2 ddiv3 ddiv4 ddiv5 ddiv6 ddiv7 ddiv8";

 *8th grade reading scores;
  reg by2xrstd mnumrivr mnumstre $cd_ind $cd_ma $cd_dist $cd_div if pubschby==1 [aw=bywght], cluster(fipsmsa);
  outreg using apptabD7.txt, replace bdec(8) rdec(8) se noparen noaster nolabel ctitle("CD_8r_ivA");
  reg by2xrstd mnumstre_tot $cd_ind $cd_ma $cd_dist $cd_div if pubschby==1 [aw=bywght], cluster(fipsmsa);
  outreg using apptabD7.txt, append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CD_8r_ivB");
 *12th grade reading scores;
  reg f22xrstd mnumrivr mnumstre $cd_ind $cd_ma $cd_dist $cd_div if pubschf2==1 [aw=f2wght], cluster(fipsmsa);
  outreg using apptabD7.txt, append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CD_12r_ivA");
  reg f22xrstd mnumstre_tot $cd_ind $cd_ma $cd_dist $cd_div if pubschf2==1 [aw=f2wght], cluster(fipsmsa);
  outreg using apptabD7.txt, append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CD_12r_ivB");

*Now switch to my data: CH sample.  Restandardize weights separately for each model;
 use ${mywork_confidential}/chsample.dta, clear;
 global ch_ind "ch_lnfaminc ch_asian ch_hispanic ch_black ch_female ch_parcolg ch_parscol";
 global ch_ma "m_pop_n m_arealand ch_m_avglnmeaninc ch_m_gini ch_m_pop_fas ch_m_pop_fbl ch_m_pop_fhi ch_m_herfrace ch_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global ch_dist "d_lnmeanincA ch_d_gini ch_d_pop_fas ch_d_pop_fbl ch_d_pop_fhi ch_d_herfrace ch_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global ch_div "ch_d_div1 ch_d_div2 ch_d_div3 ch_d_div4 ch_d_div5 ch_d_div6 ch_d_div7 ch_d_div8";
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 mark ch_cntrls;
 markout ch_cntrls
         $ch_ind $ch_ma $ch_dist $ch_div ch_choice;
 gen samp_8r=1   if byqwt>0 & ch_cntrls==1 & pubschby==1 & by2xrstd<. ;
 gen samp_12r=1  if f2qwt>0 & ch_cntrls==1 & pubschf2==1 & f22xrstd<. ;
 local ivA "ch_nstreams_lg ch_nstreams_sm";
 local ivB "ch_nstreams_tot";
 local ivC "ch_nstreams_lg jr_nstreamsB_sm";
 local ivD "jr_nstreamsB_tot";
 local ivE "jr_nstreamsB_inter jr_nstreamsB_intra";
 local ivF "jr_nstreamsB_long jr_nstreamsB_short";
 gen jr_nstreamsB_sm=jr_nstreamsB_tot-ch_nstreams_lg;
 gen ivsampA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
 gen ivsampB=1 if ch_nstreams_tot<. ;
 gen ivsampC=1 if ch_nstreams_lg<. & jr_nstreamsB_sm<.;
 gen ivsampD=1 if jr_nstreamsB_tot<.;
 gen ivsampE=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
 gen ivsampF=1 if jr_nstreamsB_long<. & jr_nstreamsB_short<.;
 foreach v in A B C D E F {;
  gen samp_8r_iv`v'=1 if samp_8r==1 & ivsamp`v'==1;
  egen totwgt_8r_iv`v'=sum(byqwt) if samp_8r_iv`v'==1;
  gen wgt_8r_iv`v'=byqwt/totwgt_8r_iv`v' if samp_8r_iv`v'==1;
  gen samp_12r_iv`v'=1 if samp_12r==1 & ivsamp`v'==1;
  egen totwgt_12r_iv`v'=sum(f2qwt) if samp_12r_iv`v'==1;
  gen wgt_12r_iv`v'=f2qwt/totwgt_12r_iv`v' if samp_12r_iv`v'==1;
  *8th grade reading scores;
   reg by2xrstd `iv`v'' $ch_ind $ch_ma $ch_dist $ch_div if pubschby==1 [aw=wgt_8r_iv`v'], cluster(fipsmsa);
   outreg using apptabD7.txt, append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_8r_iv`v'");
  *12th grade reading scores;
   reg f22xrstd `iv`v'' $ch_ind $ch_ma $ch_dist $ch_div if pubschf2==1 [aw=wgt_12r_iv`v'], cluster(fipsmsa);
   outreg using apptabD7.txt, append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_12r_iv`v'");
  };

*Now switch to my preferred BY sample.  Restandardize weights separately for each model;
 use ${mywork_confidential}/jrAbysample.dta, clear;
 global jr_ind "jr_lnfaminc jr_asian jr_hispanic jr_black jr_female jr_parcolg jr_parscol";
 global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 mark jr_cntrls;
 markout jr_cntrls
         $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
 gen samp_8r=1   if byqwt>0 & jr_cntrls==1 & pubschby==1 & by2xrstd<. ;
 local ivA "ch_nstreams_lg ch_nstreams_sm";
 local ivB "ch_nstreams_tot";
 local ivC "ch_nstreams_lg jr_nstreamsB_sm";
 local ivD "jr_nstreamsB_tot";
 local ivE "jr_nstreamsB_inter jr_nstreamsB_intra";
 local ivF "jr_nstreamsB_long jr_nstreamsB_short";
 gen jr_nstreamsB_sm=jr_nstreamsB_tot-ch_nstreams_lg;
 gen ivsampA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
 gen ivsampB=1 if ch_nstreams_tot<. ;
 gen ivsampC=1 if ch_nstreams_lg<. & jr_nstreamsB_sm<.;
 gen ivsampD=1 if jr_nstreamsB_tot<.;
 gen ivsampE=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
 gen ivsampF=1 if jr_nstreamsB_long<. & jr_nstreamsB_short<.;
 foreach v in A B C D E F {;
  gen samp_8r_iv`v'=1 if samp_8r==1 & ivsamp`v'==1;
  egen totwgt_8r_iv`v'=sum(byqwt) if samp_8r_iv`v'==1;
  gen wgt_8r_iv`v'=byqwt/totwgt_8r_iv`v' if samp_8r_iv`v'==1;
  *8th grade reading scores;
   reg by2xrstd `iv`v'' $jr_ind $jr_ma $jr_dist $jr_div if pubschby==1 [aw=wgt_8r_iv`v'], cluster(fipsmsa);
   outreg using apptabD7.txt, append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_8r_iv`v'");
  };

*Now switch to my preferred F2 sample.  Restandardize weights separately for each model;
 use ${mywork_confidential}/jrAf2sample.dta, clear;
 global jr_ind "jr_lnfaminc jr_asian jr_hispanic jr_black jr_female jr_parcolg jr_parscol";
 global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 mark jr_cntrls;
 markout jr_cntrls
         $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
 gen samp_12r=1   if f2qwt>0 & jr_cntrls==1 & pubschf2==1 & f22xrstd<. ;
 local ivA "ch_nstreams_lg ch_nstreams_sm";
 local ivB "ch_nstreams_tot";
 local ivC "ch_nstreams_lg jr_nstreamsB_sm";
 local ivD "jr_nstreamsB_tot";
 local ivE "jr_nstreamsB_inter jr_nstreamsB_intra";
 local ivF "jr_nstreamsB_long jr_nstreamsB_short";
 gen jr_nstreamsB_sm=jr_nstreamsB_tot-ch_nstreams_lg;
 gen ivsampA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
 gen ivsampB=1 if ch_nstreams_tot<. ;
 gen ivsampC=1 if ch_nstreams_lg<. & jr_nstreamsB_sm<.;
 gen ivsampD=1 if jr_nstreamsB_tot<.;
 gen ivsampE=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
 gen ivsampF=1 if jr_nstreamsB_long<. & jr_nstreamsB_short<.;
 foreach v in A B C D E F {;
  gen samp_12r_iv`v'=1 if samp_12r==1 & ivsamp`v'==1;
  egen totwgt_12r_iv`v'=sum(f2qwt) if samp_12r_iv`v'==1;
  gen wgt_12r_iv`v'=f2qwt/totwgt_12r_iv`v' if samp_12r_iv`v'==1;
  *12th grade reading scores;
   reg f22xrstd `iv`v'' $jr_ind $jr_ma $jr_dist $jr_div if pubschf2==1 [aw=wgt_12r_iv`v'], cluster(fipsmsa);
   outreg using apptabD7.txt, append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_12r_iv`v'");
  };

log close;
