capture log close
log using apptabD8.smcl, replace

*Program to explore sensitivity to instrument choice, MSA level models;

#delimit;
version 8.0;
pause off;
set more off;
query;
creturn list;
clear;
set mem 64m;
set matsize 800;

do "../../definedirs.do";
quietly do "../moultonprog.do";


capture program drop oneiv;
program define oneiv;
 syntax varlist [if] [in] [using] [fw pw aw],
                depvar(varname numeric) endog(varname numeric) instrum(varlist numeric) [outreg *];
 *Define sample;
  marksample samp;
  markout `samp' `varlist' `depvar' `endog' `instrum';
 *Estimate first stage;
  quietly reg `endog' `varlist' `instrum' if `samp' [`weight'`exp'];
  tempvar xhat;
  predict `xhat', xb;
 *Now estimate exogeneity test;
  quietly reg `depvar' `varlist' `xhat' `endog' if `samp' [`weight'`exp'];
  quietly test `xhat';
  local p_exog=r(p);
 *And IV model;
  ivreg `depvar' `varlist' (`endog'=`instrum') if `samp' [`weight'`exp'];
  tempvar ivresid;
  predict `ivresid', residuals;
  tempname mainmod;
  if wordcount("`instrum'")>1 {;
   *Overid test;
    _estimates hold `mainmod';
    quietly reg `ivresid' `varlist' `instrum' if `samp' [`weight'`exp'];
    local p_overid=chi2(wordcount("`instrum'")-1, e(N)*e(r2));
    _estimates unhold `mainmod';
   };
  else {;
   local p_overid=-1;
   };
  if "`outreg'"=="outreg" {;
    outreg `using', `options' bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Exog. p", `p_exog', "Overid p", `p_overid');
    };
end;

local ivA "mnumrivr mnumstre";
local ivB "ch_nstreams_tot";
local ivC "mnumrivr jr_nstreamsB_sm";
local ivD "jr_nstreamsB_tot";
local ivE "jr_nstreamsB_inter jr_nstreamsB_intra";
local ivF "jr_nstreamsB_long jr_nstreamsB_short";

*Start with CD data;
 *Merge on total rivers;
 use ${mywork_public}/msadata;
 keep fipsmsa jr_nstreamsB*;
 sort fipsmsa;
 tempfile jrstreams;
 save `jrstreams';
 use ${hoxbydat_confidential}/achievement.regressions.dta, clear;
 sort fipsmsa;
 merge fipsmsa using `jrstreams', uniqusing;
 gen ch_nstreams_tot=mnumrivr+mnumstre;
 gen jr_nstreamsB_sm=jr_nstreamsB_tot-mnumrivr;
 global cd_ind "lnfaminc asian hispanic black female parcolg parscol";
 global cd_ma "mpop marea mlnincme mincgini mpctasia mpctblac mpcthisp mherfrac mherfeth mpctscol mpctcolg mherfed";
 global cd_dist "lnincmea incgini pctasia pctblac pcthisp herfrac herfeth pctscol pctcolg herfed";
 global cd_div "ddiv1 ddiv2 ddiv3 ddiv4 ddiv5 ddiv6 ddiv7 ddiv8";
 mark cd_cntrls;
 markout cd_cntrls $cd_ind $cd_ma $cd_dist $cd_div;
 gen ivsampA=1 if mnumrivr<. & mnumstre<.;
 gen ivsampB=1 if ch_nstreams_tot<.;
 gen ivsampC=1 if mnumrivr<. & jr_nstreamsB_sm<.;
 gen ivsampD=1 if jr_nstreamsB_tot<.;
 gen ivsampE=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
 gen ivsampF=1 if jr_nstreamsB_long<. & jr_nstreamsB_short<.;
 gen samp_8r_ols=1 if bywght>0 & cd_cntrls==1 & pubschby==1 & by2xrstd<.;
 gen samp_12r_ols=1 if f2wght>0 & cd_cntrls==1 & pubschf2==1 & f22xrstd<.;
 foreach l in A B C D E F {;
  gen samp_8r_`l'=1 if samp_8r_ols==1 & ivsamp`l'==1;
  gen samp_12r_`l'=1 if samp_12r_ols==1 & ivsamp`l'==1;
 };
tempfile cdind;
save `cdind';
*8th grade;
 *OLS;
 collapse (mean) by2xrstd mchoienr $cd_ind $cd_ma $cd_dist $cd_div if samp_8r_ols==1 [aw=bywght], by(fipsmsa);
 reg by2xrstd mchoienr $cd_ind $cd_ma $cd_dist $cd_div;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel replace ctitle("CD_8r_ols_all");
 reg by2xrstd mchoienr $cd_ind $cd_ma $cd_div;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("CD_8r_ols_mi");
 reg by2xrstd mchoienr $cd_ma $cd_div;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("CD_8r_ols_m");
 *IV;
 foreach l in A B C D E F {;
  use `cdind', clear;
  collapse (mean) by2xrstd mchoienr $cd_ind $cd_ma $cd_dist $cd_div `iv`l'' if samp_8r_`l'==1 [aw=bywght], by(fipsmsa);
  oneiv $cd_ind $cd_ma $cd_dist $cd_div using "apptabD8.txt",
        depvar(by2xrstd) endog(mchoienr) instrum(`iv`l'') outreg append ctitle("CD_8r_`l'_all");
  oneiv $cd_ind $cd_ma $cd_div using "apptabD8.txt",
        depvar(by2xrstd) endog(mchoienr) instrum(`iv`l'') outreg append ctitle("CD_8r_`l'_mi");
  oneiv $cd_ma $cd_div using "apptabD8.txt",
        depvar(by2xrstd) endog(mchoienr) instrum(`iv`l'') outreg append ctitle("CD_8r_`l'_m");
  };
*12th grade;
 *OLS;
 use `cdind', clear;
 collapse (mean) f22xrstd mchoienr $cd_ind $cd_ma $cd_dist $cd_div if samp_12r_ols==1 [aw=f2wght], by(fipsmsa);
 reg f22xrstd mchoienr $cd_ind $cd_ma $cd_dist $cd_div;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("CD_12r_ols_all");
 reg f22xrstd mchoienr $cd_ind $cd_ma $cd_div;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("CD_12r_ols_mi");
 reg f22xrstd mchoienr $cd_ma $cd_div;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("CD_12r_ols_m");
 *IV;
 foreach l in A B C D E F {;
  use `cdind', clear;
  collapse (mean) f22xrstd mchoienr $cd_ind $cd_ma $cd_dist $cd_div `iv`l'' if samp_12r_`l'==1 [aw=f2wght], by(fipsmsa);
  oneiv $cd_ind $cd_ma $cd_dist $cd_div using "apptabD8.txt",
        depvar(f22xrstd) endog(mchoienr) instrum(`iv`l'') outreg append ctitle("CD_12r_`l'_all");
  oneiv $cd_ind $cd_ma $cd_div using "apptabD8.txt",
        depvar(f22xrstd) endog(mchoienr) instrum(`iv`l'') outreg append ctitle("CD_12r_`l'_mi");
  oneiv $cd_ma $cd_div using "apptabD8.txt",
        depvar(f22xrstd) endog(mchoienr) instrum(`iv`l'') outreg append ctitle("CD_12r_`l'_m");
  };

*CH sample.  Restandardize weights separately for each model;
 use ${mywork_confidential}/chsample.dta, clear;
 gen jr_nstreamsB_sm=jr_nstreamsB_tot-ch_nstreams_lg;
 local ivA "ch_nstreams_sm ch_nstreams_lg";
local ivC "ch_nstreams_lg jr_nstreamsB_sm";
 global ch_ind "ch_lnfaminc ch_asian ch_hispanic ch_black ch_female ch_parcolg ch_parscol";
 global ch_ma "m_pop_n m_arealand ch_m_avglnmeaninc ch_m_gini ch_m_pop_fas ch_m_pop_fbl ch_m_pop_fhi ch_m_herfrace ch_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global ch_dist "d_lnmeanincA ch_d_gini ch_d_pop_fas ch_d_pop_fbl ch_d_pop_fhi ch_d_herfrace ch_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global ch_div "ch_d_div1 ch_d_div2 ch_d_div3 ch_d_div4 ch_d_div5 ch_d_div6 ch_d_div7 ch_d_div8";
 mark ch_cntrls;
 markout ch_cntrls
         $ch_ind $ch_ma $ch_dist $ch_div ch_choice;
 gen ivsampA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
 gen ivsampB=1 if ch_nstreams_tot<.;
 gen ivsampC=1 if ch_nstreams_lg<. & jr_nstreamsB_sm<.;
 gen ivsampD=1 if jr_nstreamsB_tot<.;
 gen ivsampE=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
 gen ivsampF=1 if jr_nstreamsB_long<. & jr_nstreamsB_short<.;
 gen samp_8r_ols=1 if byqwt>0 & ch_cntrls==1 & pubschby==1 & by2xrstd<.;
 egen totwgt_8r_ols=sum(byqwt) if samp_8r_ols==1, by(fipsmsa);
 gen wgt_8r_ols=byqwt/totwgt_8r_ols if samp_8r_ols==1;
 gen samp_12r_ols=1 if f2qwt>0 & ch_cntrls==1 & pubschf2==1 & f22xrstd<.;
 egen totwgt_12r_ols=sum(f2qwt) if samp_12r_ols==1, by(fipsmsa);
 gen wgt_12r_ols=f2qwt/totwgt_12r_ols if samp_12r_ols==1;
 foreach l in A B C D E F {;
  gen samp_8r_`l'=1 if samp_8r_ols==1 & ivsamp`l'==1;
  egen totwgt_8r_`l'=sum(byqwt) if samp_8r_`l'==1, by(fipsmsa);
  gen wgt_8r_`l'=byqwt/totwgt_8r_`l' if samp_8r_`l'==1;
  gen samp_12r_`l'=1 if samp_12r_ols==1 & ivsamp`l'==1;
  egen totwgt_12r_`l'=sum(f2qwt) if samp_12r_`l'==1, by(fipsmsa);
  gen wgt_12r_`l'=f2qwt/totwgt_12r_`l' if samp_12r_`l'==1;
 };
tempfile chind;
save `chind';

*8th grade;
 *OLS;
 collapse (mean) by2xrstd ch_choice $ch_ind $ch_ma $ch_dist $ch_div if samp_8r_ols==1 [aw=byqwt], by(fipsmsa);
 reg by2xrstd ch_choice $ch_ind $ch_ma $ch_dist $ch_div;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("CH_8r_ols_all");
 reg by2xrstd ch_choice $ch_ind $ch_ma $ch_div;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("CH_8r_ols_mi");
 reg by2xrstd ch_choice $ch_ma $ch_div;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("CH_8r_ols_m");
 *IV;
 foreach l in A B C D E F {;
  use `chind', clear;
  collapse (mean) by2xrstd ch_choice $ch_ind $ch_ma $ch_dist $ch_div `iv`l'' if samp_8r_`l'==1 [aw=byqwt], by(fipsmsa);
  oneiv $ch_ind $ch_ma $ch_dist $ch_div using "apptabD8.txt",
        depvar(by2xrstd) endog(ch_choice) instrum(`iv`l'') outreg append ctitle("CH_8r_`l'_all");
  oneiv $ch_ind $ch_ma $ch_div using "apptabD8.txt",
        depvar(by2xrstd) endog(ch_choice) instrum(`iv`l'') outreg append ctitle("CH_8r_`l'_mi");
  oneiv $ch_ma $ch_div using "apptabD8.txt",
        depvar(by2xrstd) endog(ch_choice) instrum(`iv`l'') outreg append ctitle("CH_8r_`l'_m");
  };
*Now 12th grade scores;
 use `chind', clear;
 *OLS;
 collapse (mean) f22xrstd ch_choice $ch_ind $ch_ma $ch_dist $ch_div if samp_12r_ols==1 [aw=f2qwt], by(fipsmsa);
 reg f22xrstd ch_choice $ch_ind $ch_ma $ch_dist $ch_div;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("CH_12r_ols_all");
 reg f22xrstd ch_choice $ch_ind $ch_ma $ch_div;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("CH_12r_ols_mi");
 reg f22xrstd ch_choice $ch_ma $ch_div;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("CH_12r_ols_m");
 *IV;
 foreach l in A B C D E F {;
  use `chind', clear;
  collapse (mean) f22xrstd ch_choice $ch_ind $ch_ma $ch_dist $ch_div `iv`l'' if samp_12r_`l'==1 [aw=f2qwt], by(fipsmsa);
  oneiv $ch_ind $ch_ma $ch_dist $ch_div using "apptabD8.txt",
        depvar(f22xrstd) endog(ch_choice) instrum(`iv`l'') outreg append ctitle("CH_12r_`l'_all");
  oneiv $ch_ind $ch_ma $ch_div using "apptabD8.txt",
        depvar(f22xrstd) endog(ch_choice) instrum(`iv`l'') outreg append ctitle("CH_12r_`l'_mi");
  oneiv $ch_ma $ch_div using "apptabD8.txt",
        depvar(f22xrstd) endog(ch_choice) instrum(`iv`l'') outreg append ctitle("CH_12r_`l'_m");
  };


*JR sample.  Restandardize weights separately for each model;
 use ${mywork_confidential}/jrAbysample.dta, clear;
 gen jr_nstreamsB_sm=jr_nstreamsB_tot-ch_nstreams_lg;
 global jr_ind "jr_lnfaminc jr_asian jr_hispanic jr_black jr_female jr_parcolg jr_parscol";
 global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
 mark jr_cntrls;
 markout jr_cntrls
         $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
 gen ivsampA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
 gen ivsampB=1 if ch_nstreams_tot<.;
 gen ivsampC=1 if ch_nstreams_lg<. & jr_nstreamsB_sm<.;
 gen ivsampD=1 if jr_nstreamsB_tot<.;
 gen ivsampE=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
 gen ivsampF=1 if jr_nstreamsB_long<. & jr_nstreamsB_short<.;
 gen samp_8r_ols=1 if byqwt>0 & jr_cntrls==1 & pubschby==1 & by2xrstd<.;
 egen totwgt_8r_ols=sum(byqwt) if samp_8r_ols==1, by(fipsmsa);
 gen wgt_8r_ols=byqwt/totwgt_8r_ols if samp_8r_ols==1;
 foreach l in A B C D E F {;
  gen samp_8r_`l'=1 if samp_8r_ols==1 & ivsamp`l'==1;
  egen totwgt_8r_`l'=sum(byqwt) if samp_8r_`l'==1, by(fipsmsa);
  gen wgt_8r_`l'=byqwt/totwgt_8r_`l' if samp_8r_`l'==1;
 };
 tempfile jrind_8;
 save `jrind_8';
*8th grade;
 *OLS;
 collapse (mean) by2xrstd jr_choice $jr_ind $jr_ma $jr_dist $jr_div if samp_8r_ols==1 [aw=byqwt], by(fipsmsa);
 reg by2xrstd jr_choice $jr_ind $jr_ma $jr_dist $jr_div ;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("JR_8r_ols_all");
 reg by2xrstd jr_choice $jr_ind $jr_ma $jr_div ;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("JR_8r_ols_mi");
 reg by2xrstd jr_choice $jr_ma $jr_div ;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("JR_8r_ols_m");
 *IV;
 foreach l in A B C D E F {;
  use `jrind_8', clear;
  collapse (mean) by2xrstd jr_choice $jr_ind $jr_ma $jr_dist $jr_div `iv`l'' if samp_8r_`l'==1 [aw=byqwt], by(fipsmsa);
  oneiv $jr_ind $jr_ma $jr_dist $jr_div using "apptabD8.txt",
        depvar(by2xrstd) endog(jr_choice) instrum(`iv`l'') outreg append ctitle("JR_8r_`l'_all");
  oneiv $jr_ind $jr_ma $jr_div using "apptabD8.txt",
        depvar(by2xrstd) endog(jr_choice) instrum(`iv`l'') outreg append ctitle("JR_8r_`l'_mi");
  oneiv $jr_ma $jr_div using "apptabD8.txt",
        depvar(by2xrstd) endog(jr_choice) instrum(`iv`l'') outreg append ctitle("JR_8r_`l'_m");
  };

 *Now 12th grade scores;
 use ${mywork_confidential}/jrAf2sample.dta, clear;
 gen jr_nstreamsB_sm=jr_nstreamsB_tot-ch_nstreams_lg;
 global jr_ind "jr_lnfaminc jr_asian jr_hispanic jr_black jr_female jr_parcolg jr_parscol";
 global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
 mark jr_cntrls;
 markout jr_cntrls
         $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
 gen ivsampA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
 gen ivsampB=1 if ch_nstreams_tot<.;
 gen ivsampC=1 if ch_nstreams_lg<. & jr_nstreamsB_sm<.;
 gen ivsampD=1 if jr_nstreamsB_tot<.;
 gen ivsampE=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
 gen ivsampF=1 if jr_nstreamsB_long<. & jr_nstreamsB_short<.;
 gen samp_12r_ols=1 if f2qwt>0 & jr_cntrls==1 & pubschf2==1 & f22xrstd<.;
 egen totwgt_12r_ols=sum(f2qwt) if samp_12r_ols==1, by(fipsmsa);
 gen wgt_12r_ols=f2qwt/totwgt_12r_ols if samp_12r_ols==1;
 foreach l in A B C D E F {;
  gen samp_12r_`l'=1 if samp_12r_ols==1 & ivsamp`l'==1;
  egen totwgt_12r_`l'=sum(f2qwt) if samp_12r_`l'==1, by(fipsmsa);
  gen wgt_12r_`l'=f2qwt/totwgt_12r_`l' if samp_12r_`l'==1;
 };
 tempfile jrind_12;
 save `jrind_12';
 *OLS;
 collapse (mean) f22xrstd jr_choice $jr_ind $jr_ma $jr_dist $jr_div `iv`l'' if samp_12r_ols==1 [aw=f2qwt], by(fipsmsa);
 reg f22xrstd jr_choice $jr_ind $jr_ma $jr_dist $jr_div ;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("JR_12r_ols_all");
 reg f22xrstd jr_choice $jr_ind $jr_ma $jr_div ;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("JR_12r_ols_mi");
 reg f22xrstd jr_choice $jr_ma $jr_div ;
 outreg using "apptabD8.txt", bdec(8) rdec(8) se noparen noaster nolabel append ctitle("JR_12r_ols_m");
 *IV;
 foreach l in A B C D E F {;
  use `jrind_12', clear;
  collapse (mean) f22xrstd jr_choice $jr_ind $jr_ma $jr_dist $jr_div `iv`l'' if samp_12r_`l'==1 [aw=f2qwt], by(fipsmsa);
  oneiv $jr_ind $jr_ma $jr_dist $jr_div using "apptabD8.txt",
        depvar(f22xrstd) endog(jr_choice) instrum(`iv`l'') outreg append ctitle("JR_12r_`l'_all");
  oneiv $jr_ind $jr_ma $jr_div using "apptabD8.txt",
        depvar(f22xrstd) endog(jr_choice) instrum(`iv`l'') outreg append ctitle("JR_12r_`l'_mi");
  oneiv $jr_ma $jr_div using "apptabD8.txt",
        depvar(f22xrstd) endog(jr_choice) instrum(`iv`l'') outreg append ctitle("JR_12r_`l'_m");
  };

log close;
