capture log close
log using apptabE1.smcl, replace

*Program to explore sensitivity of spending and class size effects to instrument choice;
#delimit;
version 8.0;
pause off;
set more off;
query;
creturn list;
clear;
set mem 64m;
set matsize 800;

do "../../definedirs.do";
quietly do "../moultonprog.do";

capture program drop onereg;
program define onereg, eclass;
 syntax varlist [if] [in] [using] [fw pw aw],
                depvar(varname numeric) endog(varname numeric) instrum(varlist numeric)
                [cluster(varname) moulton(varlist min=1 max=2) outreg *];
 *Program to run a single IV regression and compute exogeneity tests,
 *with classical, clustered, or Moulton SEs;

 *Start by computing the sample;
  marksample samp;
  markout `samp' `depvar' `endog' `instrum';
 *Estimate first stage;
  quietly reg `endog' `instrum' `varlist' if `samp' [`weight'`exp'];
  tempvar xhat;
  predict `xhat', xb;

 tempname mainmod;
 *Begin with classical case;
  if "`cluster'"=="" & "`moulton'"=="" {;
   *Run exog test;
    quietly reg `depvar' `endog' `varlist' `xhat' if `samp' [`weight'`exp'];
    quietly test `xhat';
    local p_exog=r(p);
   *Run overid test;
    ivreg `depvar' `varlist' (`endog'=`instrum') if `samp' [`weight'`exp'];
    tempvar ivresid;
    predict `ivresid', residuals;
    _estimates hold `mainmod';
    if wordcount("`instrum'")>1 {;
     quietly reg `ivresid' `varlist' `instrum' if `samp' [`weight'`exp'];
     local p_overid=chi2(wordcount("`instrum'")-1, e(N)*e(r2));
     };
    else {;
     local p_overid=-1;
     };
   _estimates unhold `mainmod';
   if "`outreg'"=="outreg" {;
    outreg `using', `options' bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Exog. p", `p_exog', "Overid p", `p_overid', "Error type", 0);
    };
   };
 *Now clustered;
  if "`cluster'"~="" {;
   *Run exog test;
    quietly reg `depvar' `endog' `varlist' `xhat' if `samp' [`weight'`exp'], cluster(`cluster');
    quietly test `xhat';
    local p_exog=r(p);
   *Run IV;
    local p_overid=-1;
    ivreg `depvar' `varlist' (`endog'=`instrum') if `samp' [`weight'`exp'], cluster(`cluster');
    local nclust=e(df_r)+1;
   if "`outreg'"=="outreg" {;
    outreg `using', `options' bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Exog. p", `p_exog', "Overid p", `p_overid', "Error type", 1,
                             "#cluster", `nclust');
    };
   };
 *And finally Moulton;
  if "`moulton'"~="" {;
   *Run exog test;
    quietly olserrcomp `depvar' `endog' `varlist' `xhat' if `samp' [`weight'`exp'], groups(`moulton');
    quietly test `xhat';
    local p_exog=r(p);
   *Run IV;
    local p_overid=-1;
    iverrcomp `depvar' `varlist' (`endog'=`instrum') if `samp' [`weight'`exp'], groups(`moulton');
    local ngroups=e(N_g1);
    local sd_ind=e(sigma_0);
    local sd_gp=e(sigma_1);
   if "`outreg'"=="outreg" {;
    outreg `using', `options' bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Exog. p", `p_exog', "Overid p", `p_overid', "Error type", 2,
                             "#Groups", `ngroups', "SDind", `sd_ind', "SDgroup", `sd_gp');
    };
   };
end;

local ivA "ch_nstreams_lg ch_nstreams_sm";
local ivB "ch_nstreams_tot";
local ivC "ch_nstreams_lg jr_nstreamsB_sm";
local ivD "jr_nstreamsB_tot";
local ivE "jr_nstreamsB_inter jr_nstreamsB_intra";
local ivF "jr_nstreamsB_long jr_nstreamsB_short";

*CD data;
 use ${hoxbydat_confidential}/district.regressions.dta;
 replace mpop=mpop/10000000;
 replace marea=marea/100000;
 gen mnumstre_tot=mnumrivr+mnumstre;
 global cd_ma "mpop marea mlnincme mincgini mpctasia mpctblac mpcthisp mherfrac mherfeth mpctscol mpctcolg mherfed";
 global cd_dist "lnincmea incgini pctasia pctblac pcthisp herfrac herfeth pctscol pctcolg herfed";
 global cd_div "ddiv1 ddiv2 ddiv3 ddiv4 ddiv5 ddiv6 ddiv7 ddiv8";
 reg lnpps mchoienr $cd_dist $cd_ma $cd_div [aw=rcwght];
 outreg using "apptabE1.txt", replace bdec(8) rdec(8) se noparen noaster nolabel ctitle("CD_ols_classical");
 reg lnpps mchoienr $cd_dist $cd_ma $cd_div [aw=rcwght], cluster(fipsmsa);
 outreg using "apptabE1.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CD_ols_cluster");
 olserrcomp lnpps mchoienr $cd_dist $cd_ma $cd_div [aw=rcwght], groups(fipsmsa);
 outreg using "apptabE1.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CD_ols_moulton");
 onereg $cd_dist $cd_ma $cd_div using "apptabE1.txt" [aw=rcwght],
        depvar(lnpps) endog(mchoienr) instrum(mnumrivr mnumstre)
        outreg append ctitle("CD_ivA_classical");
 onereg $cd_dist $cd_ma $cd_div using "apptabE1.txt" [aw=rcwght],
        depvar(lnpps) endog(mchoienr) instrum(mnumrivr mnumstre)
        cluster(fipsmsa) outreg append ctitle("CD_ivA_cluster");
 onereg $cd_dist $cd_ma $cd_div using "apptabE1.txt" [aw=rcwght],
        depvar(lnpps) endog(mchoienr) instrum(mnumrivr mnumstre)
        moulton(fipsmsa) outreg append ctitle("CD_ivA_moulton");
 onereg $cd_dist $cd_ma $cd_div using "apptabE1.txt" [aw=rcwght],
        depvar(lnpps) endog(mchoienr) instrum(mnumstre_tot)
        outreg append ctitle("CD_ivB_classical");
 onereg $cd_dist $cd_ma $cd_div using "apptabE1.txt" [aw=rcwght],
        depvar(lnpps) endog(mchoienr) instrum(mnumstre_tot)
        cluster(fipsmsa) outreg append ctitle("CD_ivB_cluster");
 onereg $cd_dist $cd_ma $cd_div using "apptabE1.txt" [aw=rcwght],
        depvar(lnpps) endog(mchoienr) instrum(mnumstre_tot)
        moulton(fipsmsa) outreg append ctitle("CD_ivB_moulton");

*My replication sample;
*CH covariates.  Restandardize weights separately for each model;
 use ${mywork_public}/distdata.dta, clear;
 keep if fipsmsa>0 & fipsmsa<.;
 sort fipsmsa;
 merge fipsmsa using ${mywork_public}/msadata.dta, uniqusing _merge(dist2msa);
 tab dist2msa;
 gen jr_nstreamsB_sm=jr_nstreamsB_tot-ch_nstreams_lg;
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 global ch_ma "m_pop_n m_arealand ch_m_avglnmeaninc ch_m_gini ch_m_pop_fas ch_m_pop_fbl ch_m_pop_fhi ch_m_herfrace ch_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global ch_dist "d_lnmeanincA ch_d_gini ch_d_pop_fas ch_d_pop_fbl ch_d_pop_fhi ch_d_herfrace ch_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global ch_div "ch_d_div1 ch_d_div2 ch_d_div3 ch_d_div4 ch_d_div5 ch_d_div6 ch_d_div7 ch_d_div8";
 global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
 mark ch_cntrls;
 markout ch_cntrls $ch_ma $ch_dist $ch_div ch_choice;
 mark jr_cntrls;
 markout jr_cntrls $jr_ma $jr_dist $jr_div jr_choice;
 gen ivsampA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
 gen ivsampB=1 if ch_nstreams_tot<.;
 gen ivsampC=1 if ch_nstreams_lg<. & jr_nstreamsB_sm<.;
 gen ivsampD=1 if jr_nstreamsB_tot<.;
 gen ivsampE=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
 gen ivsampF=1 if jr_nstreamsB_long<. & jr_nstreamsB_short<.;
 gen samp_ch_ols=1 if rc>0 & rc<. & ch_cntrls==1 & lnpps_cens<.;
 gen samp_jr_ols=1 if rc>0 & rc<. & jr_cntrls==1 & lnpps_cens<.;
 egen totwgt_ch_ols=sum(rc) if samp_ch_ols==1, by(fipsmsa);
 egen totwgt_jr_ols=sum(rc) if samp_jr_ols==1, by(fipsmsa);
 gen wgt_ch_ols=rc/totwgt_ch_ols if samp_ch_ols==1;
 gen wgt_jr_ols=rc/totwgt_jr_ols if samp_jr_ols==1;
 foreach l in A B C D E F {;
  gen samp_ch_`l'=1 if samp_ch_ols==1 & ivsamp`l'==1;
  egen totwgt_ch_`l'=sum(rc) if samp_ch_`l'==1, by(fipsmsa);
  gen wgt_ch_`l'=rc/totwgt_ch_`l' if samp_ch_`l'==1;
  gen samp_jr_`l'=1 if samp_jr_ols==1 & ivsamp`l'==1;
  egen totwgt_jr_`l'=sum(rc) if samp_jr_`l'==1, by(fipsmsa);
  gen wgt_jr_`l'=rc/totwgt_ch_`l' if samp_jr_`l'==1;
 };

 *Do CH analysis;
  *OLS;
   reg lnpps_cens ch_choice $ch_dist $ch_ma $ch_div [aw=wgt_ch_ols];
   outreg using "apptabE1.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_ols_classical");
   reg lnpps_cens ch_choice $ch_dist $ch_ma $ch_div [aw=wgt_ch_ols], cluster(fipsmsa);
   outreg using "apptabE1.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_ols_cluster");
   olserrcomp lnpps_cens ch_choice $ch_dist $ch_ma $ch_div [aw=wgt_ch_ols], groups(fipsmsa);
   outreg using "apptabE1.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_ols_moulton");
  *IV;
   foreach l in A B C D E F {;
    onereg $ch_ma $ch_dist $ch_div using "apptabE1.txt" [aw=wgt_ch_`l'],
           depvar(lnpps_cens) endog(ch_choice) instrum(`iv`l'')
           outreg append ctitle("CH_iv`l'_classical");
    onereg $ch_ma $ch_dist $ch_div using "apptabE1.txt" [aw=wgt_ch_`l'],
           depvar(lnpps_cens) endog(ch_choice) instrum(`iv`l'')
           cluster(fipsmsa) outreg append ctitle("CH_iv`l'_cluster");
    onereg $ch_ma $ch_dist $ch_div using "apptabE1.txt" [aw=wgt_ch_`l'],
           depvar(lnpps_cens) endog(ch_choice) instrum(`iv`l'')
           moulton(fipsmsa) outreg append ctitle("CH_iv`l'_moulton");
    };
 *Do JR analysis;
  *OLS;
   reg lnpps_cens jr_choice $jr_dist $jr_ma $jr_div [aw=wgt_jr_ols];
   outreg using "apptabE1.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_ols_classical");
   reg lnpps_cens jr_choice $jr_dist $jr_ma $jr_div [aw=wgt_jr_ols], cluster(fipsmsa);
   outreg using "apptabE1.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_ols_cluster");
   olserrcomp lnpps_cens jr_choice $jr_dist $jr_ma $jr_div [aw=wgt_jr_ols], groups(fipsmsa);
   outreg using "apptabE1.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_ols_moulton");
  *IV;
   foreach l in A B C D E F {;
    onereg $jr_dist $jr_ma $jr_div using "apptabE1.txt" [aw=wgt_jr_`l'],
           depvar(lnpps_cens) endog(jr_choice) instrum(`iv`l'')
           outreg append ctitle("JR_iv`l'_classical");
    onereg $jr_dist $jr_ma $jr_div using "apptabE1.txt" [aw=wgt_jr_`l'],
           depvar(lnpps_cens) endog(jr_choice) instrum(`iv`l'')
           cluster(fipsmsa) outreg append ctitle("JR_iv`l'_cluster");
    onereg $jr_dist $jr_ma $jr_div using "apptabE1.txt" [aw=wgt_jr_`l'],
           depvar(lnpps_cens) endog(jr_choice) instrum(`iv`l'')
           moulton(fipsmsa) outreg append ctitle("JR_iv`l'_moulton");
    };


*My replication sample--MSA level;
*CH covariates.  Restandardize weights separately for each model;
 global ch_mdiv "ch_m_divis1 ch_m_divis2 ch_m_divis3 ch_m_divis4 ch_m_divis5 ch_m_divis6 ch_m_divis7 ch_m_divis8 ";
 use fipsmsa students pps using ${mywork_public}/distdata.dta, clear;
 keep if fipsmsa>0 & fipsmsa<.;
 gen totexp=pps*students;
 collapse (sum) students totexp, by(fipsmsa);
 gen lnpps=log(totexp/students);
 keep fipsmsa lnpps;
 sort fipsmsa;
 merge fipsmsa using ${mywork_public}/msadata.dta, unique _merge(spend2msa);
 tab spend2msa;
 gen jr_nstreamsB_sm=jr_nstreamsB_tot-ch_nstreams_lg;

 *Do CH analysis;
  *OLS;
   reg lnpps ch_choice $ch_ma $ch_mdiv;
   outreg using "apptabE1.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_ols_MAlvl");
  *IV;
   foreach l in A B C D E F {;
    ivreg lnpps $ch_ma $ch_mdiv (ch_choice=`iv`l'');
    outreg using "apptabE1.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_iv`l'_classical");
    };
 *Do JR analysis;
  *OLS;
   reg lnpps jr_choice $jr_ma $jr_div ;
   outreg using "apptabE1.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_ols_MAlvl");
  *IV;
   foreach l in A B C D E F {;
    ivreg lnpps $jr_ma $jr_div (jr_choice=`iv`l'');
    outreg using "apptabE1.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_iv`l'_classical");
    };

log close;
