capture log close
log using tab1.smcl, replace

#delimit;
version 8.0;
pause off;
set more off;
query;
creturn list;
clear;
set mem 64m;
set matsize 800;

do "../definedirs.do";
quietly do "moultonprog.do";

capture program drop onereg;
program define onereg, eclass;
 syntax varlist [if] [in] [using] [fw pw aw],
                depvar(varname numeric) endog(varname numeric) instrum(varlist numeric)
                [cluster(varname) moulton(varlist min=1 max=2) outreg *];
 *Program to run a single IV regression and compute exogeneity test,
 *with classical, clustered, or Moulton SEs;

 *Start by computing the sample;
  marksample samp;
  markout `samp' `depvar' `endog' `instrum';
 *Estimate first stage;
  quietly reg `endog' `instrum' `varlist' if `samp' [`weight'`exp'];
  tempvar xhat;
  predict `xhat', xb;

 tempname mainmod;
 *Begin with classical case;
  if "`cluster'"=="" & "`moulton'"=="" {;
   *Run exog test;
    quietly reg `depvar' `endog' `varlist' `xhat' if `samp' [`weight'`exp'];
    quietly test `xhat';
    local p_exog=r(p);
   *Run overid test;
    ivreg `depvar' `varlist' (`endog'=`instrum') if `samp' [`weight'`exp'];
    tempvar ivresid;
    predict `ivresid', residuals;
    _estimates hold `mainmod';
    quietly reg `ivresid' `varlist' `instrum' if `samp' [`weight'`exp'];
    local p_overid=chi2(wordcount("`instrum'")-1, e(N)*e(r2));
   _estimates unhold `mainmod';
   if "`outreg'"=="outreg" {;
    outreg `using', `options' bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Exog. p", `p_exog', "Overid p", `p_overid', "Error type", 0);
    };
   };
 *Now clustered;
  if "`cluster'"~="" {;
   *Run exog test;
    quietly reg `depvar' `endog' `varlist' `xhat' if `samp' [`weight'`exp'], cluster(`cluster');
    quietly test `xhat';
    local p_exog=r(p);
   *Run IV model;
    local p_overid=-1;
    ivreg `depvar' `varlist' (`endog'=`instrum') if `samp' [`weight'`exp'], cluster(`cluster');
    local nclust=e(df_r)+1;
   if "`outreg'"=="outreg" {;
    outreg `using', `options' bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Exog. p", `p_exog', "Overid p", `p_overid', "Error type", 1,
                             "#cluster", `nclust');
    };
   };
 *And finally Moulton;
  if "`moulton'"~="" {;
   *Run exog test;
    quietly olserrcomp `depvar' `endog' `varlist' `xhat' if `samp' [`weight'`exp'], groups(`moulton');
    quietly test `xhat';
    local p_exog=r(p);
   *Run IV model;
    local p_overid=-1;
    iverrcomp `depvar' `varlist' (`endog'=`instrum') if `samp' [`weight'`exp'], groups(`moulton');
    local ngroups=e(N_g2);
    local nsubgroups=e(N_g1);
    local sd_ind=e(sigma_0);
    local sd_gp=e(sigma_2);
    local sd_subgp=e(sigma_1);
   if "`outreg'"=="outreg" {;
    outreg `using', `options' bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Exog. p", `p_exog', "Overid p", `p_overid', "Error type", 2,
                             "#Groups", `ngroups', "#Subgroups", `nsubgroups',
                             "SDind", `sd_ind', "SDsubgp", `sd_subgp', "SDgroup", `sd_gp');
    };
   };
end;

*Start with Hoxby/NCES CD data;
 *Merge on total rivers;
 use ${mywork_public}/msadata;
 keep fipsmsa jr_nstreamsB_tot;
 sort fipsmsa;
 tempfile jrstreams;
 save `jrstreams';
 use ${hoxbydat_confidential}/achievement.regressions.dta, clear;
 sort fipsmsa;
 merge fipsmsa using `jrstreams', uniqusing;

 replace mpop=mpop/10000000;
 replace marea=marea/100000;
 global cd_ind "lnfaminc asian hispanic black female parcolg parscol";
 global cd_ma "mpop marea mlnincme mincgini mpctasia mpctblac mpcthisp mherfrac mherfeth mpctscol mpctcolg mherfed";
 global cd_dist "lnincmea incgini pctasia pctblac pcthisp herfrac herfeth pctscol pctcolg herfed";
 global cd_div "ddiv1 ddiv2 ddiv3 ddiv4 ddiv5 ddiv6 ddiv7 ddiv8";

 *8th grade reading scores;
  onereg $cd_ind $cd_ma $cd_dist $cd_div if pubschby==1 using "tab1.txt" [aw=bywght],
         depvar(by2xrstd) endog(mchoienr) instrum(mnumrivr mnumstre)
         outreg replace ctitle("CD_8r_classical");
  onereg $cd_ind $cd_ma $cd_dist $cd_div if pubschby==1 using "tab1.txt" [aw=bywght],
         depvar(by2xrstd) endog(mchoienr) instrum(mnumrivr mnumstre)
         cluster(fipsmsa) outreg append ctitle("CD_8r_cluster");
  onereg $cd_ind $cd_ma $cd_dist $cd_div if pubschby==1 using "tab1.txt" [aw=bywght],
         depvar(by2xrstd) endog(mchoienr) instrum(mnumrivr mnumstre)
         moulton(fipsmsa leaid) outreg append ctitle("CD_8r_moulton");
 *12th grade reading scores;
  onereg $cd_ind $cd_ma $cd_dist $cd_div if pubschf2==1 using "tab1.txt" [aw=f2wght],
         depvar(f22xrstd) endog(mchoienr) instrum(mnumrivr mnumstre)
         outreg append ctitle("CD_12r_classical");
  onereg $cd_ind $cd_ma $cd_dist $cd_div if pubschf2==1 using "tab1.txt" [aw=f2wght],
         depvar(f22xrstd) endog(mchoienr) instrum(mnumrivr mnumstre)
         cluster(fipsmsa) outreg append ctitle("CD_12r_cluster");
  onereg $cd_ind $cd_ma $cd_dist $cd_div if pubschf2==1 using "tab1.txt" [aw=f2wght],
         depvar(f22xrstd) endog(mchoienr) instrum(mnumrivr mnumstre)
         moulton(fipsmsa leaid) outreg append ctitle("CD_12r_moulton");

*Now switch to my data: close replication sample.  Restandardize weights separately for each model;
 use ${mywork_confidential}/chsample.dta, clear;
 global ch_ind "ch_lnfaminc ch_asian ch_hispanic ch_black ch_female ch_parcolg ch_parscol";
 global ch_ma "m_pop_n m_arealand ch_m_avglnmeaninc ch_m_gini ch_m_pop_fas ch_m_pop_fbl ch_m_pop_fhi ch_m_herfrace ch_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global ch_dist "d_lnmeanincA ch_d_gini ch_d_pop_fas ch_d_pop_fbl ch_d_pop_fhi ch_d_herfrace ch_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global ch_div "ch_d_div1 ch_d_div2 ch_d_div3 ch_d_div4 ch_d_div5 ch_d_div6 ch_d_div7 ch_d_div8";
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 mark ch_cntrls;
 markout ch_cntrls
         $ch_ind $ch_ma $ch_dist $ch_div ch_choice;
  gen samp_8r=1   if byqwt>0 & ch_cntrls==1 & pubschby==1 & by2xrstd<. & ch_nstreams_lg<. & ch_nstreams_sm<.;
  gen samp_12r=1  if f2qwt>0 & ch_cntrls==1 & pubschf2==1 & f22xrstd<. & ch_nstreams_lg<. & ch_nstreams_sm<.;
  egen totwgt_8r  =sum(byqwt) if samp_8r  ==1, by(fipsmsa);
  egen totwgt_12r =sum(f2qwt) if samp_12r ==1, by(fipsmsa);
  gen wgt_8r  =byqwt/totwgt_8r   if samp_8r  ==1;
  gen wgt_12r =f2qwt/totwgt_12r  if samp_12r ==1;
 *8th grade reading scores;
  onereg $ch_ind $ch_ma $ch_dist $ch_div if pubschby==1 using "tab1.txt" [aw=wgt_8r],
         depvar(by2xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
         outreg append ctitle("CH_8r_classical");
  onereg $ch_ind $ch_ma $ch_dist $ch_div if pubschby==1 using "tab1.txt" [aw=wgt_8r],
         depvar(by2xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
         cluster(fipsmsa) outreg append ctitle("CH_8r_cluster");
  onereg $ch_ind $ch_ma $ch_dist $ch_div if pubschby==1 using "tab1.txt" [aw=wgt_8r],
         depvar(by2xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
         moulton(fipsmsa leaid) outreg append ctitle("CH_8r_moulton");
 *12th grade reading scores;
  onereg $ch_ind $ch_ma $ch_dist $ch_div if pubschf2==1 using "tab1.txt" [aw=wgt_12r],
         depvar(f22xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
         outreg append ctitle("CH_12r_classical");
  onereg $ch_ind $ch_ma $ch_dist $ch_div if pubschf2==1 using "tab1.txt" [aw=wgt_12r],
         depvar(f22xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
         cluster(fipsmsa) outreg append ctitle("CH_12r_cluster");
  onereg $ch_ind $ch_ma $ch_dist $ch_div if pubschf2==1 using "tab1.txt" [aw=wgt_12r],
         depvar(f22xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
         moulton(fipsmsa leaid) outreg append ctitle("CH_12r_moulton");

*Now switch to preferred replication sample, BY.  Restandardize weights separately for each model;
 use ${mywork_confidential}/jrAbysample.dta, clear;
 global jr_ind "jr_lnfaminc jr_asian jr_hispanic jr_black jr_female jr_parcolg jr_parscol";
 global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 mark jr_cntrls;
 markout jr_cntrls
         $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
 gen samp_8r=1   if byqwt>0 & jr_cntrls==1 & pubschby==1 & by2xrstd<. & ch_nstreams_lg<. & ch_nstreams_sm<.;
 egen totwgt_8r  =sum(byqwt) if samp_8r  ==1, by(fipsmsa);
 gen wgt_8r  =byqwt/totwgt_8r   if samp_8r  ==1;
 *8th grade reading scores;
  onereg $jr_ind $jr_ma $jr_dist $jr_div if pubschby==1 using "tab1.txt" [aw=wgt_8r],
         depvar(by2xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
         outreg append ctitle("JR_8r_classical");
  onereg $jr_ind $jr_ma $jr_dist $jr_div if pubschby==1 using "tab1.txt" [aw=wgt_8r],
         depvar(by2xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
         cluster(fipsmsa) outreg append ctitle("JR_8r_cluster");
  onereg $jr_ind $jr_ma $jr_dist $jr_div if pubschby==1 using "tab1.txt" [aw=wgt_8r],
         depvar(by2xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
         moulton(fipsmsa leaid) outreg append ctitle("JR_8r_moulton");

*Now switch to preferred replication sample, F2.  Restandardize weights separately for each model;
 use ${mywork_confidential}/jrAf2sample.dta, clear;
 global jr_ind "jr_lnfaminc jr_asian jr_hispanic jr_black jr_female jr_parcolg jr_parscol";
 global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 mark jr_cntrls;
 markout jr_cntrls
         $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
 gen samp_12r=1   if f2qwt>0 & jr_cntrls==1 & pubschf2==1 & f22xrstd<. & ch_nstreams_lg<. & ch_nstreams_sm<.;
 egen totwgt_12r  =sum(f2qwt) if samp_12r  ==1, by(fipsmsa);
 gen wgt_12r  =f2qwt/totwgt_12r   if samp_12r  ==1;
 *12th grade reading scores;
  onereg $jr_ind $jr_ma $jr_dist $jr_div if pubschf2==1 using "tab1.txt" [aw=wgt_12r],
         depvar(f22xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
         outreg append ctitle("JR_12r_classical");
  onereg $jr_ind $jr_ma $jr_dist $jr_div if pubschf2==1 using "tab1.txt" [aw=wgt_12r],
         depvar(f22xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
         cluster(fipsmsa) outreg append ctitle("JR_12r_cluster");
  onereg $jr_ind $jr_ma $jr_dist $jr_div if pubschf2==1 using "tab1.txt" [aw=wgt_12r],
         depvar(f22xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
         moulton(fipsmsa leaid) outreg append ctitle("JR_12r_moulton");

log close;
