capture log close
log using tab2.smcl, replace

/* First stage models */

#delimit;
version 8.0;
pause off;
set more off;
query;
creturn list;
clear;
set mem 64m;
set matsize 800;

do "../definedirs.do";
quietly do "moultonprog.do";

*Using Hoxby/NCES CD data;

 *Start by estimating first stage at the MSA level;
 use ${hoxbydat_confidential}/firststage.regression.dta;
 replace mpop=mpop/10000000;
 replace marea=marea/100000;
 regress mchoienr mnumrivr mnumstre mpop marea mlnincme mincgini mpctasia mpctblac mpcthisp mherfrac
                  mherfeth mpctscol mpctcolg mherfed
                  fs_div1 fs_div2 fs_div3 fs_div4 fs_div5 fs_div6 fs_div7 fs_div8 fs_div9;
 test mnumrivr mnumstre;
 local fstat=r(F);
 local pval=r(p);
 outreg using tab2.txt, title("First stage") ctitle("CD_msa") bdec(8) rdec(8) adec(8) se noparen noaster
        addstat("F", `fstat', "p", `pval') replace;
 *Now at the individual level;
 use ${hoxbydat_confidential}/achievement.regressions.dta, clear;
 global cd_ind "lnfaminc asian hispanic black female parcolg parscol";
 global cd_ma "mpop marea mlnincme mincgini mpctasia mpctblac mpcthisp mherfrac mherfeth mpctscol mpctcolg mherfed";
 global cd_dist "lnincmea incgini pctasia pctblac pcthisp herfrac herfeth pctscol pctcolg herfed";
 global cd_div "ddiv1 ddiv2 ddiv3 ddiv4 ddiv5 ddiv6 ddiv7 ddiv8";
 replace mpop=mpop/10000000;
 replace marea=marea/100000;
 *Start with 8th grade sample;
  quietly ivreg by2xrstd $cd_ind $cd_ma $cd_dist $cd_div (mchoienr=mnumrivr mnumstre) if pubschby==1 [aw=bywght];
  gen samp8=e(sample);
  regress mchoienr $cd_ind $cd_ma $cd_dist $cd_div mnumrivr mnumstre [aw=bywght] if samp8;
  test mnumrivr mnumstre;
  local fstat=r(F);
  local pval=r(p);
  outreg using tab2.txt, ctitle("CD_ind8_classical") bdec(8) rdec(8) adec(8) se noparen noaster addstat("F", `fstat', "p", `pval') append;
  regress mchoienr $cd_ind $cd_ma $cd_dist $cd_div mnumrivr mnumstre [aw=bywght] if samp8, cluster(fipsmsa);
  test mnumrivr mnumstre;
  local fstat=r(F);
  local pval=r(p);
  outreg using tab2.txt, ctitle("CD_ind8_cluster") bdec(8) rdec(8) adec(8) se noparen noaster addstat("F", `fstat', "p", `pval') append;
  olserrcomp mchoienr $cd_ind $cd_ma $cd_dist $cd_div mnumrivr mnumstre [aw=bywght] if samp8, groups(fipsmsa leaid);
  test mnumrivr mnumstre;
  local chi2=r(chi2);
  local pval=r(p);
  outreg using tab2.txt, ctitle("CD_ind8_moulton") bdec(8) rdec(8) adec(8) se noparen noaster addstat("chi2", `chi2', "p", `pval') append;
 *And then 12th grade sample;
  quietly ivreg f22xrstd $cd_ind $cd_ma $cd_dist $cd_div (mchoienr=mnumrivr mnumstre) if pubschf2==1 [aw=f2wght];
  gen samp12=e(sample);
  regress mchoienr $cd_ind $cd_ma $cd_dist $cd_div mnumrivr mnumstre [aw=f2wght] if samp12;
  test mnumrivr mnumstre;
  local fstat=r(F);
  local pval=r(p);
  outreg using tab2.txt, ctitle("CD_ind12_classical") bdec(8) rdec(8) adec(8) se noparen noaster addstat("F", `fstat', "p", `pval') append;
  regress mchoienr $cd_ind $cd_ma $cd_dist $cd_div mnumrivr mnumstre [aw=f2wght] if samp12, cluster(fipsmsa);
  test mnumrivr mnumstre;
  local fstat=r(F);
  local pval=r(p);
  outreg using tab2.txt, ctitle("CD_ind12_cluster") bdec(8) rdec(8) adec(8) se noparen noaster addstat("F", `fstat', "p", `pval') append;
  olserrcomp mchoienr $cd_ind $cd_ma $cd_dist $cd_div mnumrivr mnumstre [aw=f2wght] if samp12, groups(fipsmsa leaid);
  test mnumrivr mnumstre;
  local chi2=r(chi2);
  local pval=r(p);
  outreg using tab2.txt, ctitle("CD_ind12_moulton") bdec(8) rdec(8) adec(8) se noparen noaster addstat("chi2", `chi2', "p", `pval') append;

*Using close replication sample;
 use ${mywork_public}/msadata.dta, clear;
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 regress ch_choice ch_nstreams_sm ch_nstreams_lg m_pop_n m_arealand ch_m_avglnmeaninc ch_m_gini
                   ch_m_pop_fas ch_m_pop_fbl ch_m_pop_fhi ch_m_herfrace ch_m_herfethn
                   m_ed_scol m_ed_ba m_herfed ch_m_divis1 ch_m_divis2 ch_m_divis3
                   ch_m_divis4 ch_m_divis5 ch_m_divis6 ch_m_divis7 ch_m_divis8 ch_m_divis9;
 test ch_nstreams_sm ch_nstreams_lg;
 local fstat=r(F);
 local pval=r(p);
 outreg using tab2.txt, ctitle("CH_MSA") bdec(8) rdec(8) adec(8) se noparen noaster append addstat("F", `fstat', "p", `pval');
 *And at the individual level;
  use ${mywork_confidential}/chsample.dta, clear;
  global ch_ind "ch_lnfaminc ch_asian ch_hispanic ch_black ch_female ch_parcolg ch_parscol";
  global ch_ma "m_pop_n m_arealand ch_m_avglnmeaninc ch_m_gini ch_m_pop_fas ch_m_pop_fbl ch_m_pop_fhi ch_m_herfrace ch_m_herfethn m_ed_scol m_ed_ba m_herfed";
  global ch_dist "d_lnmeanincA ch_d_gini ch_d_pop_fas ch_d_pop_fbl ch_d_pop_fhi ch_d_herfrace ch_d_herfethn d_ed_scol d_ed_ba d_herfed";
  global ch_div "ch_d_div1 ch_d_div2 ch_d_div3 ch_d_div4 ch_d_div5 ch_d_div6 ch_d_div7 ch_d_div8";
  replace m_pop_n=m_pop_n/10000000;
  replace m_arealand=m_arealand/100000;
  mark ch_cntrls;
  markout ch_cntrls
          $ch_ind $ch_ma $ch_dist $ch_div ch_choice;
  gen samp_8r=1   if byqwt>0 & ch_cntrls==1 & pubschby==1 & by2xrstd<. & ch_nstreams_lg<. & ch_nstreams_sm<.;
  gen samp_12r=1  if f2qwt>0 & ch_cntrls==1 & pubschf2==1 & f22xrstd<. & ch_nstreams_lg<. & ch_nstreams_sm<.;
  egen totwgt_8r  =sum(byqwt) if samp_8r  ==1, by(fipsmsa);
  egen totwgt_12r =sum(f2qwt) if samp_12r ==1, by(fipsmsa);
  gen wgt_8r  =byqwt/totwgt_8r   if samp_8r  ==1;
  gen wgt_12r =f2qwt/totwgt_12r  if samp_12r ==1;
  *Start with 8th grade sample;
   regress ch_choice $ch_ind $ch_ma $ch_dist $ch_div ch_nstreams_sm ch_nstreams_lg [aw=wgt_8r] if samp_8r;
   test ch_nstreams_sm ch_nstreams_lg;
   local fstat=r(F);
   local pval=r(p);
   outreg using tab2.txt, ctitle("CH_ind8_classical") bdec(8) rdec(8) adec(8) se noparen noaster addstat("F", `fstat', "p", `pval') append;
   regress ch_choice $ch_ind $ch_ma $ch_dist $ch_div ch_nstreams_sm ch_nstreams_lg [aw=wgt_8r] if samp_8r, cluster(fipsmsa);
   test ch_nstreams_sm ch_nstreams_lg;
   local fstat=r(F);
   local pval=r(p);
   outreg using tab2.txt, ctitle("CH_ind8_cluster") bdec(8) rdec(8) adec(8) se noparen noaster addstat("F", `fstat', "p", `pval') append;
   olserrcomp ch_choice $ch_ind $ch_ma $ch_dist $ch_div ch_nstreams_sm ch_nstreams_lg [aw=wgt_8r] if samp_8r, groups(fipsmsa leaid);
   test ch_nstreams_sm ch_nstreams_lg;
   local chi2=r(chi2);
   local pval=r(p);
   outreg using tab2.txt, ctitle("CH_ind8_moulton") bdec(8) rdec(8) adec(8) se noparen noaster addstat("chi2", `chi2', "p", `pval') append;
  *Now 12th grade sample;
   regress ch_choice $ch_ind $ch_ma $ch_dist $ch_div ch_nstreams_sm ch_nstreams_lg [aw=wgt_12r] if samp_12r;
   test ch_nstreams_sm ch_nstreams_lg;
   local fstat=r(F);
   local pval=r(p);
   outreg using tab2.txt, ctitle("CH_ind12_classical") bdec(8) rdec(8) adec(8) se noparen noaster addstat("F", `fstat', "p", `pval') append;
   regress ch_choice $ch_ind $ch_ma $ch_dist $ch_div ch_nstreams_sm ch_nstreams_lg [aw=wgt_12r] if samp_12r, cluster(fipsmsa);
   test ch_nstreams_sm ch_nstreams_lg;
   local fstat=r(F);
   local pval=r(p);
   outreg using tab2.txt, ctitle("CH_ind12_cluster") bdec(8) rdec(8) adec(8) se noparen noaster addstat("F", `fstat', "p", `pval') append;
   olserrcomp ch_choice $ch_ind $ch_ma $ch_dist $ch_div ch_nstreams_sm ch_nstreams_lg [aw=wgt_12r] if samp_12r, groups(fipsmsa leaid);
   test ch_nstreams_sm ch_nstreams_lg;
   local chi2=r(chi2);
   local pval=r(p);
   outreg using tab2.txt, ctitle("CH_ind12_moulton") bdec(8) rdec(8) adec(8) se noparen noaster addstat("chi2", `chi2', "p", `pval') append;

*And using preferred construction;
 use ${mywork_public}/msadata.dta, clear;
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 regress jr_choice ch_nstreams_sm ch_nstreams_lg m_pop_n m_arealand m_lnmeanincA jr_m_gini
                   jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn
                   m_ed_scol m_ed_ba m_herfed jr_m_divis1 jr_m_divis2 jr_m_divis3
                   jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 jr_m_divis9;
 test ch_nstreams_sm ch_nstreams_lg;
 local fstat=r(F);
 local pval=r(p);
 outreg using tab2.txt, ctitle("JR_MSA") bdec(8) rdec(8) adec(8) se noparen noaster append addstat("F", `fstat', "p", `pval');
 *And at the individual level;
  *Start with 8th grade sample;
   use ${mywork_confidential}/jrAbysample.dta, clear;
   global jr_ind "jr_lnfaminc jr_asian jr_hispanic jr_black jr_female jr_parcolg jr_parscol";
   global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
   global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
   global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
   replace m_pop_n=m_pop_n/10000000;
   replace m_arealand=m_arealand/100000;
   mark jr_cntrls;
   markout jr_cntrls
           $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
   gen samp_8r=1   if byqwt>0 & jr_cntrls==1 & pubschby==1 & by2xrstd<. & ch_nstreams_lg<. & ch_nstreams_sm<.;
   egen totwgt_8r  =sum(byqwt) if samp_8r  ==1, by(fipsmsa);
   gen wgt_8r  =byqwt/totwgt_8r   if samp_8r  ==1;
   regress jr_choice $jr_ind $jr_ma $jr_dist $jr_div ch_nstreams_sm ch_nstreams_lg [aw=wgt_8r] if samp_8r;
   test ch_nstreams_sm ch_nstreams_lg;
   local fstat=r(F);
   local pval=r(p);
   outreg using tab2.txt, ctitle("JR_ind8_classical") bdec(8) rdec(8) adec(8) se noparen noaster addstat("F", `fstat', "p", `pval') append;
   regress jr_choice $jr_ind $jr_ma $jr_dist $jr_div ch_nstreams_sm ch_nstreams_lg [aw=wgt_8r] if samp_8r, cluster(fipsmsa);
   test ch_nstreams_sm ch_nstreams_lg;
   local fstat=r(F);
   local pval=r(p);
   outreg using tab2.txt, ctitle("JR_ind8_cluster") bdec(8) rdec(8) adec(8) se noparen noaster addstat("F", `fstat', "p", `pval') append;
   olserrcomp jr_choice $jr_ind $jr_ma $jr_dist $jr_div ch_nstreams_sm ch_nstreams_lg [aw=wgt_8r] if samp_8r, groups(fipsmsa leaid);
   test ch_nstreams_sm ch_nstreams_lg;
   local chi2=r(chi2);
   local pval=r(p);
   outreg using tab2.txt, ctitle("JR_ind8_moulton") bdec(8) rdec(8) adec(8) se noparen noaster addstat("chi2", `chi2', "p", `pval') append;
  *Now 12th grade sample;
   use ${mywork_confidential}/jrAf2sample.dta, clear;
   global jr_ind "jr_lnfaminc jr_asian jr_hispanic jr_black jr_female jr_parcolg jr_parscol";
   global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
   global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
   global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
   replace m_pop_n=m_pop_n/10000000;
   replace m_arealand=m_arealand/100000;
   mark jr_cntrls;
   markout jr_cntrls
           $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
   gen samp_12r=1   if f2qwt>0 & jr_cntrls==1 & pubschf2==1 & f22xrstd<. & ch_nstreams_lg<. & ch_nstreams_sm<.;
   egen totwgt_12r  =sum(f2qwt) if samp_12r  ==1, by(fipsmsa);
   gen wgt_12r  =f2qwt/totwgt_12r   if samp_12r  ==1;
   regress jr_choice $jr_ind $jr_ma $jr_dist $jr_div ch_nstreams_sm ch_nstreams_lg [aw=wgt_12r] if samp_12r;
   test ch_nstreams_sm ch_nstreams_lg;
   local fstat=r(F);
   local pval=r(p);
   outreg using tab2.txt, ctitle("JR_ind12_classical") bdec(8) rdec(8) adec(8) se noparen noaster addstat("F", `fstat', "p", `pval') append;
   regress jr_choice $jr_ind $jr_ma $jr_dist $jr_div ch_nstreams_sm ch_nstreams_lg [aw=wgt_12r] if samp_12r, cluster(fipsmsa);
   test ch_nstreams_sm ch_nstreams_lg;
   local fstat=r(F);
   local pval=r(p);
   outreg using tab2.txt, ctitle("JR_ind12_cluster") bdec(8) rdec(8) adec(8) se noparen noaster addstat("F", `fstat', "p", `pval') append;
   olserrcomp jr_choice $jr_ind $jr_ma $jr_dist $jr_div ch_nstreams_sm ch_nstreams_lg [aw=wgt_12r] if samp_12r, groups(fipsmsa leaid);
   test ch_nstreams_sm ch_nstreams_lg;
   local chi2=r(chi2);
   local pval=r(p);
   outreg using tab2.txt, ctitle("JR_ind12_moulton") bdec(8) rdec(8) adec(8) se noparen noaster addstat("chi2", `chi2', "p", `pval') append;

log close;
