capture log close
log using tab3.smcl, replace

*First stage models using alternative instruments;

#delimit;
version 8.0;
pause off;
set more off;
query;
creturn list;
clear;
set mem 64m;
set matsize 800;

do "../definedirs.do";
quietly do "moultonprog.do";


capture program drop oneset;
program define oneset;
 syntax varlist using [fw pw aw],
          data1(string) data2(string) data3(string) choicevar(name)
          stub(name) title(name) [append replace];
 *Program to run first-stage regression at MSA level and at individual level;
 *Start with MSA-level;
  use "`data1'", clear;
  reg `choicevar' `varlist' ${`stub'_ma} ${`stub'_madiv};
  test `varlist';
  local fstat=r(F);
  local pval=r(p);
  outreg using tab3.txt, ctitle(`title'_MSA) bdec(8) rdec(8) adec(8) se noparen noaster addstat("F", `fstat', "p", `pval')
          `append' `replace';
 *Now individual level, for 8th grade scores;
  use "`data2'", clear;
  *Classical SEs;
   reg `choicevar' `varlist' ${`stub'_ind} ${`stub'_ma} ${`stub'_dist} ${`stub'_div} [`weight'`exp'];
   test `varlist';
   local fstat=r(F);
   local pval=r(p);
   outreg using tab3.txt, ctitle(`title'_ind8_classical) bdec(8) rdec(8) adec(8) se noparen noaster append
                          addstat("F", `fstat', "p", `pval') ;
  *Cluster SEs;
   reg `choicevar' `varlist' ${`stub'_ind} ${`stub'_ma} ${`stub'_dist} ${`stub'_div} [`weight'`exp'],
         cluster(fipsmsa);
   test `varlist';
   local fstat=r(F);
   local pval=r(p);
   outreg using tab3.txt, ctitle(`title'_ind8_cluster) bdec(8) rdec(8) adec(8) se noparen noaster append
                          addstat("F", `fstat', "p", `pval') ;
  *Moulton SEs;
   olserrcomp `choicevar' `varlist' ${`stub'_ind} ${`stub'_ma} ${`stub'_dist} ${`stub'_div} [`weight'`exp'],
              groups(fipsmsa);
   test `varlist';
   local chi2=r(chi2);
   local pval=r(p);
   outreg using tab3.txt, ctitle(`title'_ind8_moulton) bdec(8) rdec(8) adec(8) se noparen noaster append
                          addstat("chi2", `chi2', "p", `pval') ;
 *And individual level, for 12th grade scores;
  use "`data3'", clear;
  *Classical SEs;
   reg `choicevar' `varlist' ${`stub'_ind} ${`stub'_ma} ${`stub'_dist} ${`stub'_div} [`weight'`exp'];
   test `varlist';
   local fstat=r(F);
   local pval=r(p);
   outreg using tab3.txt, ctitle(`title'_ind12_classical) bdec(8) rdec(8) adec(8) se noparen noaster append
                          addstat("F", `fstat', "p", `pval');
  *Cluster SEs;
   reg `choicevar' `varlist' ${`stub'_ind} ${`stub'_ma} ${`stub'_dist} ${`stub'_div} [`weight'`exp'],
         cluster(fipsmsa);
   test `varlist';
   local fstat=r(F);
   local pval=r(p);
   outreg using tab3.txt, ctitle(`title'_ind12_cluster) bdec(8) rdec(8) adec(8) se noparen noaster append
                          addstat("F", `fstat', "p", `pval') ;
  *Moulton SEs;
   olserrcomp `choicevar' `varlist' ${`stub'_ind} ${`stub'_ma} ${`stub'_dist} ${`stub'_div} [`weight'`exp'],
              groups(fipsmsa);
   test `varlist';
   local chi2=r(chi2);
   local pval=r(p);
   outreg using tab3.txt, ctitle(`title'_ind12_moulton) bdec(8) rdec(8) adec(8) se noparen noaster append
                          addstat("chi2", `chi2', "p", `pval') ;
end;

*Start with close replication sample;
 *Prepare the data;
  use ${mywork_confidential}/chsample.dta, clear;
  gen jr_nstreamsB_sm=jr_nstreamsB_tot-ch_nstreams_lg;
  global ch_ind "ch_lnfaminc ch_asian ch_hispanic ch_black ch_female ch_parcolg ch_parscol";
  global ch_ma "m_pop_n m_arealand ch_m_avglnmeaninc ch_m_gini ch_m_pop_fas ch_m_pop_fbl ch_m_pop_fhi ch_m_herfrace ch_m_herfethn m_ed_scol m_ed_ba m_herfed";
  global ch_dist "d_lnmeanincA ch_d_gini ch_d_pop_fas ch_d_pop_fbl ch_d_pop_fhi ch_d_herfrace ch_d_herfethn d_ed_scol d_ed_ba d_herfed";
  global ch_div "ch_d_div1 ch_d_div2 ch_d_div3 ch_d_div4 ch_d_div5 ch_d_div6 ch_d_div7 ch_d_div8";
  global ch_madiv "ch_m_divis1 ch_m_divis2 ch_m_divis3 ch_m_divis4 ch_m_divis5 ch_m_divis6 ch_m_divis7 ch_m_divis8";
  replace m_pop_n=m_pop_n/10000000;
  replace m_arealand=m_arealand/100000;
  mark ch_cntrls;
  markout ch_cntrls
          $ch_ind $ch_ma $ch_dist $ch_div ch_choice;
  gen ivsampA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
  gen ivsampB=1 if ch_nstreams_tot<.;
  gen ivsampC=1 if ch_nstreams_lg<. & jr_nstreamsB_sm<.;
  gen ivsampD=1 if jr_nstreamsB_tot<.;
  gen ivsampE=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
  gen ivsampF=1 if jr_nstreamsB_long<. & jr_nstreamsB_short<.;
  foreach l in A B C D E F {;
   gen samp_8r_`l'=1 if byqwt>0 & ch_cntrls==1 & pubschby==1 & by2xrstd<. & ivsamp`l'==1;
   egen totwgt_8r_`l'=sum(byqwt) if samp_8r_`l'==1, by(fipsmsa);
   gen wgt_8r_`l'=byqwt/totwgt_8r_`l' if samp_8r_`l'==1;
   gen samp_12r_`l'=1 if f2qwt>0 & ch_cntrls==1 & pubschf2==1 & f22xrstd<. & ivsamp`l'==1;
   egen totwgt_12r_`l'=sum(f2qwt) if samp_12r_`l'==1, by(fipsmsa);
   gen wgt_12r_`l'=f2qwt/totwgt_12r_`l' if samp_12r_`l'==1;
  };
  tempfile chdata chsamp8 chsamp12;
  save `chdata';
  foreach l in A B C D E F {;
   rename wgt_8r_`l' wgt_`l';
   };
  save `chsamp8';
  use `chdata';
  foreach l in A B C D E F {;
   rename wgt_12r_`l' wgt_`l';
   };
  save `chsamp12';
 use ${mywork_public}/msadata.dta;
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 tempfile madata;
 gen jr_nstreamsB_sm=jr_nstreamsB_tot-ch_nstreams_lg;
 save `madata';
 use `chsamp12';
 *Hoxby streams variables;
  oneset ch_nstreams_sm ch_nstreams_lg using tab3.txt [aw=wgt_A],
         data1("`madata'") data2("`chsamp8'") data3("`chsamp12'")
         choicevar(ch_choice) stub(ch) title(CHA) replace;
 *Hoxby total streams;
  oneset ch_nstreams_tot using tab3.txt [aw=wgt_B],
         data1("`madata'") data2("`chsamp8'") data3("`chsamp12'")
         choicevar(ch_choice) stub(ch) title(CHB) append;
 *JR streams variables;
  oneset ch_nstreams_lg jr_nstreamsB_sm using tab3.txt [aw=wgt_C],
         data1("`madata'") data2("`chsamp8'") data3("`chsamp12'")
         choicevar(ch_choice) stub(ch) title(CHC) append;
 *JR total streams;
  oneset jr_nstreamsB_tot using tab3.txt [aw=wgt_D],
         data1("`madata'") data2("`chsamp8'") data3("`chsamp12'")
         choicevar(ch_choice) stub(ch) title(CHD) append;
 *JR inter- and intra-county streams;
  oneset jr_nstreamsB_inter jr_nstreamsB_intra using tab3.txt [aw=wgt_E],
         data1("`madata'") data2("`chsamp8'") data3("`chsamp12'")
         choicevar(ch_choice) stub(ch) title(CHE) append;
 *JR long and short streams;
  oneset jr_nstreamsB_long jr_nstreamsB_short using tab3.txt [aw=wgt_F],
         data1("`madata'") data2("`chsamp8'") data3("`chsamp12'")
         choicevar(ch_choice) stub(ch) title(CHF) append;


*Again with preferred replication sample;
 *Prepare the data;
  tempfile jrsamp8 jrsamp12 jrmadata;
  use ${mywork_confidential}/jrAbysample.dta, clear;
  gen jr_nstreamsB_sm=jr_nstreamsB_tot-ch_nstreams_lg;
  replace m_pop_n=m_pop_n/10000000;
  replace m_arealand=m_arealand/100000;
  global jr_ind "jr_lnfaminc jr_asian jr_hispanic jr_black jr_female jr_parcolg jr_parscol";
  global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
  global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
  global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
  global jr_madiv "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
  mark jr_cntrls;
  markout jr_cntrls
          $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
  gen ivsampA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
  gen ivsampB=1 if ch_nstreams_tot<.;
  gen ivsampC=1 if ch_nstreams_lg<. & jr_nstreamsB_sm<.;
  gen ivsampD=1 if jr_nstreamsB_tot<.;
  gen ivsampE=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
  gen ivsampF=1 if jr_nstreamsB_long<. & jr_nstreamsB_short<.;
  foreach l in A B C D E F {;
   gen samp_8r_`l'=1 if byqwt>0 & jr_cntrls==1 & pubschby==1 & by2xrstd<. & ivsamp`l'==1;
   egen totwgt_8r_`l'=sum(byqwt) if samp_8r_`l'==1, by(fipsmsa);
   gen wgt_`l'=byqwt/totwgt_8r_`l' if samp_8r_`l'==1;
  };
  save `jrsamp8';
  use ${mywork_confidential}/jrAf2sample.dta, clear;
  gen jr_nstreamsB_sm=jr_nstreamsB_tot-ch_nstreams_lg;
  replace m_pop_n=m_pop_n/10000000;
  replace m_arealand=m_arealand/100000;
  mark jr_cntrls;
  markout jr_cntrls
          $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
  gen ivsampA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
  gen ivsampB=1 if ch_nstreams_tot<.;
  gen ivsampC=1 if ch_nstreams_lg<. & jr_nstreamsB_sm<.;
  gen ivsampD=1 if jr_nstreamsB_tot<.;
  gen ivsampE=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
  gen ivsampF=1 if jr_nstreamsB_long<. & jr_nstreamsB_short<.;
  foreach l in A B C D E F {;
   gen samp_12r_`l'=1 if f2qwt>0 & jr_cntrls==1 & pubschf2==1 & f22xrstd<. & ivsamp`l'==1;
   egen totwgt_12r_`l'=sum(f2qwt) if samp_12r_`l'==1, by(fipsmsa);
   gen wgt_`l'=f2qwt/totwgt_12r_`l' if samp_12r_`l'==1;
  };
  save `jrsamp12';
 use `jrsamp8';
 *Hoxby streams variables;
  oneset ch_nstreams_sm ch_nstreams_lg using tab3.txt [aw=wgt_A],
         data1("`madata'") data2("`jrsamp8'") data3("`jrsamp12'")
         choicevar(jr_choice) stub(jr) title(JRA) append;
 *Hoxby total streams;
  oneset ch_nstreams_tot using tab3.txt [aw=wgt_B],
         data1("`madata'") data2("`jrsamp8'") data3("`jrsamp12'")
         choicevar(jr_choice) stub(jr) title(JRB) append;
 *JR streams variables;
  oneset ch_nstreams_lg jr_nstreamsB_sm using tab3.txt [aw=wgt_C],
         data1("`madata'") data2("`jrsamp8'") data3("`jrsamp12'")
         choicevar(jr_choice) stub(jr) title(JRC) append;
 *JR total streams;
  oneset jr_nstreamsB_tot using tab3.txt [aw=wgt_D],
         data1("`madata'") data2("`jrsamp8'") data3("`jrsamp12'")
         choicevar(jr_choice) stub(jr) title(JRD) append;
 *JR inter- and intra-county streams;
  oneset jr_nstreamsB_inter jr_nstreamsB_intra using tab3.txt [aw=wgt_E],
         data1("`madata'") data2("`jrsamp8'") data3("`jrsamp12'")
         choicevar(jr_choice) stub(jr) title(JRE) append;
 *JR long and short streams;
  oneset jr_nstreamsB_long jr_nstreamsB_short using tab3.txt [aw=wgt_F],
         data1("`madata'") data2("`jrsamp8'") data3("`jrsamp12'")
         choicevar(jr_choice) stub(jr) title(JRF) append;

log close;