capture log close
log using tab4.smcl, replace

*Program to explore sensitivity to instrument choice;

#delimit;
version 8.0;
pause off;
set more off;
query;
creturn list;
clear;
set mem 64m;
set matsize 800;

do "../definedirs.do";
quietly do "moultonprog.do";

capture program drop onereg;
program define onereg, eclass;
 syntax varlist [if] [in] [using] [fw pw aw],
                depvar(varname numeric) endog(varname numeric) instrum(varlist numeric)
                [cluster(varname) moulton(varlist min=1 max=2) outreg *];
 *Program to run a single IV regression and compute exogeneity test,
 *with classical, clustered, or Moulton SEs;

 *Start by computing the sample;
  marksample samp;
  markout `samp' `depvar' `endog' `instrum';
 *Estimate first stage;
  quietly reg `endog' `instrum' `varlist' if `samp' [`weight'`exp'];
  tempvar xhat;
  predict `xhat', xb;

 tempname mainmod;
 *Begin with classical case;
  if "`cluster'"=="" & "`moulton'"=="" {;
   *Run exog test;
    quietly reg `depvar' `endog' `varlist' `xhat' if `samp' [`weight'`exp'];
    quietly test `xhat';
    local p_exog=r(p);
   *Run overid test;
    ivreg `depvar' `varlist' (`endog'=`instrum') if `samp' [`weight'`exp'];
    tempvar ivresid;
    predict `ivresid', residuals;
    _estimates hold `mainmod';
    if wordcount("`instrum'")>1 {;
     quietly reg `ivresid' `varlist' `instrum' if `samp' [`weight'`exp'];
     local p_overid=chi2(wordcount("`instrum'")-1, e(N)*e(r2));
     };
    else {;
     local p_overid=-1;
     };
   _estimates unhold `mainmod';
   if "`outreg'"=="outreg" {;
    outreg `using', `options' bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Exog. p", `p_exog', "Overid p", `p_overid', "Error type", 0);
    };
   };
 *Now clustered;
  if "`cluster'"~="" {;
   *Run exog test;
    quietly reg `depvar' `endog' `varlist' `xhat' if `samp' [`weight'`exp'], cluster(`cluster');
    quietly test `xhat';
    local p_exog=r(p);
   *Run IV model;
    local p_overid=-1;
    ivreg `depvar' `varlist' (`endog'=`instrum') if `samp' [`weight'`exp'], cluster(`cluster');
    local nclust=e(df_r)+1;
   if "`outreg'"=="outreg" {;
    outreg `using', `options' bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Exog. p", `p_exog', "Overid p", `p_overid', "Error type", 1,
                             "#cluster", `nclust');
    };
   };
 *And finally Moulton;
  if "`moulton'"~="" {;
   *Run exog test;
    quietly olserrcomp `depvar' `endog' `varlist' `xhat' if `samp' [`weight'`exp'], groups(`moulton');
    quietly test `xhat';
    local p_exog=r(p);
   *Run IV model;
    local p_overid=-1;
    iverrcomp `depvar' `varlist' (`endog'=`instrum') if `samp' [`weight'`exp'], groups(`moulton');
    local ngroups=e(N_g2);
    local nsubgroups=e(N_g1);
    local sd_ind=e(sigma_0);
    local sd_gp=e(sigma_2);
    local sd_subgp=e(sigma_1);
   if "`outreg'"=="outreg" {;
    outreg `using', `options' bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Exog. p", `p_exog', "Overid p", `p_overid', "Error type", 2,
                             "#Groups", `ngroups', "#Subgroups", `nsubgroups',
                             "SDind", `sd_ind', "SDsubgp", `sd_subgp', "SDgroup", `sd_gp');
    };
   };
end;

local ivA "ch_nstreams_lg ch_nstreams_sm";
local ivB "ch_nstreams_tot";
local ivC "ch_nstreams_lg jr_nstreamsB_sm";
local ivD "jr_nstreamsB_tot";
local ivE "jr_nstreamsB_inter jr_nstreamsB_intra";
local ivF "jr_nstreamsB_long jr_nstreamsB_short";

*Close replication sample.  Restandardize weights separately for each model;
 use ${mywork_confidential}/chsample.dta, clear;
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 gen jr_nstreamsB_sm=jr_nstreamsB_tot-ch_nstreams_lg;
 global ch_ind "ch_lnfaminc ch_asian ch_hispanic ch_black ch_female ch_parcolg ch_parscol";
 global ch_ma "m_pop_n m_arealand ch_m_avglnmeaninc ch_m_gini ch_m_pop_fas ch_m_pop_fbl ch_m_pop_fhi ch_m_herfrace ch_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global ch_dist "d_lnmeanincA ch_d_gini ch_d_pop_fas ch_d_pop_fbl ch_d_pop_fhi ch_d_herfrace ch_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global ch_div "ch_d_div1 ch_d_div2 ch_d_div3 ch_d_div4 ch_d_div5 ch_d_div6 ch_d_div7 ch_d_div8";
 mark ch_cntrls;
 markout ch_cntrls
         $ch_ind $ch_ma $ch_dist $ch_div ch_choice;
 gen ivsampA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
 gen ivsampB=1 if ch_nstreams_tot<.;
 gen ivsampC=1 if ch_nstreams_lg<. & jr_nstreamsB_sm<.;
 gen ivsampD=1 if jr_nstreamsB_tot<.;
 gen ivsampE=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
 gen ivsampF=1 if jr_nstreamsB_long<. & jr_nstreamsB_short<.;
 gen samp_8r_ols=1 if byqwt>0 & ch_cntrls==1 & pubschby==1 & by2xrstd<.;
 egen totwgt_8r_ols=sum(byqwt) if samp_8r_ols==1, by(fipsmsa);
 gen wgt_8r_ols=byqwt/totwgt_8r_ols if samp_8r_ols==1;
 gen samp_12r_ols=1 if f2qwt>0 & ch_cntrls==1 & pubschf2==1 & f22xrstd<.;
 egen totwgt_12r_ols=sum(f2qwt) if samp_12r_ols==1, by(fipsmsa);
 gen wgt_12r_ols=f2qwt/totwgt_12r_ols if samp_12r_ols==1;
 foreach l in A B C D E F {;
  gen samp_8r_`l'=1 if samp_8r_ols==1 & ivsamp`l'==1;
  egen totwgt_8r_`l'=sum(byqwt) if samp_8r_`l'==1, by(fipsmsa);
  gen wgt_8r_`l'=byqwt/totwgt_8r_`l' if samp_8r_`l'==1;
  gen samp_12r_`l'=1 if samp_12r_ols==1 & ivsamp`l'==1;
  egen totwgt_12r_`l'=sum(f2qwt) if samp_12r_`l'==1, by(fipsmsa);
  gen wgt_12r_`l'=f2qwt/totwgt_12r_`l' if samp_12r_`l'==1;
 };
 *Start with 8th grade scores;
  *OLS;
   reg by2xrstd ch_choice $ch_ind $ch_ma $ch_dist $ch_div [aw=wgt_8r_ols];
    outreg using "tab4.txt", replace bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Error type", 0) ctitle("CH_8r_OLS_classical");
   reg by2xrstd ch_choice $ch_ind $ch_ma $ch_dist $ch_div [aw=wgt_8r_ols], cluster(fipsmsa);
    local nclust=e(df_r)+1;
    outreg using "tab4.txt", append bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Error type", 1, "#cluster", `nclust') ctitle("CH_8r_OLS_cluster");
   olserrcomp by2xrstd ch_choice $ch_ind $ch_ma $ch_dist $ch_div [aw=wgt_8r_ols], groups(fipsmsa leaid);
    local ngroups=e(N_g2);
    local nsubgroups=e(N_g1);
    local sd_ind=e(sigma_0);
    local sd_gp=e(sigma_2);
    local sd_subgp=e(sigma_1);
    outreg using "tab4.txt", append bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Error type", 2, "#Groups", `ngroups', "#Subgroups", `nsubgroups',
                             "SDind", `sd_ind', "SDsubgp", `sd_subgp', "SDgroup", `sd_gp')
                     ctitle("CH_8r_OLS_moulton");
 foreach l in A B C D E F {;
  onereg $ch_ind $ch_ma $ch_dist $ch_div using "tab4.txt" [aw=wgt_8r_`l'],
         depvar(by2xrstd) endog(ch_choice) instrum(`iv`l'')
         outreg append ctitle("CH_8r_`l'_classical");
  onereg $ch_ind $ch_ma $ch_dist $ch_div using "tab4.txt" [aw=wgt_8r_`l'],
         depvar(by2xrstd) endog(ch_choice) instrum(`iv`l'')
         cluster(fipsmsa) outreg append ctitle("CH_8r_`l'_cluster");
  onereg $ch_ind $ch_ma $ch_dist $ch_div using "tab4.txt" [aw=wgt_8r_`l'],
         depvar(by2xrstd) endog(ch_choice) instrum(`iv`l'')
         moulton(fipsmsa leaid) outreg append ctitle("CH_8r_`l'_moulton");
  };
 *Now 12th grade scores;
  *OLS;
   reg f22xrstd ch_choice $ch_ind $ch_ma $ch_dist $ch_div [aw=wgt_12r_ols];
    outreg using "tab4.txt", append bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Error type", 0) ctitle("CH_12r_OLS_classical");
   reg f22xrstd ch_choice $ch_ind $ch_ma $ch_dist $ch_div [aw=wgt_12r_ols], cluster(fipsmsa);
    local nclust=e(df_r)+1;
    outreg using "tab4.txt", append bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Error type", 1, "#cluster", `nclust') ctitle("CH_12r_OLS_cluster");
   olserrcomp f22xrstd ch_choice $ch_ind $ch_ma $ch_dist $ch_div [aw=wgt_12r_ols], groups(fipsmsa leaid);
    local ngroups=e(N_g2);
    local nsubgroups=e(N_g1);
    local sd_ind=e(sigma_0);
    local sd_gp=e(sigma_2);
    local sd_subgp=e(sigma_1);
    outreg using "tab4.txt", append bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Error type", 2, "#Groups", `ngroups', "#Subgroups", `nsubgroups',
                             "SDind", `sd_ind', "SDsubgp", `sd_subgp', "SDgroup", `sd_gp')
                     ctitle("CH_12r_OLS_moulton");
 foreach l in A B C D E F {;
  onereg $ch_ind $ch_ma $ch_dist $ch_div using "tab4.txt" [aw=wgt_12r_`l'],
         depvar(f22xrstd) endog(ch_choice) instrum(`iv`l'')
         outreg append ctitle("CH_12r_`l'_classical");
  onereg $ch_ind $ch_ma $ch_dist $ch_div using "tab4.txt" [aw=wgt_12r_`l'],
         depvar(f22xrstd) endog(ch_choice) instrum(`iv`l'')
         cluster(fipsmsa) outreg append ctitle("CH_12r_`l'_cluster");
  onereg $ch_ind $ch_ma $ch_dist $ch_div using "tab4.txt" [aw=wgt_12r_`l'],
         depvar(f22xrstd) endog(ch_choice) instrum(`iv`l'')
         moulton(fipsmsa leaid) outreg append ctitle("CH_12r_`l'_moulton");
  };

*Preferred replication sample.  Restandardize weights separately for each model;
 use ${mywork_confidential}/jrAbysample.dta, clear;
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 gen jr_nstreamsB_sm=jr_nstreamsB_tot-ch_nstreams_lg;
 global jr_ind "jr_lnfaminc jr_asian jr_hispanic jr_black jr_female jr_parcolg jr_parscol";
 global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
 mark jr_cntrls;
 markout jr_cntrls
         $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
 gen ivsampA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
 gen ivsampB=1 if ch_nstreams_tot<.;
 gen ivsampC=1 if ch_nstreams_lg<. & jr_nstreamsB_sm<.;
 gen ivsampD=1 if jr_nstreamsB_tot<.;
 gen ivsampE=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
 gen ivsampF=1 if jr_nstreamsB_long<. & jr_nstreamsB_short<.;
 gen samp_8r_ols=1 if byqwt>0 & jr_cntrls==1 & pubschby==1 & by2xrstd<.;
 egen totwgt_8r_ols=sum(byqwt) if samp_8r_ols==1, by(fipsmsa);
 gen wgt_8r_ols=byqwt/totwgt_8r_ols if samp_8r_ols==1;
 foreach l in A B C D E F {;
  gen samp_8r_`l'=1 if samp_8r_ols==1 & ivsamp`l'==1;
  egen totwgt_8r_`l'=sum(byqwt) if samp_8r_`l'==1, by(fipsmsa);
  gen wgt_8r_`l'=byqwt/totwgt_8r_`l' if samp_8r_`l'==1;
 };
 *Start with 8th grade scores;
  *OLS;
   reg by2xrstd jr_choice $jr_ind $jr_ma $jr_dist $jr_div [aw=wgt_8r_ols];
    outreg using "tab4.txt", append bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Error type", 0) ctitle("JR_8r_OLS_classical");
   reg by2xrstd jr_choice $jr_ind $jr_ma $jr_dist $jr_div [aw=wgt_8r_ols], cluster(fipsmsa);
    local nclust=e(df_r)+1;
    outreg using "tab4.txt", append bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Error type", 1, "#cluster", `nclust') ctitle("JR_8r_OLS_cluster");
   olserrcomp by2xrstd jr_choice $jr_ind $jr_ma $jr_dist $jr_div [aw=wgt_8r_ols], groups(fipsmsa leaid);
    local ngroups=e(N_g2);
    local nsubgroups=e(N_g1);
    local sd_ind=e(sigma_0);
    local sd_gp=e(sigma_2);
    local sd_subgp=e(sigma_1);
    outreg using "tab4.txt", append bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Error type", 2, "#Groups", `ngroups', "#Subgroups", `nsubgroups',
                             "SDind", `sd_ind', "SDsubgp", `sd_subgp', "SDgroup", `sd_gp')
                     ctitle("JR_8r_OLS_moulton");
 foreach l in A B C D E F {;
  onereg $jr_ind $jr_ma $jr_dist $jr_div using "tab4.txt" [aw=wgt_8r_`l'],
         depvar(by2xrstd) endog(jr_choice) instrum(`iv`l'')
         outreg append ctitle("JR_8r_`l'_classical");
  onereg $jr_ind $jr_ma $jr_dist $jr_div using "tab4.txt" [aw=wgt_8r_`l'],
         depvar(by2xrstd) endog(jr_choice) instrum(`iv`l'')
         cluster(fipsmsa) outreg append ctitle("JR_8r_`l'_cluster");
  onereg $jr_ind $jr_ma $jr_dist $jr_div using "tab4.txt" [aw=wgt_8r_`l'],
         depvar(by2xrstd) endog(jr_choice) instrum(`iv`l'')
         moulton(fipsmsa leaid) outreg append ctitle("JR_8r_`l'_moulton");
  };
 *Now 12th grade scores;
 use ${mywork_confidential}/jrAf2sample.dta, clear;
 replace m_pop_n=m_pop_n/10000000;
 replace m_arealand=m_arealand/100000;
 gen jr_nstreamsB_sm=jr_nstreamsB_tot-ch_nstreams_lg;
 global jr_ind "jr_lnfaminc jr_asian jr_hispanic jr_black jr_female jr_parcolg jr_parscol";
 global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
 global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
 global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
 mark jr_cntrls;
 markout jr_cntrls
         $jr_ind $jr_ma $jr_dist $jr_div jr_choice;
 gen ivsampA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
 gen ivsampB=1 if ch_nstreams_tot<.;
 gen ivsampC=1 if ch_nstreams_lg<. & jr_nstreamsB_sm<.;
 gen ivsampD=1 if jr_nstreamsB_tot<.;
 gen ivsampE=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
 gen ivsampF=1 if jr_nstreamsB_long<. & jr_nstreamsB_short<.;
 gen samp_12r_ols=1 if f2qwt>0 & jr_cntrls==1 & pubschf2==1 & f22xrstd<.;
 egen totwgt_12r_ols=sum(f2qwt) if samp_12r_ols==1, by(fipsmsa);
 gen wgt_12r_ols=f2qwt/totwgt_12r_ols if samp_12r_ols==1;
 foreach l in A B C D E F {;
  gen samp_12r_`l'=1 if samp_12r_ols==1 & ivsamp`l'==1;
  egen totwgt_12r_`l'=sum(f2qwt) if samp_12r_`l'==1, by(fipsmsa);
  gen wgt_12r_`l'=f2qwt/totwgt_12r_`l' if samp_12r_`l'==1;
 };
  *OLS;
   reg f22xrstd jr_choice $jr_ind $jr_ma $jr_dist $jr_div [aw=wgt_12r_ols];
    outreg using "tab4.txt", append bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Error type", 0) ctitle("JR_12r_OLS_classical");
   reg f22xrstd jr_choice $jr_ind $jr_ma $jr_dist $jr_div [aw=wgt_12r_ols], cluster(fipsmsa);
    local nclust=e(df_r)+1;
    outreg using "tab4.txt", append bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Error type", 1, "#cluster", `nclust') ctitle("JR_12r_OLS_cluster");
   olserrcomp f22xrstd jr_choice $jr_ind $jr_ma $jr_dist $jr_div [aw=wgt_12r_ols], groups(fipsmsa leaid);
    local ngroups=e(N_g2);
    local nsubgroups=e(N_g1);
    local sd_ind=e(sigma_0);
    local sd_gp=e(sigma_2);
    local sd_subgp=e(sigma_1);
    outreg using "tab4.txt", append bdec(8) rdec(8) se noparen noaster nolabel
                     addstat("Error type", 2, "#Groups", `ngroups', "#Subgroups", `nsubgroups',
                             "SDind", `sd_ind', "SDsubgp", `sd_subgp', "SDgroup", `sd_gp')
                     ctitle("JR_12r_OLS_moulton");
 foreach l in A B C D E F {;
  onereg $jr_ind $jr_ma $jr_dist $jr_div using "tab4.txt" [aw=wgt_12r_`l'],
         depvar(f22xrstd) endog(jr_choice) instrum(`iv`l'')
         outreg append ctitle("JR_12r_`l'_classical");
  onereg $jr_ind $jr_ma $jr_dist $jr_div using "tab4.txt" [aw=wgt_12r_`l'],
         depvar(f22xrstd) endog(jr_choice) instrum(`iv`l'')
         cluster(fipsmsa) outreg append ctitle("JR_12r_`l'_cluster");
  onereg $jr_ind $jr_ma $jr_dist $jr_div using "tab4.txt" [aw=wgt_12r_`l'],
         depvar(f22xrstd) endog(jr_choice) instrum(`iv`l'')
         moulton(fipsmsa leaid) outreg append ctitle("JR_12r_`l'_moulton");
  };

log close;
