capture log close
log using tab5.smcl, replace

*Program to explore sensitivity to private enrollment issue;

#delimit;
version 8.0;
pause off;
set more off;
query;
creturn list;
clear;
set mem 64m;
set matsize 800;

do "../definedirs.do";
quietly do "moultonprog.do";

capture program drop onereg;
program define onereg, eclass;
 syntax varlist [if] [in] [using] [fw pw aw],
                depvar(varname numeric) endog(varname numeric) instrum(varlist numeric)
                [cluster(varname) moulton(varlist min=1 max=2) outreg *];
 *Program to run a single IV regression and compute exogeneity tests,
 *with classical, clustered, or Moulton SEs;

 *Start by computing the sample;
  marksample samp;
  markout `samp' `depvar' `endog' `instrum';
 *Estimate first stage;
  quietly reg `endog' `instrum' `varlist' if `samp' [`weight'`exp'];
  tempvar xhat;
  predict `xhat', xb;

 tempname mainmod;
 *Begin with classical case;
  if "`cluster'"=="" & "`moulton'"=="" {;
   *Run exog test;
    quietly reg `depvar' `endog' `varlist' `xhat' if `samp' [`weight'`exp'];
    quietly test `xhat';
    local p_exog=r(p);
   *Run overid test;
    ivreg `depvar' `varlist' (`endog'=`instrum') if `samp' [`weight'`exp'];
    tempvar ivresid;
    predict `ivresid', residuals;
    _estimates hold `mainmod';
    if wordcount("`instrum'")>1 {;
     quietly reg `ivresid' `varlist' `instrum' if `samp' [`weight'`exp'];
     local p_overid=chi2(wordcount("`instrum'")-1, e(N)*e(r2));
     };
    else {;
     local p_overid=-1;
     };
   _estimates unhold `mainmod';
   if "`outreg'"=="outreg" {;
    outreg `using', `options' bdec(8) rdec(8) adec(8) se noparen noaster nolabel
                     addstat("Exog. p", `p_exog', "Overid p", `p_overid', "Error type", 0);
    };
   };
 *Now clustered;
  if "`cluster'"~="" {;
   *Run exog test;
    quietly reg `depvar' `endog' `varlist' `xhat' if `samp' [`weight'`exp'], cluster(`cluster');
    quietly test `xhat';
    local p_exog=r(p);
   *Run IV model;
    local p_overid=-1;
    ivreg `depvar' `varlist' (`endog'=`instrum') if `samp' [`weight'`exp'], cluster(`cluster');
    local nclust=e(df_r)+1;
   if "`outreg'"=="outreg" {;
    outreg `using', `options' bdec(8) rdec(8) adec(8) se noparen noaster nolabel
                     addstat("Exog. p", `p_exog', "Overid p", `p_overid', "Error type", 1,
                             "#cluster", `nclust');
    };
   };
 *And finally Moulton;
  if "`moulton'"~="" {;
   *Run exog test;
    quietly olserrcomp `depvar' `endog' `varlist' `xhat' if `samp' [`weight'`exp'], groups(`moulton');
    quietly test `xhat';
    local p_exog=r(p);
   *Run IV model;
    local p_overid=-1;
    iverrcomp `depvar' `varlist' (`endog'=`instrum') if `samp' [`weight'`exp'], groups(`moulton');
    if wordcount("`moulton'")==2 {;
     local ngroups=e(N_g2);
     local nsubgroups=e(N_g1);
     local sd_ind=e(sigma_0);
     local sd_gp=e(sigma_2);
     local sd_subgp=e(sigma_1);
    };
    else {;
     local ngroups=e(N_g1);
     local sd_ind=e(sigma_0);
     local sd_gp=e(sigma_1);
     local nsubgroups=0;
     local sd_subgp=0;
    };
   if "`outreg'"=="outreg" {;
    outreg `using', `options' bdec(8) rdec(8) adec(8) se noparen noaster nolabel
                      addstat("Exog. p", `p_exog', "Overid p", `p_overid', "Error type", 2,
                             "#Groups", `ngroups', "#Subgroups", `nsubgroups',
                             "SDind", `sd_ind', "SDsubgp", `sd_subgp', "SDgroup", `sd_gp');
    };
   };
end;

global ch_ind "ch_lnfaminc ch_asian ch_hispanic ch_black ch_female ch_parcolg ch_parscol";
global ch_ma "m_pop_n m_arealand ch_m_avglnmeaninc ch_m_gini ch_m_pop_fas ch_m_pop_fbl ch_m_pop_fhi ch_m_herfrace ch_m_herfethn m_ed_scol m_ed_ba m_herfed";
global ch_dist "d_lnmeanincA ch_d_gini ch_d_pop_fas ch_d_pop_fbl ch_d_pop_fhi ch_d_herfrace ch_d_herfethn d_ed_scol d_ed_ba d_herfed";
global ch_div "ch_d_div1 ch_d_div2 ch_d_div3 ch_d_div4 ch_d_div5 ch_d_div6 ch_d_div7 ch_d_div8";
global ch_mdiv "ch_m_divis1 ch_m_divis2 ch_m_divis3 ch_m_divis4 ch_m_divis5 ch_m_divis6 ch_m_divis7 ch_m_divis8";
global jr_ind "jr_lnfaminc jr_asian jr_hispanic jr_black jr_female jr_parcolg jr_parscol";
global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";

*Start by using regular data, to test effect of dropping district covariates;
 *8th grade scores;
  *Close replication sample and covariates;
   use ${mywork_confidential}/chsample.dta, clear;
   replace m_pop_n=m_pop_n/10000000;
   replace m_arealand=m_arealand/100000;
   gen ivA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
   gen ivB=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
   mark ch8A;
   markout ch8A $ch_ind $ch_ma $ch_dist $ch_div ch_choice byqwt;
   mark ch8B;
   markout ch8B $ch_ind $ch_ma $ch_div ch_choice byqwt;
   *With district controls;
    *OLS;
     gen samp_ch8Apub_ols=1 if byqwt>0 & ch8A==1 & pubschby==1 & by2xrstd<.;
     egen totwgt_ch8Apub_ols=sum(byqwt) if samp_ch8Apub_ols==1, by(fipsmsa);
     gen wgt_ch8Apub_ols=byqwt/totwgt_ch8Apub_ols if samp_ch8Apub_ols==1;
     reg by2xrstd ch_choice $ch_ind $ch_ma $ch_dist $ch_div [aw=wgt_ch8Apub_ols];
     outreg using "tab5.txt", replace bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_8Apub_ols_classical");
     reg by2xrstd ch_choice $ch_ind $ch_ma $ch_dist $ch_div [aw=wgt_ch8Apub_ols], cluster(fipsmsa);
     local nclust=e(df_r)+1;
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_8Apub_ols_cluster")
                              addstat("nclust", `nclust') adec(8);
     *IV with Hoxby instruments;
     gen samp_ch8Apub_ivA=1 if byqwt>0 & ch8A==1 & pubschby==1 & by2xrstd<. & ivA==1;
     egen totwgt_ch8Apub_ivA=sum(byqwt) if samp_ch8Apub_ivA==1, by(fipsmsa);
     gen wgt_ch8Apub_ivA=byqwt/totwgt_ch8Apub_ivA if samp_ch8Apub_ivA==1;
     onereg $ch_ind $ch_ma $ch_dist $ch_div using "tab5.txt" [aw=wgt_ch8Apub_ivA],
            depvar(by2xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            outreg append ctitle("CH_8Apub_ivA_classical");
     onereg $ch_ind $ch_ma $ch_dist $ch_div using "tab5.txt" [aw=wgt_ch8Apub_ivA],
            depvar(by2xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            cluster(fipsmsa) outreg append ctitle("CH_8Apub_ivA_cluster");
     *IV with alternative instruments;
     gen samp_ch8Apub_ivB=1 if byqwt>0 & ch8A==1 & pubschby==1 & by2xrstd<. & ivB==1;
     egen totwgt_ch8Apub_ivB=sum(byqwt) if samp_ch8Apub_ivB==1, by(fipsmsa);
     gen wgt_ch8Apub_ivB=byqwt/totwgt_ch8Apub_ivB if samp_ch8Apub_ivB==1;
     onereg $ch_ind $ch_ma $ch_dist $ch_div using "tab5.txt" [aw=wgt_ch8Apub_ivB],
            depvar(by2xrstd) endog(ch_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            outreg append ctitle("CH_8Apub_ivB_classical");
     onereg $ch_ind $ch_ma $ch_dist $ch_div using "tab5.txt" [aw=wgt_ch8Apub_ivB],
            depvar(by2xrstd) endog(ch_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            cluster(fipsmsa) outreg append ctitle("CH_8Apub_ivB_cluster");
   *Without district controls;
    *OLS;
     gen samp_ch8Bpub_ols=1 if byqwt>0 & ch8B==1 & pubschby==1 & by2xrstd<.;
     egen totwgt_ch8Bpub_ols=sum(byqwt) if samp_ch8Bpub_ols==1, by(fipsmsa);
     gen wgt_ch8Bpub_ols=byqwt/totwgt_ch8Bpub_ols if samp_ch8Bpub_ols==1;
     reg by2xrstd ch_choice $ch_ind $ch_ma $ch_div [aw=wgt_ch8Bpub_ols];
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_8Bpub_ols_classical");
     reg by2xrstd ch_choice $ch_ind $ch_ma $ch_div [aw=wgt_ch8Bpub_ols], cluster(fipsmsa);
     local nclust=e(df_r)+1;
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_8Bpub_ols_cluster")
                              addstat("nclust", `nclust') adec(8);
     *IV with Hoxby instruments;
     gen samp_ch8Bpub_ivA=1 if byqwt>0 & ch8B==1 & pubschby==1 & by2xrstd<. & ivA==1;
     egen totwgt_ch8Bpub_ivA=sum(byqwt) if samp_ch8Bpub_ivA==1, by(fipsmsa);
     gen wgt_ch8Bpub_ivA=byqwt/totwgt_ch8Bpub_ivA if samp_ch8Bpub_ivA==1;
     onereg $ch_ind $ch_ma $ch_div using "tab5.txt" [aw=wgt_ch8Bpub_ivA],
            depvar(by2xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            outreg append ctitle("CH_8Bpub_ivA_classical");
     onereg $ch_ind $ch_ma $ch_div using "tab5.txt" [aw=wgt_ch8Bpub_ivA],
            depvar(by2xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            cluster(fipsmsa) outreg append ctitle("CH_8Bpub_ivA_cluster");
     *IV with alternative instruments;
     gen samp_ch8Bpub_ivB=1 if byqwt>0 & ch8B==1 & pubschby==1 & by2xrstd<. & ivB==1;
     egen totwgt_ch8Bpub_ivB=sum(byqwt) if samp_ch8Bpub_ivB==1, by(fipsmsa);
     gen wgt_ch8Bpub_ivB=byqwt/totwgt_ch8Bpub_ivB if samp_ch8Bpub_ivB==1;
     onereg $ch_ind $ch_ma $ch_div using "tab5.txt" [aw=wgt_ch8Bpub_ivB],
            depvar(by2xrstd) endog(ch_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            outreg append ctitle("CH_8Bpub_ivB_classical");
     onereg $ch_ind $ch_ma $ch_div using "tab5.txt" [aw=wgt_ch8Bpub_ivB],
            depvar(by2xrstd) endog(ch_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            cluster(fipsmsa) outreg append ctitle("CH_8Bpub_ivB_cluster");
  *Preferred replication sample and covariates;
   use ${mywork_confidential}/jrAbysample.dta, clear;
   replace m_pop_n=m_pop_n/10000000;
   replace m_arealand=m_arealand/100000;
   gen ivA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
   gen ivB=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
   mark jr8A;
   markout jr8A $jr_ind $jr_ma $jr_dist $jr_div jr_choice byqwt;
   mark jr8B;
   markout jr8B $jr_ind $jr_ma $jr_div jr_choice byqwt;
   *With district controls;
    *OLS;
     gen samp_jr8Apub_ols=1 if byqwt>0 & jr8A==1 & pubschby==1 & by2xrstd<.;
     egen totwgt_jr8Apub_ols=sum(byqwt) if samp_jr8Apub_ols==1, by(fipsmsa);
     gen wgt_jr8Apub_ols=byqwt/totwgt_jr8Apub_ols if samp_jr8Apub_ols==1;
     reg by2xrstd jr_choice $jr_ind $jr_ma $jr_dist $jr_div [aw=wgt_jr8Apub_ols];
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_8Apub_ols_classical");
     reg by2xrstd jr_choice $jr_ind $jr_ma $jr_dist $jr_div [aw=wgt_jr8Apub_ols], cluster(fipsmsa);
     local nclust=e(df_r)+1;
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_8Apub_ols_cluster")
                              addstat("nclust", `nclust') adec(8);
     *IV with Hoxby instruments;
     gen samp_jr8Apub_ivA=1 if byqwt>0 & jr8A==1 & pubschby==1 & by2xrstd<. & ivA==1;
     egen totwgt_jr8Apub_ivA=sum(byqwt) if samp_jr8Apub_ivA==1, by(fipsmsa);
     gen wgt_jr8Apub_ivA=byqwt/totwgt_jr8Apub_ivA if samp_jr8Apub_ivA==1;
     onereg $jr_ind $jr_ma $jr_dist $jr_div using "tab5.txt" [aw=wgt_jr8Apub_ivA],
            depvar(by2xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            outreg append ctitle("JR_8Apub_ivA_classical");
     onereg $jr_ind $jr_ma $jr_dist $jr_div using "tab5.txt" [aw=wgt_jr8Apub_ivA],
            depvar(by2xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            cluster(fipsmsa) outreg append ctitle("JR_8Apub_ivA_cluster");
     *IV with alternative instruments;
     gen samp_jr8Apub_ivB=1 if byqwt>0 & jr8A==1 & pubschby==1 & by2xrstd<. & ivB==1;
     egen totwgt_jr8Apub_ivB=sum(byqwt) if samp_jr8Apub_ivB==1, by(fipsmsa);
     gen wgt_jr8Apub_ivB=byqwt/totwgt_jr8Apub_ivB if samp_jr8Apub_ivB==1;
     onereg $jr_ind $jr_ma $jr_dist $jr_div using "tab5.txt" [aw=wgt_jr8Apub_ivB],
            depvar(by2xrstd) endog(jr_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            outreg append ctitle("JR_8Apub_ivB_classical");
     onereg $jr_ind $jr_ma $jr_dist $jr_div using "tab5.txt" [aw=wgt_jr8Apub_ivB],
            depvar(by2xrstd) endog(jr_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            cluster(fipsmsa) outreg append ctitle("JR_8Apub_ivB_cluster");
   *Without district controls;
    *OLS;
     gen samp_jr8Bpub_ols=1 if byqwt>0 & jr8B==1 & pubschby==1 & by2xrstd<.;
     egen totwgt_jr8Bpub_ols=sum(byqwt) if samp_jr8Bpub_ols==1, by(fipsmsa);
     gen wgt_jr8Bpub_ols=byqwt/totwgt_jr8Bpub_ols if samp_jr8Bpub_ols==1;
     reg by2xrstd jr_choice $jr_ind $jr_ma $jr_div [aw=wgt_jr8Bpub_ols];
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_8Bpub_ols_classical");
     reg by2xrstd jr_choice $jr_ind $jr_ma $jr_div [aw=wgt_jr8Bpub_ols], cluster(fipsmsa);
     local nclust=e(df_r)+1;
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_8Bpub_ols_cluster")
                              addstat("nclust", `nclust') adec(8);
     *IV with Hoxby instruments;
     gen samp_jr8Bpub_ivA=1 if byqwt>0 & jr8B==1 & pubschby==1 & by2xrstd<. & ivA==1;
     egen totwgt_jr8Bpub_ivA=sum(byqwt) if samp_jr8Bpub_ivA==1, by(fipsmsa);
     gen wgt_jr8Bpub_ivA=byqwt/totwgt_jr8Bpub_ivA if samp_jr8Bpub_ivA==1;
     onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr8Bpub_ivA],
            depvar(by2xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            outreg append ctitle("JR_8Bpub_ivA_classical");
     onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr8Bpub_ivA],
            depvar(by2xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            cluster(fipsmsa) outreg append ctitle("JR_8Bpub_ivA_cluster");
     *IV with alternative instruments;
     gen samp_jr8Bpub_ivB=1 if byqwt>0 & jr8B==1 & pubschby==1 & by2xrstd<. & ivB==1;
     egen totwgt_jr8Bpub_ivB=sum(byqwt) if samp_jr8Bpub_ivB==1, by(fipsmsa);
     gen wgt_jr8Bpub_ivB=byqwt/totwgt_jr8Bpub_ivB if samp_jr8Bpub_ivB==1;
     onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr8Bpub_ivB],
            depvar(by2xrstd) endog(jr_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            outreg append ctitle("JR_8Bpub_ivB_classical");
     onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr8Bpub_ivB],
            depvar(by2xrstd) endog(jr_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            cluster(fipsmsa) outreg append ctitle("JR_8Bpub_ivB_cluster");

 *12th grade scores;
  *Close replication sample and covariates;
   use ${mywork_confidential}/chsample.dta, clear;
   replace m_pop_n=m_pop_n/10000000;
   replace m_arealand=m_arealand/100000;
   gen ivA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
   gen ivB=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
   mark ch12A;
   markout ch12A $ch_ind $ch_ma $ch_dist $ch_div ch_choice f2qwt;
   mark ch12B;
   markout ch12B $ch_ind $ch_ma $ch_div ch_choice f2qwt;
   *With district controls;
    *OLS;
     gen samp_ch12Apub_ols=1 if f2qwt>0 & ch12A==1 & pubschf2==1 & f22xrstd<.;
     egen totwgt_ch12Apub_ols=sum(f2qwt) if samp_ch12Apub_ols==1, by(fipsmsa);
     gen wgt_ch12Apub_ols=f2qwt/totwgt_ch12Apub_ols if samp_ch12Apub_ols==1;
     reg f22xrstd ch_choice $ch_ind $ch_ma $ch_dist $ch_div [aw=wgt_ch12Apub_ols];
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_12Apub_ols_classical");
     reg f22xrstd ch_choice $ch_ind $ch_ma $ch_dist $ch_div [aw=wgt_ch12Apub_ols], cluster(fipsmsa);
     local nclust=e(df_r)+1;
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_12Apub_ols_cluster")
                              addstat("nclust", `nclust') adec(8);
     *IV with Hoxby instruments;
     gen samp_ch12Apub_ivA=1 if f2qwt>0 & ch12A==1 & pubschf2==1 & f22xrstd<. & ivA==1;
     egen totwgt_ch12Apub_ivA=sum(f2qwt) if samp_ch12Apub_ivA==1, by(fipsmsa);
     gen wgt_ch12Apub_ivA=f2qwt/totwgt_ch12Apub_ivA if samp_ch12Apub_ivA==1;
     onereg $ch_ind $ch_ma $ch_dist $ch_div using "tab5.txt" [aw=wgt_ch12Apub_ivA],
            depvar(f22xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            outreg append ctitle("CH_12Apub_ivA_classical");
     onereg $ch_ind $ch_ma $ch_dist $ch_div using "tab5.txt" [aw=wgt_ch12Apub_ivA],
            depvar(f22xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            cluster(fipsmsa) outreg append ctitle("CH_12Apub_ivA_cluster");
     *IV with alternative instruments;
     gen samp_ch12Apub_ivB=1 if f2qwt>0 & ch12A==1 & pubschf2==1 & f22xrstd<. & ivB==1;
     egen totwgt_ch12Apub_ivB=sum(f2qwt) if samp_ch12Apub_ivB==1, by(fipsmsa);
     gen wgt_ch12Apub_ivB=f2qwt/totwgt_ch12Apub_ivB if samp_ch12Apub_ivB==1;
     onereg $ch_ind $ch_ma $ch_dist $ch_div using "tab5.txt" [aw=wgt_ch12Apub_ivB],
            depvar(f22xrstd) endog(ch_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            outreg append ctitle("CH_12Apub_ivB_classical");
     onereg $ch_ind $ch_ma $ch_dist $ch_div using "tab5.txt" [aw=wgt_ch12Apub_ivB],
            depvar(f22xrstd) endog(ch_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            cluster(fipsmsa) outreg append ctitle("CH_12Apub_ivB_cluster");
   *Without district controls;
    *OLS;
     gen samp_ch12Bpub_ols=1 if f2qwt>0 & ch12B==1 & pubschf2==1 & f22xrstd<.;
     egen totwgt_ch12Bpub_ols=sum(f2qwt) if samp_ch12Bpub_ols==1, by(fipsmsa);
     gen wgt_ch12Bpub_ols=f2qwt/totwgt_ch12Bpub_ols if samp_ch12Bpub_ols==1;
     reg f22xrstd ch_choice $ch_ind $ch_ma $ch_div [aw=wgt_ch12Bpub_ols];
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_12Bpub_ols_classical");
     reg f22xrstd ch_choice $ch_ind $ch_ma $ch_div [aw=wgt_ch12Bpub_ols], cluster(fipsmsa);
     local nclust=e(df_r)+1;
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_12Bpub_ols_cluster")
                              addstat("nclust", `nclust') adec(8);
     *IV with Hoxby instruments;
     gen samp_ch12Bpub_ivA=1 if f2qwt>0 & ch12B==1 & pubschf2==1 & f22xrstd<. & ivA==1;
     egen totwgt_ch12Bpub_ivA=sum(f2qwt) if samp_ch12Bpub_ivA==1, by(fipsmsa);
     gen wgt_ch12Bpub_ivA=f2qwt/totwgt_ch12Bpub_ivA if samp_ch12Bpub_ivA==1;
     onereg $ch_ind $ch_ma $ch_div using "tab5.txt" [aw=wgt_ch12Bpub_ivA],
            depvar(f22xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            outreg append ctitle("CH_12Bpub_ivA_classical");
     onereg $ch_ind $ch_ma $ch_div using "tab5.txt" [aw=wgt_ch12Bpub_ivA],
            depvar(f22xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            cluster(fipsmsa) outreg append ctitle("CH_12Bpub_ivA_cluster");
     *IV with alternative instruments;
     gen samp_ch12Bpub_ivB=1 if f2qwt>0 & ch12B==1 & pubschf2==1 & f22xrstd<. & ivB==1;
     egen totwgt_ch12Bpub_ivB=sum(f2qwt) if samp_ch12Bpub_ivB==1, by(fipsmsa);
     gen wgt_ch12Bpub_ivB=f2qwt/totwgt_ch12Bpub_ivB if samp_ch12Bpub_ivB==1;
     onereg $ch_ind $ch_ma $ch_div using "tab5.txt" [aw=wgt_ch12Bpub_ivB],
            depvar(f22xrstd) endog(ch_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            outreg append ctitle("CH_12Bpub_ivB_classical");
     onereg $ch_ind $ch_ma $ch_div using "tab5.txt" [aw=wgt_ch12Bpub_ivB],
            depvar(f22xrstd) endog(ch_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            cluster(fipsmsa) outreg append ctitle("CH_12Bpub_ivB_cluster");
  *Preferred replication sample and covariates;
   use ${mywork_confidential}/jrAf2sample.dta, clear;
   replace m_pop_n=m_pop_n/10000000;
   replace m_arealand=m_arealand/100000;
   gen ivA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
   gen ivB=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
   mark jr12A;
   markout jr12A $jr_ind $jr_ma $jr_dist $jr_div jr_choice f2qwt;
   mark jr12B;
   markout jr12B $jr_ind $jr_ma $jr_div jr_choice f2qwt;
   *With district controls;
    *OLS;
     gen samp_jr12Apub_ols=1 if f2qwt>0 & jr12A==1 & pubschf2==1 & f22xrstd<.;
     egen totwgt_jr12Apub_ols=sum(f2qwt) if samp_jr12Apub_ols==1, by(fipsmsa);
     gen wgt_jr12Apub_ols=f2qwt/totwgt_jr12Apub_ols if samp_jr12Apub_ols==1;
     reg f22xrstd jr_choice $jr_ind $jr_ma $jr_dist $jr_div [aw=wgt_jr12Apub_ols];
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_12Apub_ols_classical");
     reg f22xrstd jr_choice $jr_ind $jr_ma $jr_dist $jr_div [aw=wgt_jr12Apub_ols], cluster(fipsmsa);
     local nclust=e(df_r)+1;
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_12Apub_ols_cluster")
                              addstat("nclust", `nclust') adec(8);
     *IV with Hoxby instruments;
     gen samp_jr12Apub_ivA=1 if f2qwt>0 & jr12A==1 & pubschf2==1 & f22xrstd<. & ivA==1;
     egen totwgt_jr12Apub_ivA=sum(f2qwt) if samp_jr12Apub_ivA==1, by(fipsmsa);
     gen wgt_jr12Apub_ivA=f2qwt/totwgt_jr12Apub_ivA if samp_jr12Apub_ivA==1;
     onereg $jr_ind $jr_ma $jr_dist $jr_div using "tab5.txt" [aw=wgt_jr12Apub_ivA],
            depvar(f22xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            outreg append ctitle("JR_12Apub_ivA_classical");
     onereg $jr_ind $jr_ma $jr_dist $jr_div using "tab5.txt" [aw=wgt_jr12Apub_ivA],
            depvar(f22xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            cluster(fipsmsa) outreg append ctitle("JR_12Apub_ivA_cluster");
     *IV with alternative instruments;
     gen samp_jr12Apub_ivB=1 if f2qwt>0 & jr12A==1 & pubschf2==1 & f22xrstd<. & ivB==1;
     egen totwgt_jr12Apub_ivB=sum(f2qwt) if samp_jr12Apub_ivB==1, by(fipsmsa);
     gen wgt_jr12Apub_ivB=f2qwt/totwgt_jr12Apub_ivB if samp_jr12Apub_ivB==1;
     onereg $jr_ind $jr_ma $jr_dist $jr_div using "tab5.txt" [aw=wgt_jr12Apub_ivB],
            depvar(f22xrstd) endog(jr_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            outreg append ctitle("JR_12Apub_ivB_classical");
     onereg $jr_ind $jr_ma $jr_dist $jr_div using "tab5.txt" [aw=wgt_jr12Apub_ivB],
            depvar(f22xrstd) endog(jr_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            cluster(fipsmsa) outreg append ctitle("JR_12Apub_ivB_cluster");
   *Without district controls;
    *OLS;
     gen samp_jr12Bpub_ols=1 if f2qwt>0 & jr12B==1 & pubschf2==1 & f22xrstd<.;
     egen totwgt_jr12Bpub_ols=sum(f2qwt) if samp_jr12Bpub_ols==1, by(fipsmsa);
     gen wgt_jr12Bpub_ols=f2qwt/totwgt_jr12Bpub_ols if samp_jr12Bpub_ols==1;
     reg f22xrstd jr_choice $jr_ind $jr_ma $jr_div [aw=wgt_jr12Bpub_ols];
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_12Bpub_ols_classical");
     reg f22xrstd jr_choice $jr_ind $jr_ma $jr_div [aw=wgt_jr12Bpub_ols], cluster(fipsmsa);
     local nclust=e(df_r)+1;
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_12Bpub_ols_cluster")
                              addstat("nclust", `nclust') adec(8);
     *IV with Hoxby instruments;
     gen samp_jr12Bpub_ivA=1 if f2qwt>0 & jr12B==1 & pubschf2==1 & f22xrstd<. & ivA==1;
     egen totwgt_jr12Bpub_ivA=sum(f2qwt) if samp_jr12Bpub_ivA==1, by(fipsmsa);
     gen wgt_jr12Bpub_ivA=f2qwt/totwgt_jr12Bpub_ivA if samp_jr12Bpub_ivA==1;
     onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr12Bpub_ivA],
            depvar(f22xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            outreg append ctitle("JR_12Bpub_ivA_classical");
     onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr12Bpub_ivA],
            depvar(f22xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            cluster(fipsmsa) outreg append ctitle("JR_12Bpub_ivA_cluster");
     *IV with alternative instruments;
     gen samp_jr12Bpub_ivB=1 if f2qwt>0 & jr12B==1 & pubschf2==1 & f22xrstd<. & ivB==1;
     egen totwgt_jr12Bpub_ivB=sum(f2qwt) if samp_jr12Bpub_ivB==1, by(fipsmsa);
     gen wgt_jr12Bpub_ivB=f2qwt/totwgt_jr12Bpub_ivB if samp_jr12Bpub_ivB==1;
     onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr12Bpub_ivB],
            depvar(f22xrstd) endog(jr_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            outreg append ctitle("JR_12Bpub_ivB_classical");
     onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr12Bpub_ivB],
            depvar(f22xrstd) endog(jr_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            cluster(fipsmsa) outreg append ctitle("JR_12Bpub_ivB_cluster");


*Finally, switch to zip-code matched data, and do with just public or pub+private;
 *Start with 8th grade scores;
  use ${mywork_confidential}/jrBbysample.dta, clear;
  replace m_pop_n=m_pop_n/10000000;
  replace m_arealand=m_arealand/100000;
  gen ivA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
  gen ivB=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
  *Close replication covariates;
   mark ch8C;
   markout ch8C $ch_ind $ch_ma $ch_mdiv ch_choice byqwt;
   *Public schools only;
    *Without district controls;
     *OLS;
      gen samp_ch8Cpub_ols=1 if byqwt>0 & ch8C==1 & pubschby==1 & by2xrstd<.;
      egen totwgt_ch8Cpub_ols=sum(byqwt) if samp_ch8Cpub_ols==1, by(fipsmsa);
      gen wgt_ch8Cpub_ols=byqwt/totwgt_ch8Cpub_ols if samp_ch8Cpub_ols==1;
      reg by2xrstd ch_choice $ch_ind $ch_ma $ch_mdiv [aw=wgt_ch8Cpub_ols];
      outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_8Cpub_ols_classical");
      reg by2xrstd ch_choice $ch_ind $ch_ma $ch_mdiv [aw=wgt_ch8Cpub_ols], cluster(fipsmsa);
      local nclust=e(df_r)+1;
      outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_8Cpub_ols_cluster")
                               addstat("nclust", `nclust') adec(8);
      *IV with Hoxby instruments;
      gen samp_ch8Cpub_ivA=1 if byqwt>0 & ch8C==1 & pubschby==1 & by2xrstd<. & ivA==1;
      egen totwgt_ch8Cpub_ivA=sum(byqwt) if samp_ch8Cpub_ivA==1, by(fipsmsa);
      gen wgt_ch8Cpub_ivA=byqwt/totwgt_ch8Cpub_ivA if samp_ch8Cpub_ivA==1;
      onereg $ch_ind $ch_ma $ch_mdiv using "tab5.txt" [aw=wgt_ch8Cpub_ivA],
             depvar(by2xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
             outreg append ctitle("CH_8Cpub_ivA_classical");
      onereg $ch_ind $ch_ma $ch_mdiv using "tab5.txt" [aw=wgt_ch8Cpub_ivA],
             depvar(by2xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
             cluster(fipsmsa) outreg append ctitle("CH_8Cpub_ivA_cluster");
      *IV with alternative instruments;
      gen samp_ch8Cpub_ivB=1 if byqwt>0 & ch8C==1 & pubschby==1 & by2xrstd<. & ivB==1;
      egen totwgt_ch8Cpub_ivB=sum(byqwt) if samp_ch8Cpub_ivB==1, by(fipsmsa);
      gen wgt_ch8Cpub_ivB=byqwt/totwgt_ch8Cpub_ivB if samp_ch8Cpub_ivB==1;
      onereg $ch_ind $ch_ma $ch_mdiv using "tab5.txt" [aw=wgt_ch8Cpub_ivB],
             depvar(by2xrstd) endog(ch_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
             outreg append ctitle("CH_8Cpub_ivB_classical");
      onereg $ch_ind $ch_ma $ch_mdiv using "tab5.txt" [aw=wgt_ch8Cpub_ivB],
             depvar(by2xrstd) endog(ch_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
             cluster(fipsmsa) outreg append ctitle("CH_8Cpub_ivB_cluster");
   *Public and private schools ;
    *Without district controls;
     *OLS;
      gen samp_ch8C_ols=1 if byqwt>0 & ch8C==1 & by2xrstd<.;
      egen totwgt_ch8C_ols=sum(byqwt) if samp_ch8C_ols==1, by(fipsmsa);
      gen wgt_ch8C_ols=byqwt/totwgt_ch8C_ols if samp_ch8C_ols==1;
      reg by2xrstd ch_choice $ch_ind $ch_ma $ch_mdiv [aw=wgt_ch8C_ols];
      outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_8C_ols_classical");
      reg by2xrstd ch_choice $ch_ind $ch_ma $ch_mdiv [aw=wgt_ch8C_ols], cluster(fipsmsa);
      local nclust=e(df_r)+1;
      outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_8C_ols_cluster")
                               addstat("nclust", `nclust') adec(8);
      *IV with Hoxby instruments;
      gen samp_ch8C_ivA=1 if byqwt>0 & ch8C==1 & by2xrstd<. & ivA==1;
      egen totwgt_ch8C_ivA=sum(byqwt) if samp_ch8C_ivA==1, by(fipsmsa);
      gen wgt_ch8C_ivA=byqwt/totwgt_ch8C_ivA if samp_ch8C_ivA==1;
      onereg $ch_ind $ch_ma $ch_mdiv using "tab5.txt" [aw=wgt_ch8C_ivA],
             depvar(by2xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
             outreg append ctitle("CH_8C_ivA_classical");
      onereg $ch_ind $ch_ma $ch_mdiv using "tab5.txt" [aw=wgt_ch8C_ivA],
             depvar(by2xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
             cluster(fipsmsa) outreg append ctitle("CH_8C_ivA_cluster");
      *IV with alternative instruments;
      gen samp_ch8C_ivB=1 if byqwt>0 & ch8C==1 & by2xrstd<. & ivB==1;
      egen totwgt_ch8C_ivB=sum(byqwt) if samp_ch8C_ivB==1, by(fipsmsa);
      gen wgt_ch8C_ivB=byqwt/totwgt_ch8C_ivB if samp_ch8C_ivB==1;
      onereg $ch_ind $ch_ma $ch_mdiv using "tab5.txt" [aw=wgt_ch8C_ivB],
             depvar(by2xrstd) endog(ch_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
             outreg append ctitle("CH_8C_ivB_classical");
      onereg $ch_ind $ch_ma $ch_mdiv using "tab5.txt" [aw=wgt_ch8C_ivB],
             depvar(by2xrstd) endog(ch_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
             cluster(fipsmsa) outreg append ctitle("CH_8C_ivB_cluster");
  *Preferred replication covariates;
   mark jr8C;
   markout jr8C $jr_ind $jr_ma $jr_div jr_choice byqwt;
   *Public schools only;
    *OLS;
     gen samp_jr8Cpub_ols=1 if byqwt>0 & jr8C==1 & pubschby==1 & by2xrstd<.;
     egen totwgt_jr8Cpub_ols=sum(byqwt) if samp_jr8Cpub_ols==1, by(fipsmsa);
     gen wgt_jr8Cpub_ols=byqwt/totwgt_jr8Cpub_ols if samp_jr8Cpub_ols==1;
     reg by2xrstd jr_choice $jr_ind $jr_ma $jr_div [aw=wgt_jr8Cpub_ols];
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_8Cpub_ols_classical");
     reg by2xrstd jr_choice $jr_ind $jr_ma $jr_div [aw=wgt_jr8Cpub_ols], cluster(fipsmsa);
     local nclust=e(df_r)+1;
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_8Cpub_ols_cluster")
                              addstat("nclust", `nclust') adec(8);
     *IV with Hoxby instruments;
     gen samp_jr8Cpub_ivA=1 if byqwt>0 & jr8C==1 & pubschby==1 & by2xrstd<. & ivA==1;
     egen totwgt_jr8Cpub_ivA=sum(byqwt) if samp_jr8Cpub_ivA==1, by(fipsmsa);
     gen wgt_jr8Cpub_ivA=byqwt/totwgt_jr8Cpub_ivA if samp_jr8Cpub_ivA==1;
     onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr8Cpub_ivA],
            depvar(by2xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            outreg append ctitle("JR_8Cpub_ivA_classical");
     onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr8Cpub_ivA],
            depvar(by2xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            cluster(fipsmsa) outreg append ctitle("JR_8Cpub_ivA_cluster");
     *IV with alternative instruments;
     gen samp_jr8Cpub_ivB=1 if byqwt>0 & jr8C==1 & pubschby==1 & by2xrstd<. & ivB==1;
     egen totwgt_jr8Cpub_ivB=sum(byqwt) if samp_jr8Cpub_ivB==1, by(fipsmsa);
     gen wgt_jr8Cpub_ivB=byqwt/totwgt_jr8Cpub_ivB if samp_jr8Cpub_ivB==1;
     onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr8Cpub_ivB],
            depvar(by2xrstd) endog(jr_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            outreg append ctitle("JR_8Cpub_ivB_classical");
     onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr8Cpub_ivB],
            depvar(by2xrstd) endog(jr_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            cluster(fipsmsa) outreg append ctitle("JR_8Cpub_ivB_cluster");
   *Public and private schools ;
    *Without district controls;
      gen samp_jr8C_ols=1 if byqwt>0 & jr8C==1 & by2xrstd<.;
      egen totwgt_jr8C_ols=sum(byqwt) if samp_jr8C_ols==1, by(fipsmsa);
      gen wgt_jr8C_ols=byqwt/totwgt_jr8C_ols if samp_jr8C_ols==1;
      reg by2xrstd jr_choice $jr_ind $jr_ma $jr_div [aw=wgt_jr8C_ols];
      outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_8C_ols_classical");
      reg by2xrstd jr_choice $jr_ind $jr_ma $jr_div [aw=wgt_jr8C_ols], cluster(fipsmsa);
      local nclust=e(df_r)+1;
      outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_8C_ols_cluster")
                               addstat("nclust", `nclust') adec(8);
      *IV with Hoxby instruments;
      gen samp_jr8C_ivA=1 if byqwt>0 & jr8C==1 & by2xrstd<. & ivA==1;
      egen totwgt_jr8C_ivA=sum(byqwt) if samp_jr8C_ivA==1, by(fipsmsa);
      gen wgt_jr8C_ivA=byqwt/totwgt_jr8C_ivA if samp_jr8C_ivA==1;
      onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr8C_ivA],
             depvar(by2xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
             outreg append ctitle("JR_8C_ivA_classical");
      onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr8C_ivA],
             depvar(by2xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
             cluster(fipsmsa) outreg append ctitle("JR_8C_ivA_cluster");
      *IV with alternative instruments;
      gen samp_jr8C_ivB=1 if byqwt>0 & jr8C==1 & by2xrstd<. & ivB==1;
      egen totwgt_jr8C_ivB=sum(byqwt) if samp_jr8C_ivB==1, by(fipsmsa);
      gen wgt_jr8C_ivB=byqwt/totwgt_jr8C_ivB if samp_jr8C_ivB==1;
      onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr8C_ivB],
             depvar(by2xrstd) endog(jr_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
             outreg append ctitle("JR_8C_ivB_classical");
      onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr8C_ivB],
             depvar(by2xrstd) endog(jr_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
             cluster(fipsmsa) outreg append ctitle("JR_8C_ivB_cluster");


 *Now 12th grade scores;
  use ${mywork_confidential}/jrBf2sample.dta, clear;
  replace m_pop_n=m_pop_n/10000000;
  replace m_arealand=m_arealand/100000;
  gen ivA=1 if ch_nstreams_lg<. & ch_nstreams_sm<.;
  gen ivB=1 if jr_nstreamsB_inter<. & jr_nstreamsB_intra<.;
  *Close replication covariates;
   global ch_ind "ch_lnfaminc ch_asian ch_hispanic ch_black ch_female ch_parcolg ch_parscol";
   global ch_ma "m_pop_n m_arealand ch_m_avglnmeaninc ch_m_gini ch_m_pop_fas ch_m_pop_fbl ch_m_pop_fhi ch_m_herfrace ch_m_herfethn m_ed_scol m_ed_ba m_herfed";
   global ch_dist "d_lnmeanincA ch_d_gini ch_d_pop_fas ch_d_pop_fbl ch_d_pop_fhi ch_d_herfrace ch_d_herfethn d_ed_scol d_ed_ba d_herfed";
   global ch_div "ch_d_div1 ch_d_div2 ch_d_div3 ch_d_div4 ch_d_div5 ch_d_div6 ch_d_div7 ch_d_div8";
   mark ch12C;
   markout ch12C $ch_ind $ch_ma $ch_mdiv ch_choice f2qwt;
   *Public schools only;
    *OLS;
     gen samp_ch12Cpub_ols=1 if f2qwt>0 & ch12C==1 & pubschf2==1 & f22xrstd<.;
     egen totwgt_ch12Cpub_ols=sum(f2qwt) if samp_ch12Cpub_ols==1, by(fipsmsa);
     gen wgt_ch12Cpub_ols=f2qwt/totwgt_ch12Cpub_ols if samp_ch12Cpub_ols==1;
     reg f22xrstd ch_choice $ch_ind $ch_ma $ch_mdiv [aw=wgt_ch12Cpub_ols];
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_12Cpub_ols_classical");
     reg f22xrstd ch_choice $ch_ind $ch_ma $ch_mdiv [aw=wgt_ch12Cpub_ols], cluster(fipsmsa);
     local nclust=e(df_r)+1;
     outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_12Cpub_ols_cluster")
                              addstat("nclust", `nclust') adec(8);
     *IV with Hoxby instruments;
     gen samp_ch12Cpub_ivA=1 if f2qwt>0 & ch12C==1 & pubschf2==1 & f22xrstd<. & ivA==1;
     egen totwgt_ch12Cpub_ivA=sum(f2qwt) if samp_ch12Cpub_ivA==1, by(fipsmsa);
     gen wgt_ch12Cpub_ivA=f2qwt/totwgt_ch12Cpub_ivA if samp_ch12Cpub_ivA==1;
     onereg $ch_ind $ch_ma $ch_mdiv using "tab5.txt" [aw=wgt_ch12Cpub_ivA],
            depvar(f22xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            outreg append ctitle("CH_12Cpub_ivA_classical");
     onereg $ch_ind $ch_ma $ch_mdiv using "tab5.txt" [aw=wgt_ch12Cpub_ivA],
            depvar(f22xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
            cluster(fipsmsa) outreg append ctitle("CH_12Cpub_ivA_cluster");
     *IV with alternative instruments;
     gen samp_ch12Cpub_ivB=1 if f2qwt>0 & ch12C==1 & pubschf2==1 & f22xrstd<. & ivB==1;
     egen totwgt_ch12Cpub_ivB=sum(f2qwt) if samp_ch12Cpub_ivB==1, by(fipsmsa);
     gen wgt_ch12Cpub_ivB=f2qwt/totwgt_ch12Cpub_ivB if samp_ch12Cpub_ivB==1;
     onereg $ch_ind $ch_ma $ch_mdiv using "tab5.txt" [aw=wgt_ch12Cpub_ivB],
            depvar(f22xrstd) endog(ch_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            outreg append ctitle("CH_12Cpub_ivB_classical");
     onereg $ch_ind $ch_ma $ch_mdiv using "tab5.txt" [aw=wgt_ch12Cpub_ivB],
            depvar(f22xrstd) endog(ch_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
            cluster(fipsmsa) outreg append ctitle("CH_12Cpub_ivB_cluster");
   *Public and private schools ;
     *OLS;
      gen samp_ch12C_ols=1 if f2qwt>0 & ch12C==1 & f22xrstd<.;
      egen totwgt_ch12C_ols=sum(f2qwt) if samp_ch12C_ols==1, by(fipsmsa);
      gen wgt_ch12C_ols=f2qwt/totwgt_ch12C_ols if samp_ch12C_ols==1;
      reg f22xrstd ch_choice $ch_ind $ch_ma $ch_mdiv [aw=wgt_ch12C_ols];
      outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_12C_ols_classical");
      reg f22xrstd ch_choice $ch_ind $ch_ma $ch_mdiv [aw=wgt_ch12C_ols], cluster(fipsmsa);
      local nclust=e(df_r)+1;
      outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("CH_12C_ols_cluster")
                               addstat("nclust", `nclust') adec(8);
      *IV with Hoxby instruments;
      gen samp_ch12C_ivA=1 if f2qwt>0 & ch12C==1 & f22xrstd<. & ivA==1;
      egen totwgt_ch12C_ivA=sum(f2qwt) if samp_ch12C_ivA==1, by(fipsmsa);
      gen wgt_ch12C_ivA=f2qwt/totwgt_ch12C_ivA if samp_ch12C_ivA==1;
      onereg $ch_ind $ch_ma $ch_mdiv using "tab5.txt" [aw=wgt_ch12C_ivA],
             depvar(f22xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
             outreg append ctitle("CH_12C_ivA_classical");
      onereg $ch_ind $ch_ma $ch_mdiv using "tab5.txt" [aw=wgt_ch12C_ivA],
             depvar(f22xrstd) endog(ch_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
             cluster(fipsmsa) outreg append ctitle("CH_12C_ivA_cluster");
      *IV with alternative instruments;
      gen samp_ch12C_ivB=1 if f2qwt>0 & ch12C==1 & f22xrstd<. & ivB==1;
      egen totwgt_ch12C_ivB=sum(f2qwt) if samp_ch12C_ivB==1, by(fipsmsa);
      gen wgt_ch12C_ivB=f2qwt/totwgt_ch12C_ivB if samp_ch12C_ivB==1;
      onereg $ch_ind $ch_ma $ch_mdiv using "tab5.txt" [aw=wgt_ch12C_ivB],
             depvar(f22xrstd) endog(ch_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
             outreg append ctitle("CH_12C_ivB_classical");
      onereg $ch_ind $ch_ma $ch_mdiv using "tab5.txt" [aw=wgt_ch12C_ivB],
             depvar(f22xrstd) endog(ch_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
             cluster(fipsmsa) outreg append ctitle("CH_12C_ivB_cluster");
  *Preferred replication covariates;
   global jr_ind "jr_lnfaminc jr_asian jr_hispanic jr_black jr_female jr_parcolg jr_parscol";
   global jr_ma "m_pop_n m_arealand m_lnmeanincA jr_m_gini jr_m_pop_fas jr_m_pop_fbl jr_m_pop_fhi jr_m_herfrace jr_m_herfethn m_ed_scol m_ed_ba m_herfed";
   global jr_dist "d_lnmeanincA jr_d_gini jr_d_pop_fas jr_d_pop_fbl jr_d_pop_fhi jr_d_herfrace jr_d_herfethn d_ed_scol d_ed_ba d_herfed";
   global jr_div "jr_m_divis1 jr_m_divis2 jr_m_divis3 jr_m_divis4 jr_m_divis5 jr_m_divis6 jr_m_divis7 jr_m_divis8 ";
   mark jr12C;
   markout jr12C $jr_ind $jr_ma $jr_div jr_choice f2qwt;
   *Public schools only;
    *Without district controls;
     *OLS;
      gen samp_jr12Cpub_ols=1 if f2qwt>0 & jr12C==1 & pubschf2==1 & f22xrstd<.;
      egen totwgt_jr12Cpub_ols=sum(f2qwt) if samp_jr12Cpub_ols==1, by(fipsmsa);
      gen wgt_jr12Cpub_ols=f2qwt/totwgt_jr12Cpub_ols if samp_jr12Cpub_ols==1;
      reg f22xrstd jr_choice $jr_ind $jr_ma $jr_div [aw=wgt_jr12Cpub_ols];
      outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_12Cpub_ols_classical");
      reg f22xrstd jr_choice $jr_ind $jr_ma $jr_div [aw=wgt_jr12Cpub_ols], cluster(fipsmsa);
      local nclust=e(df_r)+1;
      outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_12Cpub_ols_cluster")
                               addstat("nclust", `nclust') adec(8);
      *IV with Hoxby instruments;
      gen samp_jr12Cpub_ivA=1 if f2qwt>0 & jr12C==1 & pubschf2==1 & f22xrstd<. & ivA==1;
      egen totwgt_jr12Cpub_ivA=sum(f2qwt) if samp_jr12Cpub_ivA==1, by(fipsmsa);
      gen wgt_jr12Cpub_ivA=f2qwt/totwgt_jr12Cpub_ivA if samp_jr12Cpub_ivA==1;
      onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr12Cpub_ivA],
             depvar(f22xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
             outreg append ctitle("JR_12Cpub_ivA_classical");
      onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr12Cpub_ivA],
             depvar(f22xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
             cluster(fipsmsa) outreg append ctitle("JR_12Cpub_ivA_cluster");
      *IV with alternative instruments;
      gen samp_jr12Cpub_ivB=1 if f2qwt>0 & jr12C==1 & pubschf2==1 & f22xrstd<. & ivB==1;
      egen totwgt_jr12Cpub_ivB=sum(f2qwt) if samp_jr12Cpub_ivB==1, by(fipsmsa);
      gen wgt_jr12Cpub_ivB=f2qwt/totwgt_jr12Cpub_ivB if samp_jr12Cpub_ivB==1;
      onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr12Cpub_ivB],
             depvar(f22xrstd) endog(jr_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
             outreg append ctitle("JR_12Cpub_ivB_classical");
      onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr12Cpub_ivB],
             depvar(f22xrstd) endog(jr_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
             cluster(fipsmsa) outreg append ctitle("JR_12Cpub_ivB_cluster");
   *Public and private schools ;
    *Without district controls;
      gen samp_jr12C_ols=1 if f2qwt>0 & jr12C==1 & f22xrstd<.;
      egen totwgt_jr12C_ols=sum(f2qwt) if samp_jr12C_ols==1, by(fipsmsa);
      gen wgt_jr12C_ols=f2qwt/totwgt_jr12C_ols if samp_jr12C_ols==1;
      reg f22xrstd jr_choice $jr_ind $jr_ma $jr_div [aw=wgt_jr12C_ols];
      outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_12C_ols_classical");
      reg f22xrstd jr_choice $jr_ind $jr_ma $jr_div [aw=wgt_jr12C_ols], cluster(fipsmsa);
      local nclust=e(df_r)+1;
      outreg using "tab5.txt", append bdec(8) rdec(8) se noparen noaster nolabel ctitle("JR_12C_ols_cluster")
                               addstat("nclust", `nclust') adec(8);
      *IV with Hoxby instruments;
      gen samp_jr12C_ivA=1 if f2qwt>0 & jr12C==1 & f22xrstd<. & ivA==1;
      egen totwgt_jr12C_ivA=sum(f2qwt) if samp_jr12C_ivA==1, by(fipsmsa);
      gen wgt_jr12C_ivA=f2qwt/totwgt_jr12C_ivA if samp_jr12C_ivA==1;
      onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr12C_ivA],
             depvar(f22xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
             outreg append ctitle("JR_12C_ivA_classical");
      onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr12C_ivA],
             depvar(f22xrstd) endog(jr_choice) instrum(ch_nstreams_lg ch_nstreams_sm)
             cluster(fipsmsa) outreg append ctitle("JR_12C_ivA_cluster");
      *IV with alternative instruments;
      gen samp_jr12C_ivB=1 if f2qwt>0 & jr12C==1 & f22xrstd<. & ivB==1;
      egen totwgt_jr12C_ivB=sum(f2qwt) if samp_jr12C_ivB==1, by(fipsmsa);
      gen wgt_jr12C_ivB=f2qwt/totwgt_jr12C_ivB if samp_jr12C_ivB==1;
      onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr12C_ivB],
             depvar(f22xrstd) endog(jr_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
             outreg append ctitle("JR_12C_ivB_classical");
      onereg $jr_ind $jr_ma $jr_div using "tab5.txt" [aw=wgt_jr12C_ivB],
             depvar(f22xrstd) endog(jr_choice) instrum(jr_nstreamsB_inter jr_nstreamsB_intra)
             cluster(fipsmsa) outreg append ctitle("JR_12C_ivB_cluster");

log close;
