capture log close
log using makedata_nels.smcl, replace
/*
Program to assemble NELS data, and to match it to districts and MSAs.
Need to run makedata_msadist.do first.

Define variables according to two algorithms:
 1) That followed by Hoxby in creating the Hoxby/NCES data.
    These variables are prefixed "ch_", and are referred to
    as the "close replication" covariates.;
 2) The so-called "preferred" algorithm.  These variables are
    prefixed "jr_".  See appendix A for details.
 In some cases, the two algorithms were identical.  Generally,
 these variables are given no prefix.
*/

#delimit;
clear;
set mem 600m;
do ../definedirs.do;
version 8.0;
pause off;
set more off;
query;
creturn list;

**Section A:  Read MSA definitions, and create county-MSA and town-MSA crosswalks;
 *Read 1990 MSA defs.  Note--lots of invalid lines--skip these;
  quietly infix msa 1-4
        pmsa 9-12
        cmsa 17-18
        stfips 25-26
        cofips 27-29
        central 33
        townfips 41-45
        str name 49-115 using "${mydata}/MSA defs/msadefs90.txt", clear;
  *Fix an error in the text file--MSA code is left off of name line for one MSA;
   replace msa=1400 if name=="Champaign-Urbana-Rantoul, IL MSA";
  *Fix one town FIPS code that is wrong on MSA definitions file;
   replace townfips=29405 if stfips==25 & cofips==9 & townfips==25625 & name=="Haverhill city";
  drop if msa==.;
  gen fipsmsa=msa if cmsa==.;
  replace fipsmsa=pmsa if cmsa~=.;
  tempfile allmsa msanames co2msa town2msa co2msa_ne;
  compress;
  save `allmsa';
  keep if stfips==. & fipsmsa~=.;
  drop if index(name, "PR")>0;
  sort fipsmsa msa cmsa pmsa name;
  duplicates report fipsmsa msa cmsa pmsa;
  rename name msaname;
  keep fipsmsa msaname;
  sort fipsmsa;
  save `msanames';
 *Make a county-MSA crosswalk;
  use `allmsa';
  keep if townfips==. & central~=. & fipsmsa~=. & fipsmsa>0;
  drop if stfips>56;
  keep stfips cofips fipsmsa;
  sort fipsmsa;
  merge fipsmsa using `msanames', uniqusing _merge(co2name);
  tab co2name;
  *co2name=2 is NE MSAs;
  keep if co2name==3;
  drop co2name;
  sort stfips cofips;
  duplicates report stfips cofips;
  save `co2msa';
 *Make a town-MSA crosswalk;
  use `allmsa';
  keep if townfips~=. & central~=. & fipsmsa~=. & fipsmsa>0;
  drop if stfips>56;
  keep stfips cofips townfips fipsmsa;
  sort fipsmsa;
  merge fipsmsa using `msanames', uniqusing _merge(town2name);
  tab town2name;
  drop if town2name==2;
  drop town2name;
  sort stfips cofips townfips;
  duplicates report stfips cofips townfips;
  save `town2msa';
 *Finally, make a list of counties that include some MSA towns in NE;
  by stfips cofips: keep if _n==1;
  gen ismsa=1;
  keep stfips cofips ismsa;
  sort stfips cofips;
  save `co2msa_ne';

**Section A:  Read NELS student-level data and clean it up;
 *NELS student-level file;
  drop _all;
  infix using makedata.include.nels.student.dct, using(${cddrive}\nels92\stmeg.pri);
  *Fix test variables;
   foreach v of varlist by2xrstd by2xmstd f12xrstd f12xmstd f22xrstd f22xmstd {;
    replace `v'=`v'/100;
    replace `v'=. if `v'>99;
    };
   replace byqwt=byqwt/1000;
   replace f1qwt=f1qwt/10000;
   replace f2qwt=f2qwt/10000;
  *Generate private school variables;
   gen prvschby=1 if g8ctrl>=2 & g8ctrl<=4;
   replace prvschby=1 if g8ctrl1>=2 & g8ctrl1<=4;
   replace prvschby=1 if g8ctrl2>=2 & g8ctrl2<=3;
   replace prvschby=1 if g8xctrl>=2 & g8xctrl<=4;
   replace prvschby=0 if prvschby==. & (g8ctrl==1 | g8ctrl1==1 | g8ctrl2==1 | g8xctrl==1);
   label var prvschby "1 if prv sch in base yr, 0 is public, missing is unknown";
   gen prvschf1=1 if g10ctrl1>=2 & g10ctrl1<=5;
   replace prvschf1=1 if g10ctrl2>=2 & g10ctrl2<=4;
   replace prvschf1=0 if prvschf1==. & (g10ctrl1==1 | g10ctrl2==1);
   label var prvschf1 "1 if prv sch in 1st foll up, 0 is public, missing is unknown";
   gen prvschf2=1 if g12ctrl1>=2 & g12ctrl1<=5;
   replace prvschf2=1 if g12ctrl2>=2 & g12ctrl2<=4;
   replace prvschf2=0 if prvschf2==. & (g12ctrl1==1 | g12ctrl2==1);
   label var prvschf2 "1 if prv sch in 2nd foll up, 0 is public, missing is unknown";
  *Generate public school variables.  These may differ from private school variables if the multiple measures disagree;
   gen pubschby=1 if g8ctrl==1;
   replace pubschby=1 if g8ctrl1==1;
   replace pubschby=1 if g8ctrl2==1;
   replace pubschby=1 if g8xctrl==1;
   replace pubschby=0 if pubschby==. & prvschby==1;
   label var pubschby "1 if pub sch in base yr, 0 is private, missing is unknown";
   gen pubschf1=1 if g10ctrl1==1;
   replace pubschf1=1 if g10ctrl2==1;
   replace pubschf1=0 if pubschf1==. & prvschf1==1;
   label var pubschf1 "1 if pub sch in 1st foll up, 0 is private, missing is unknown";
   gen pubschf2=1 if g12ctrl1==1;
   replace pubschf2=1 if g12ctrl2==1;
   replace pubschf2=0 if pubschf2==. & prvschf2==1;
   label var pubschf2 "1 if pub sch in 2nd foll up, 0 is private, missing is unknown";
  *Recode to make consistent;
   gen badby=1 if (prvschby==1 & pubschby==1) | (prvschby==0 & pubschby==0);
   gen badf1=1 if (prvschf1==1 & pubschf1==1) | (prvschf1==0 & pubschf1==0);
   gen badf2=1 if (prvschf2==1 & pubschf2==1) | (prvschf2==0 & pubschf2==0);
   replace prvschby=. if badby==1;
   replace prvschf1=. if badf1==1;
   replace prvschf2=. if badf2==1;
   replace pubschby=. if badby==1;
   replace pubschf1=. if badf1==1;
   replace pubschf2=. if badf2==1;
   drop badby badf1 badf2;
   gen prvschall=1 if prvschby==1 & prvschf1==1 & prvschf2==1;
   replace prvschall=0 if pubschby==1 | pubschf1==1 | pubschf2==1;
   label var prvschall "1 if prv sch in by&f1&f2; 0 if pub sch in at least 1 wave";
   gen pubschall=1 if pubschby==1 & pubschf1==1 & pubschf2==1;
   replace pubschall=0 if prvschby==1 | prvschf1==1 | prvschf2==1;
   label var pubschall "1 if pub sch in by&f1&f2; 0 if prv sch in at least 1 wave";

  *Create the natural log of family income.
   *CH algorithm, using category midpoints and 80% of bottom for bottom cat, 110% of top for top cat;
    gen ch_lnfaminc=.;
    label var ch_lnfaminc "LN(base year fam inc/1000), CH code";
    replace ch_lnfaminc=log(0.8) if byfaminc==2;
    replace ch_lnfaminc=log(2) if byfaminc==3;
    replace ch_lnfaminc=log(4) if byfaminc==4;
    replace ch_lnfaminc=log(6.25) if byfaminc==5;
    replace ch_lnfaminc=log(8.75) if byfaminc==6;
    replace ch_lnfaminc=log(12.5) if byfaminc==7;
    replace ch_lnfaminc=log(17.5) if byfaminc==8;
    replace ch_lnfaminc=log(22.5) if byfaminc==9;
    replace ch_lnfaminc=log(30) if byfaminc==10;
    replace ch_lnfaminc=log(42.5) if byfaminc==11;
    replace ch_lnfaminc=log(62.5) if byfaminc==12;
    replace ch_lnfaminc=log(87.5) if byfaminc==13;
    replace ch_lnfaminc=log(150) if byfaminc==14;
    replace ch_lnfaminc=log(220) if byfaminc==15;
   *JR algorithm:  Use average of logs of endpoints.  For bottom category, use 0.5*bottom.  For top cat, use 125%.
   *Use F2 survey if not available from BY survey. Also, assign bottom category (income=none) equal to log(1);
    gen jr_lnfaminc=.;
    label var jr_lnfaminc "LN(base year/F2 fam inc), JR code";
    replace jr_lnfaminc=log(1) if byfaminc==1;
    replace jr_lnfaminc=log(500) if byfaminc==2;
    replace jr_lnfaminc=(log(1000)+log(3000))/2 if byfaminc==3;
    replace jr_lnfaminc=(log(3000)+log(5000))/2 if byfaminc==4;
    replace jr_lnfaminc=(log(5000)+log(7500))/2 if byfaminc==5;
    replace jr_lnfaminc=(log(7500)+log(10000))/2 if byfaminc==6;
    replace jr_lnfaminc=(log(10000)+log(15000))/2 if byfaminc==7;
    replace jr_lnfaminc=(log(15000)+log(20000))/2 if byfaminc==8;
    replace jr_lnfaminc=(log(20000)+log(25000))/2 if byfaminc==9;
    replace jr_lnfaminc=(log(25000)+log(35000))/2 if byfaminc==10;
    replace jr_lnfaminc=(log(35000)+log(50000))/2 if byfaminc==11;
    replace jr_lnfaminc=(log(50000)+log(75000))/2 if byfaminc==12;
    replace jr_lnfaminc=(log(75000)+log(100000))/2 if byfaminc==13;
    replace jr_lnfaminc=(log(100000)+log(200000))/2 if byfaminc==14;
    replace jr_lnfaminc=log(250000) if byfaminc==15;
    replace jr_lnfaminc=log(1) if f2faminc==1 & jr_lnfaminc==.;
    replace jr_lnfaminc=log(500) if f2faminc==2 & jr_lnfaminc==.;
    replace jr_lnfaminc=(log(1000)+log(3000))/2 if f2faminc==3 & jr_lnfaminc==.;
    replace jr_lnfaminc=(log(3000)+log(5000))/2 if f2faminc==4 & jr_lnfaminc==.;
    replace jr_lnfaminc=(log(5000)+log(7500))/2 if f2faminc==5 & jr_lnfaminc==.;
    replace jr_lnfaminc=(log(7500)+log(10000))/2 if f2faminc==6 & jr_lnfaminc==.;
    replace jr_lnfaminc=(log(10000)+log(15000))/2 if f2faminc==7 & jr_lnfaminc==.;
    replace jr_lnfaminc=(log(15000)+log(20000))/2 if f2faminc==8 & jr_lnfaminc==.;
    replace jr_lnfaminc=(log(20000)+log(25000))/2 if f2faminc==9 & jr_lnfaminc==.;
    replace jr_lnfaminc=(log(25000)+log(35000))/2 if f2faminc==10 & jr_lnfaminc==.;
    replace jr_lnfaminc=(log(35000)+log(50000))/2 if f2faminc==11 & jr_lnfaminc==.;
    replace jr_lnfaminc=(log(50000)+log(75000))/2 if f2faminc==12 & jr_lnfaminc==.;
    replace jr_lnfaminc=(log(75000)+log(100000))/2 if f2faminc==13 & jr_lnfaminc==.;
    replace jr_lnfaminc=(log(100000)+log(200000))/2 if f2faminc==14 & jr_lnfaminc==.;
    replace jr_lnfaminc=log(250000) if f2faminc==15 & jr_lnfaminc==.;

  *Create race.
   *CH race computation: Just use BY, and assign values if this is non-missing;
   *Note:  There are one or two values ("blank" and 8) for which Hoxby will assign
   *white but I will assign missing byrace;
    gen ch_asian=(race==1) if race<.;
    gen ch_hispanic=(race==2) if race<.;
    gen ch_black=(race==3) if race<.;
    gen ch_minority=(race==5) if race<.;
    replace ch_minority=max(ch_asian, ch_hispanic, ch_black, ch_minority) if race<.;
    label var ch_asian "Asian indic. (CH rule)";
    label var ch_hispanic "Hispanic indic. (CH rule)";
    label var ch_black "Black indic. (CH rule)";
    label var ch_minority "Minority indic. (CH rule)";
   *JR race computation: Use BY, then F1, then F2 (two versions);
    gen jr_race=race if race>=1 & race<=5;
    replace jr_race=f1race if f1race>=1 & f1race<=5 & jr_race==.;
    replace jr_race=f2race1 if f2race1>=1 & f2race1<=5 & jr_race==.;
    replace jr_race=f2rrace1 if f2rrace1>=1 & f2rrace1<=5 & jr_race==.;
    gen jr_asian=(jr_race==1) if jr_race<.;
    gen jr_hispanic=(jr_race==2) if jr_race<.;
    gen jr_black=(jr_race==3) if jr_race<.;
    gen jr_minority=(jr_race==5) if jr_race<.;
    label var jr_asian "Asian indic. (JR rule)";
    label var jr_hispanic "Hispanic indic. (JR rule)";
    label var jr_black "Black indic. (JR rule)";
    label var jr_minority "Minority indic. (JR rule)";
    drop jr_race;

  *Create a female dummy variable;
   *CH Female computation: Just use BY, and missing if that is.;
    gen ch_female=(sex==2) if sex<.;
    label var ch_female "Female indic. (CH rule--only BY)";
   *JR Female computation:  Use BY, then F1, then F2;
    gen jr_female=(sex==2) if sex<.;
    replace jr_female=1 if jr_female==. & f1sex==2;
    replace jr_female=0 if jr_female==. & f1sex==1;
    replace jr_female=1 if jr_female==. & f2sex==2;
    replace jr_female=0 if jr_female==. & f2sex==1;
    replace jr_female=1 if jr_female==. & f2rsex==2;
    replace jr_female=0 if jr_female==. & f2rsex==1;
    label var jr_female "Female indic. (JR rule)";

  *Create parents educational attainment variables.;
   *CH:  Use BYS34A and BYS34B, which report mothers and fathers highest ed levels;
   *Codes are: 1=LTHS, 2=HS, 3=JC, 4=<BA, 5=BA, 6=MA, 7=PHD MD 8=dont know;
   *Note:  This gives quite different answers than mine, with very high misclassification rates;
   *BYS34 is students report of parents education.  BYPARED uses parents questionnaire data;
   *if available, and student questionnaire info only if parents answers are missing;
    gen ch_parhighed=bys34a;
    replace ch_parhighed=bys34b if (bys34b>bys34a & bys34b<8) | bys34a>=8;
    replace ch_parhighed=. if ch_parhighed>=8;
    gen ch_parcolg=(ch_parhighed>=5) if ch_parhighed<.;
    gen ch_parscol=(ch_parhighed>=3)-ch_parcolg if ch_parhighed<.;
    label var ch_parscol "Parents >HS, <BA (CH rule--diff var)";
    label var ch_parcolg "Parents BA+ (CH rule--diff var)";
   *JR: Use BY, then F1, then F2, using variable labeled parents highest educ.;
   *Note: 1=LTHS, 2=HS grad/GED, 3=>HS <BA, 4=BA 5=MA 6=PHD MD 7=dont know;
   *Treat dont know in each wave as missing;
    gen jr_parhighed=bypared if bypared<=6;
    replace jr_parhighed=f1pared if jr_parhighed==. & f1pared<=6;
    replace jr_parhighed=f2pared if jr_parhighed==. & f2pared<=6;
    gen jr_parscol=(jr_parhighed==3) if jr_parhighed<.;
    gen jr_parcolg=(jr_parhighed>=4 & jr_parhighed<=6) if jr_parhighed<.;
    label var jr_parscol "Parents >HS, <BA (JR rule--diff var)";
    label var jr_parcolg "Parents BA+ (JR rule--diff var)";

   *Drop unneeded variables;
   keep id sch_id byqwt f1sch_id f1qwt f2sch_id f2qwt
        *2xrstd *2xmstd prvsch* pubsch* ch_* jr_*;
   tempfile inddata;
   save `inddata';

**Section B:  Read NELS school-level file.  Assign matching information.;
 *NELS school-level file;
  drop _all;
  infix using makedata.include.nels.school.dct, using(${cddrive}\nels92\scmeg.pri);
  drop g8ctrl;

 *Each school has six possible district codes.  Compile these;
  gen sch_leaid_nby=real(substr(byncesid, 1, 7)) if byncesid~="";
  gen sch_leaid_qby=byqedstc*100000+byoedist;
  gen sch_leaid_nf1=real(substr(f1ncesid, 1, 7)) if f1ncesid~="";
  gen sch_leaid_qf1=f1qedstc*100000+f1oedist;
  gen sch_leaid_nf2=real(substr(f2ncesid, 1, 7)) if f2ncesid~="";
  gen sch_leaid_qf2=f2qedstc*100000+f2oedist;

 *Test validity of each LEA ID;
  tempfile skldata sddblist;
  save `skldata';
  use ${mywork_public}/distdata;
  keep if leaid>0 & leaid<.;
  keep leaid;
  sort leaid;
  save `sddblist';
  use `skldata';
  foreach v in nby qby nf1 qf1 nf2 qf2 {;
   rename sch_leaid_`v' leaid;
   sort leaid;
   merge leaid using `sddblist', uniqusing _merge(mrg_`v');
   gen sch_isvalid_`v'=(mrg_`v'==3);
   drop if mrg_`v'==2;
   drop mrg_`v';
   rename leaid sch_leaid_`v';
   su sch_isvalid_`v';
   su sch_isvalid_`v' if sch_leaid_`v'>0 & sch_leaid_`v'<.;
   };
 *Keep only one match per wave, preferring NCES to QED codes;
  gen sch_leaid_by=sch_leaid_nby if sch_isvalid_nby==1;
  replace sch_leaid_by=sch_leaid_qby if sch_isvalid_qby==1 & sch_isvalid_nby~=1;
  gen sch_leaid_f1=sch_leaid_nf1 if sch_isvalid_nf1==1;
  replace sch_leaid_f1=sch_leaid_qf1 if sch_isvalid_qf1==1 & sch_isvalid_nf1~=1;
  gen sch_leaid_f2=sch_leaid_nf2 if sch_isvalid_nf2==1;
  replace sch_leaid_f2=sch_leaid_qf2 if sch_isvalid_qf2==1 & sch_isvalid_nf2~=1;
  drop sch_leaid_n* sch_leaid_q* sch_isvalid* *ncesid *qedstc *oedist;
 save `skldata', replace;

 *Now match schools to zip codes, and via them to MSAs;
  *Compile a list of the zip code matching variables:  H1ZTOT P1ZTOT PZ80A, from all three waves;
   tempfile zmatchlist;
   rename byh1ztot h1_1;
   rename byp1ztot p1_1;
   rename bypz80a  p80_a;
   keep h1_1 p1_1 p80_a;
   save `zmatchlist';
   use `skldata';
   rename f1h1ztot h1_1;
   rename f1p1ztot p1_1;
   rename f1pz80a  p80_a;
   keep h1_1 p1_1 p80_a;
   append using `zmatchlist';
   save `zmatchlist', replace;
   use `skldata';
   rename f2h1ztot h1_1;
   rename f2p1ztot p1_1;
   rename f2pz80a  p80_a;
   keep h1_1 p1_1 p80_a;
   append using `zmatchlist';
   *Keep only unique values;
    duplicates drop;
   rename p80_a nels_p80a;
   save `zmatchlist', replace;
  *Read in zip code data;
   tempfile zip1 zip2 zip3 allzip;
   drop _all;
   infix 4 lines
         1: sumlev 11-13 logrecnu 19-24 cofips 72-74 stfips 133-134 zip 142-146 double p1_1 301-309
         2: double p80a_1 5791-5799
         3: double p121_1 5281-5289
         4: double h1_1 1381-1389
         using ${mydata}/stf3b/DA6116.ZIP012;
   save `zip1';
   drop _all;
   infix 4 lines
         1: sumlev 11-13 logrecnu 19-24 cofips 72-74 stfips 133-134 zip 142-146 double p1_1 301-309
         2: double p80a_1 5791-5799
         3: double p121_1 5281-5289
         4: double h1_1 1381-1389
         using ${mydata}/stf3b/DA6116.ZIP34;
   save `zip2';
   drop _all;
   infix 4 lines
         1: sumlev 11-13 logrecnu 19-24 cofips 72-74 stfips 133-134 zip 142-146 double p1_1 301-309
         2: double p80a_1 5791-5799
         3: double p121_1 5281-5289
         4: double h1_1 1381-1389
         using ${mydata}/stf3b/DA6116.ZIP567;
   save `zip3';
   drop _all;
   infix 4 lines
         1: sumlev 11-13 logrecnu 19-24 cofips 72-74 stfips 133-134 zip 142-146 double p1_1 301-309
         2: double p80a_1 5791-5799
         3: double p121_1 5281-5289
         4: double h1_1 1381-1389
         using ${mydata}/stf3b/DA6116.ZIP89;
   append using `zip1';
   append using `zip2';
   append using `zip3';
   save `allzip';
  *Make a file of the zip code summary level (rather than zip-county);
   keep if sumlev==800;
   drop sumlev;
   sort p1_1 h1_1;
   keep zip p1_1 h1_1 p80a_1;
   *Note that there are a small number of duplicates;
    duplicates report p1_1 h1_1 p80a_1;
    duplicates report p1_1 h1_1 p80a_1 if p1_1>0;
   tempfile zips;
   sort p1_1 h1_1 p80a_1;
   save `zips';
  *Merge the NELS school zip code information to the zip code file;
   use `zmatchlist';
   sort p1_1 h1_1;
   merge p1_1 h1_1 using `zips', uniqmaster _merge(nels2zip);
   tab nels2zip;
   drop if nels2zip==2;
   *Check to see if duplicates are brought in.  For the small number that are, keep based on p80a match.;
    duplicates report p1_1 h1_1 nels_p80a;
    duplicates tag p1_1 h1_1 nels_p80a, gen(isdup);
    gen incerr=abs(nels_p80a-p80a_1);
    sort p1_1 h1_1 incerr;
    list p1_1 h1_1 incerr nels_p80a p80a_1 if isdup>0 & isdup<.;
    by p1_1 h1_1: drop if _n>1;
   drop p80a_1;
   *Also, look at the small number that failed to match;
    list p1_1 h1_1 nels_p80a if nels2zip==1;
    drop if nels2zip==1;
    drop nels2zip;
   tempfile nels2zip;
   sort p1_1 h1_1;
   keep p1_1 h1_1 zip;
   keep if zip<.;
   save `nels2zip';
  *Create zip code/MSA crosswalk for non-NE, from the zip code-by-county records;
   use `allzip';
   keep if sumlev==820;
   sort stfips cofips zip;
   drop if stfips==9 | stfips==23 | stfips==25 | stfips==33 | stfips==44 | stfips==50;
   merge stfips cofips using `co2msa', uniqusing _merge(zip2county);
   tab zip2county;
   replace fipsmsa=0 if zip2county==1;
   drop zip2county;
   sort zip fipsmsa;
   collapse (sum) p1_1, by(zip fipsmsa);
   egen totzippop=sum(p1_1), by(zip);
   gen zippopshare=p1_1/totzippop;
   replace zippopshare=0 if p1_1==0 & totzippop==0;
   drop totzippop;
   gsort zip -zippopshare;
   *Some zips have zero total share, if population is zero.  Distribute equally.;
    egen totshare=sum(zippopshare), by(zip);
    tab totshare;
    egen nummsas=count(zippopshare), by(zip);
    replace zippopshare=1/nummsas if totshare==0;
   *Drop any remaining zip-MSA combos with zero pop;
    gsort zip -zippopshare;
    by zip: drop if zippopshare==0 & _n>1;
   *Test--do we have 100% share for everyone?;
    drop totshare nummsas;
    egen totshare=sum(zippopshare), by(zip);
    tab totshare;
   duplicates report zip zippopshare;
   gsort zip -zippopshare;
   by zip: gen rank=_n;
   *Keep only the majority MSA for each zip;
    bysort rank: su zippopshare;
    keep if rank==1;
   keep zip fipsmsa zippopshare;
   rename zippopshare frofzip;
   label var frofzip "Fr. of zip population in this MSA";
   sort zip;
   tempfile zip2msa_nonne;
   save `zip2msa_nonne';
  *Create zip code/MSA crosswalk for NE, from an ArcMap merge of zip code areas with MSA areas;
   use ${mydata}/gis/zips2msas.dta;
   keep zip msa z_ma_area;
   gen zipnum=real(zip);
   drop if zipnum==.;
   drop zip;
   rename zipnum zip;
   gen fipsmsa=real(msa);
   replace fipsmsa=0 if fipsmsa==.;
   collapse (sum) z_ma_area, by(zip fipsmsa);
   egen totziparea=sum(z_ma_area), by(zip);
   gen mashare=z_ma_area/totziparea;
   gsort zip -mashare;
   by zip: gen rank=_n;
   egen nummsas=count(rank), by(zip);
   *Keep only the best match for each zip;
    bysort rank: su mashare;
    keep if rank==1;
   keep zip fipsmsa mashare;
   rename mashare frofzip;
   label var frofzip "Fr. of zip population in this MSA";
   sort zip;
   tempfile zip2msa_ne;
   save `zip2msa_ne';
  *Bring the two crosswalks together;
   append using `zip2msa_nonne';
   tempfile zip2msa;
   sort zip;
   replace fipsmsa=. if fipsmsa==0;
   save `zip2msa';
  *Merge NELS zip codes to the zip2msa crosswalk;
   use `nels2zip';
   sort zip;
   merge zip using `zip2msa', uniqusing _merge(nelszip2msa);
   tab nelszip2msa;
   drop if nelszip2msa==2;
   drop nelszip2msa;
  ***NOTE:  A FEW LINES HERE TO RECODE A SMALL NUMBER OF ZIPS THAT FAIL TO SHOW UP;
  ***THIS FILE IS NEEDED TO COMPUTE EXACT ESTIMATES IN THE PAPER, BUT IS NOT DISTRIBUTED;
  ***VIA THE WORLD-WIDE WEB.  CONTACT THE AUTHOR TO OBTAIN IT.
   *do confidential.include.ziprecode.do;
   sort h1_1 p1_1;
   tempfile nels2msa;
   save `nels2msa';
  *Merge back to NELS schools;
   use `skldata';
   rename byh1ztot h1_1;
   rename byp1ztot p1_1;
   sort h1_1 p1_1;
   merge h1_1 p1_1 using `nels2msa', uniqusing _merge(zipmrg_by);
   tab zipmrg_by;
   drop if zipmrg_by==2;
   rename h1_1 byh1ztot;
   rename p1_1 byp1ztot;
   rename fipsmsa byzip_fipsmsa;
   rename frofzip byzip_score;
   *Schools that fail to match;
    su byh1ztot byp1ztot if zipmrg_by==1;
   *Schools that do match;
    su byzip_score if zipmrg_by==3, detail;
   drop zipmrg_by;
   rename f1h1ztot h1_1;
   rename f1p1ztot p1_1;
   sort h1_1 p1_1;
   merge h1_1 p1_1 using `nels2msa', uniqusing _merge(zipmrg_f1);
   tab zipmrg_f1;
   drop if zipmrg_f1==2;
   rename h1_1 f1h1ztot;
   rename p1_1 f1p1ztot;
   rename fipsmsa f1zip_fipsmsa;
   rename frofzip f1zip_score;
   *Schools that fail to match;
    su f1h1ztot f1p1ztot if zipmrg_f1==1;
   *Schools that do match;
    su f1zip_score if zipmrg_f1==3, detail;
   drop zipmrg_f1;
   rename f2h1ztot h1_1;
   rename f2p1ztot p1_1;
   sort h1_1 p1_1;
   merge h1_1 p1_1 using `nels2msa', uniqusing _merge(zipmrg_f2);
   tab zipmrg_f2;
   drop if zipmrg_f2==2;
   rename h1_1 f2h1ztot;
   rename p1_1 f2p1ztot;
   rename fipsmsa f2zip_fipsmsa;
   rename frofzip f2zip_score;
   *Schools that fail to match;
    su f2h1ztot f2p1ztot if zipmrg_f2==1;
   *Schools that do match;
    su f2zip_score if zipmrg_f2==3, detail;
   drop zipmrg_f2;
   tempfile schoollist;
   save `schoollist';

*Section C:  Assign district and MSA codes to each individual;
 *We have six bits of information about each schools location:
 *In each of BY, F1, F2 surveys, we have an LEAID (public schools only) and a zip-code-based MSA;
 *Form seven location variables for each individual:
 * A) Hoxby algorithm;
 * B) Rothstein algorithm, separately for each wave, using only public schools;
 * C) Rothstein algorithm, separately for each wave, using zip code information;
 * Hoxbys intended algorithm is not entirely clear.  She matches students to schools three times,
 * using a school ID from each of the waves (though only one of these matches actually goes through).
 * She then has an algorithm to pick from among ID obtained from the BY, F1, and F2 information.  What
 * is unclear is whether the F1 information is meant to be from the F1 school, or the F1 information
 * from the BY school, when both are available.  I will use only information about the contemporaneous
 * school to obtain each waves district ID;

 *Make three school lists, with school ID, leaid (if available), and zip-MSA, one for each wave.;
 *Merge each list to the SDDB, to get leaid-fipsmsa crosswalk;
  tempfile bylist f1list f2list xwalk;
  use ${mywork_public}/distdata.dta;
  keep leaid fipsmsa;
  sort leaid;
  save `xwalk';
  use `schoollist';
  keep if sch_id~=.;
  keep sch_id sch_leaid_by byzip_fipsmsa;
  rename sch_leaid_by leaid;
  sort leaid;
  merge leaid using `xwalk', uniqusing _merge(by2sddb);
  tab by2sddb;
  drop if by2sddb==2;
  drop by2sddb;
  rename fipsmsa bylea_fipsmsa;
  rename leaid by_leaid;
  compare bylea_fipsmsa byzip_fipsmsa;
  sort sch_id;
  save `bylist';
  use `schoollist';
  keep if f1sch_id~=.;
  keep f1sch_id sch_leaid_f1 f1zip_fipsmsa;
  sort f1sch_id;
  rename sch_leaid_f1 leaid;
  sort leaid;
  merge leaid using `xwalk', uniqusing _merge(f12sddb);
  tab f12sddb;
  drop if f12sddb==2;
  drop f12sddb;
  rename fipsmsa f1lea_fipsmsa;
  rename leaid f1_leaid;
  compare f1lea_fipsmsa f1zip_fipsmsa;
  sort f1sch_id;
  save `f1list';
  use `schoollist';
  keep if f2sch_id~=.;
  keep f2sch_id sch_leaid_f2 f2zip_fipsmsa;
  sort f2sch_id;
  rename sch_leaid_f2 leaid;
  sort leaid;
  merge leaid using `xwalk', uniqusing _merge(f22sddb);
  tab f22sddb;
  drop if f22sddb==2;
  drop f22sddb;
  rename fipsmsa f2lea_fipsmsa;
  rename leaid f2_leaid;
  compare f2lea_fipsmsa f2zip_fipsmsa;
  sort f2sch_id;
  save `f2list';

 *Merge individual data to each of the three school lists;
  use `inddata';
  sort sch_id;
  merge sch_id using `bylist', uniqusing _merge(ind2skl_by);
  tab ind2skl_by;
  drop if ind2skl_by==2;
  drop ind2skl_by;
  sort f1sch_id;
  merge f1sch_id using `f1list', uniqusing _merge(ind2skl_f1);
  tab ind2skl_f1;
  drop if ind2skl_f1==2;
  drop ind2skl_f1;
  sort f2sch_id;
  merge f2sch_id using `f2list', uniqusing _merge(ind2skl_f2);
  tab ind2skl_f2;
  drop if ind2skl_f2==2;
  drop ind2skl_f2;

 *Now implement CH algorithm to choose a single district and MSA code for each individual;
  gen allmiss=1 if by_leaid==f1_leaid & by_leaid==f2_leaid & by_leaid==.;
  gen allsame=1 if by_leaid==f1_leaid & by_leaid==f2_leaid & by_leaid~=.;
  gen byf1_f2m=1 if by_leaid==f1_leaid & by_leaid~=. & f2_leaid==.;
  gen byf2_f1m=1 if by_leaid==f2_leaid & by_leaid~=. & f1_leaid==.;
  gen f1f2_bym=1 if f1_leaid==f2_leaid & f1_leaid~=. & by_leaid==.;
  gen by_f1f2m=1 if by_leaid~=. & f1_leaid==. & f2_leaid==.;
  gen f1_byf2m=1 if f1_leaid~=. & by_leaid==. & f2_leaid==.;
  gen f2_byf1m=1 if f2_leaid~=. & by_leaid==. & f1_leaid==.;
  gen byf1_f2d=1  if by_leaid==f1_leaid & by_leaid~=. & by_leaid~=f2_leaid & f2_leaid~=.;
  gen byf2_f1d=1  if by_leaid==f2_leaid & by_leaid~=. & by_leaid~=f1_leaid & f1_leaid~=.;
  gen f1f2_byd=1  if f1_leaid==f2_leaid & f1_leaid~=. & f1_leaid~=by_leaid & by_leaid~=.;
  *Note:  CH alldiff code had to be altered, as it picked up some byf2_f1d obs;
   *old code: gen alldiff=1  if by_leaid~=f1_leaid & by_leaid~=f2_leaid~=. & f1_leaid~=f2_leaid &
   *                                                          error--->___<--error
   *                            by_leaid~=. & f1_leaid~=. & f2_leaid~=.;
   gen alldiff=1  if by_leaid~=f1_leaid & by_leaid~=f2_leaid & f1_leaid~=f2_leaid &
                     by_leaid~=. & f1_leaid~=. & f2_leaid~=.;
  *Hoxby left out a few categories;
   gen byf1d_f2m=1 if by_leaid~=. & f1_leaid~=. & by_leaid~=f1_leaid & f2_leaid==.;
   gen byf2d_f1m=1 if by_leaid~=. & f2_leaid~=. & by_leaid~=f2_leaid & f1_leaid==.;
   gen f1f2d_bym=1 if f1_leaid~=. & f2_leaid~=. & f1_leaid~=f2_leaid & by_leaid==.;
  *Note: Hoxby is wrong about alldiff;
  su allmiss allsame byf1_f2m byf2_f1m f1f2_bym by_f1f2m f1_byf2m f2_byf1m byf1_f2d byf2_f1d
     f1f2_byd alldiff byf1d_f2m byf2d_f1m f1f2d_bym;
  egen chcategories=rsum(allmiss allsame byf1_f2m byf2_f1m f1f2_bym by_f1f2m f1_byf2m f2_byf1m
                         byf1_f2d byf2_f1d f1f2_byd alldiff );
  egen allcategories=rsum(allmiss allsame byf1_f2m byf2_f1m f1f2_bym by_f1f2m f1_byf2m f2_byf1m
                         byf1_f2d byf2_f1d f1f2_byd alldiff byf1d_f2m byf2d_f1m f1f2d_bym);
  tab chcategories allcategories, missing;
  *Assignment rules:  Majority rule, or if 1 is nonmissing use it;
   label define assigncat
     1 "by f1 f2 same & not missing"
     2 "by f1 same, f2 missing"
     3 "by f2 same, f1 missing"
     4 "f1 f2 same, by missing"
     5 "by used, f1 f2 missing"
     6 "f1 used, by f2 missing"
     7 "f2 used, by f1 missing"
     8 "by=f1 used, f2 different"
     9 "by=f2 used, f1 different"
     10 "f1=f2 used, by diff (typical nonunion dist)"
     11 "by used, f1 and f2: one diff, one missing"
     12 "f1 used, by missing, f2 different"
     13 "by used, f1 and f2 both diff"
     14 "all missing, schoolmates' by used"
     15 "all missing, schoolmates' modal f1 used"
     16 "all missing, schoolmates' modal f2 used";
   label define assignwave 0 "Use BY LEA/MSA" 1 "Use F1 LEA/MSA" 2 "Use F2 LEA/MSA"
                            3 "Use BY classmates LEA/MSA" 4 "Use F1 classmates LEA/MSA"
                            5 "Use F2 classmates LEA/MSA";
   gen ch_assignwave=0 if allsame==1 | byf1_f2m==1 | byf2_f1m==1 | by_f1f2m==1 |
                          byf1_f2d==1 | byf2_f1d==1;
   replace ch_assignwave=1 if f1f2_bym==1 | f1_byf2m==1 | f1f2_byd==1;
   replace ch_assignwave=2 if f2_byf1m==1;
   gen ch_assigncat=1 if allsame==1;
   replace ch_assigncat=2 if byf1_f2m==1;
   replace ch_assigncat=3 if byf2_f1m==1;
   replace ch_assigncat=4 if f1f2_bym==1;
   replace ch_assigncat=5 if by_f1f2m==1;
   replace ch_assigncat=6 if f1_byf2m==1;
   replace ch_assigncat=7 if f2_byf1m==1;
   replace ch_assigncat=8 if byf1_f2d==1;
   replace ch_assigncat=9 if byf2_f1d==1;
   replace ch_assigncat=10 if f1f2_byd==1;
   label var ch_assigncat "CH: method by which byleaid f1leaid & f2leaid were used to assign leaid";
   label var ch_assignwave "Wave of data used to assign LEA id";
   label values ch_assigncat assigncat;
   label values ch_assignwave assignwave;

   *Those that are unassigned are those with all three different or missing, or with two different and the third missing.;
   *Hoxby uses the min of all students with the same sch_id in BY if that is not missing, then the;
   *mode of all students with the same F1 sch_id if it is non-missing, then the mode of students with the same;
   *F2 sch_id.  She seems to assign even if one of these is missing.  I wont.  Also, she claims no differences;
   *between bymin and bymax.  To be safe, I will use the mode here also.;
   *What this procedure amounts to is:  If someone who is unassigned ever went to a school with someone who
   *ever went to an assignable school, use that assignment.
   *In CH program, this "solves" the problem that only the merge on the BY sch_id ever really happened:
   *those with missing sch_ids are given codes from their f1sch_id or f2sch_id classmates who have valid codes.
   *This would be very rare (the sample freshenings would be unlikely to grab someone at the same school as an
   *original sample member), but because missing sch_ids are used as well, we get students who have missing
   *BY sch_ids randomly assigned to NCES schools with missing BY sch_ids.  Some of these students will end up
   *assignable to districts via the schools later-wave information, and then the modal district will be given
   *to all unassignable students.;
    su allmiss allsame byf1_f2m byf2_f1m f1f2_bym by_f1f2m f1_byf2m f2_byf1m byf1_f2d byf2_f1d
       f1f2_byd alldiff byf1d_f2m byf2d_f1m f1f2d_bym if ch_assignwave==.;
    *Before moving to the analysis of modes, though, assign to earliest wave if any wave is available;
    *This is seemingly implied by CH claim that "Learning is cumulative.  Therefore, for geographic matching,
    * we should give priority to base year codes and first-follow-up when codes are otherwise equal.";
     replace ch_assigncat=11 if byf1d_f2m==1 | byf2d_f1m==1;
     replace ch_assigncat=12 if f1f2d_bym==1;
     replace ch_assigncat=13 if alldiff==1;
     replace ch_assignwave=0 if ch_assigncat==11 | ch_assigncat==13;
     replace ch_assignwave=1 if ch_assigncat==12;
     tab allmiss if ch_assignwave==., missing;
    *Now assign district and MSA codes where possible thus far;
     gen ch_leaid=by_leaid if ch_assignwave==0;
     replace ch_leaid=f1_leaid if ch_assignwave==1;
     replace ch_leaid=f2_leaid if ch_assignwave==2;
     gen ch_fipsmsa=bylea_fipsmsa if ch_assignwave==0;
     replace ch_fipsmsa=f1lea_fipsmsa if ch_assignwave==1;
     replace ch_fipsmsa=f2lea_fipsmsa if ch_assignwave==2;
    *Now get the min, max, and mode for those who are not yet assigned;
     foreach t in min max mode {;
      egen ch_by`t'=`t'(ch_leaid) if sch_id~=., by(sch_id);
      egen ch_f1`t'=`t'(ch_leaid) if f1sch_id~=., by(f1sch_id);
      egen ch_f2`t'=`t'(ch_leaid) if f2sch_id~=., by(f2sch_id);
      };
     gen ch_bydiff=(ch_bymax~=ch_bymin) if ch_bymax~=. & ch_bymin~=.;
     gen ch_byhavemode=(ch_bymode~=.);
     gen ch_f1diff=(ch_f1max~=ch_f1min) if ch_f1max~=. & ch_f1min~=.;
     gen ch_f1havemode=(ch_f1mode~=.);
     gen ch_f2diff=(ch_f2max~=ch_f2min) if ch_f2max~=. & ch_f2min~=.;
     gen ch_f2havemode=(ch_f2mode~=.);
    *Assign based on the modes if they are available;
     replace ch_assignwave=3 if ch_assignwave==. & ch_bymode~=.;
     replace ch_assignwave=4 if ch_assignwave==. & ch_f1mode~=.;
     replace ch_assignwave=5 if ch_assignwave==. & ch_f2mode~=.;
     replace ch_assigncat=14 if ch_assignwave==3;
     replace ch_assigncat=15 if ch_assignwave==4;
     replace ch_assigncat=16 if ch_assignwave==5;
    *Note:  Hoxby is wrong that bymin==bymax, but we will use the mode anyway;
     tab ch_bydiff ch_byhavemode if ch_assignwave==3, missing;
     tab ch_f1diff ch_f1havemode if ch_assignwave==4, missing;
     tab ch_f2diff ch_f2havemode if ch_assignwave==5, missing;
    *Check distribution;
     tab ch_assigncat ch_assignwave, missing;
    *All of those who are still unassigned are in the "allmiss" category;
     tab allmiss if ch_assigncat==., missing;
    *What is going on with the remaining?  Roughly half are in private school for all waves;
     su prvschby prvschf1 prvschf2 prvschall pubschby pubschf1 pubschf2 pubschall if ch_assigncat==.;
    *Assign district and MSA codes to those where the modes are determinative;
     replace ch_leaid=ch_bymode if ch_assignwave==3;
     replace ch_leaid=ch_f1mode if ch_assignwave==4;
     replace ch_leaid=ch_f2mode if ch_assignwave==5;
     egen modemsa=mode(ch_fipsmsa), by(ch_leaid);
     replace ch_fipsmsa=modemsa if ch_assignwave==3 | ch_assignwave==4 | ch_assignwave==5;
    drop ch_??min ch_??max ch_??mode ch_??havemode ch_??diff modemsa
         allmiss-allcategories;

 *Finally, compute LEA/MSA codes for two JR assignment rules, in each of three waves;
  *Public school students only, using LEA information;
   gen jrAby_leaid  =by_leaid      if pubschby==1;
   gen jrAby_fipsmsa=bylea_fipsmsa if pubschby==1;
   gen jrAf1_leaid  =f1_leaid      if pubschf1==1;
   gen jrAf1_fipsmsa=f1lea_fipsmsa if pubschf1==1;
   gen jrAf2_leaid  =f2_leaid      if pubschf2==1;
   gen jrAf2_fipsmsa=f2lea_fipsmsa if pubschf2==1;
  *Public plus private, using zip information;
   gen jrBby_fipsmsa=byzip_fipsmsa;
   gen jrBf1_fipsmsa=f1zip_fipsmsa;
   gen jrBf2_fipsmsa=f2zip_fipsmsa;
  drop by_leaid f1_leaid f2_leaid bylea_fipsmsa f1lea_fipsmsa f2lea_fipsmsa
       byzip_fipsmsa f1zip_fipsmsa f2zip_fipsmsa;
  label var ch_leaid "District code, all waves, CH algorithm";
  label var ch_fipsmsa "MSA code, all waves, CH algorithm";
  label var jrAby_leaid "District code in BY, JR alg., pub sch. in BY only";
  label var jrAf1_leaid "District code in f1, JR alg., pub sch. in f1 only";
  label var jrAf2_leaid "District code in f2, JR alg., pub sch. in f2 only";
  label var jrAby_fipsmsa "MSA code in BY, JR alg., pub sch. in BY only";
  label var jrAf1_fipsmsa "MSA code in f1, JR alg., pub sch. in f1 only";
  label var jrAf2_fipsmsa "MSA code in f2, JR alg., pub sch. in f2 only";
  label var jrBby_fipsmsa "MSA code in BY, JR alg., from schl zip";
  label var jrBf1_fipsmsa "MSA code in f1, JR alg., from schl zip";
  label var jrBf2_fipsmsa "MSA code in f2, JR alg., from schl zip";

 *Check alignment;
  compare jrAby_fipsmsa jrBby_fipsmsa;
  compare jrAf1_fipsmsa jrBf1_fipsmsa;
  compare jrAf2_fipsmsa jrBf2_fipsmsa;
  compare jrAby_fipsmsa ch_fipsmsa;
  compare jrAby_leaid ch_leaid;
 save ${mywork_confidential}/nelsdata.dta, replace;

*Section D:  Make files of merged individual-district-MSA data for each merge type;
 use ${mywork_public}/distdata.dta;
 sort leaid;
 save, replace;
 use ${mywork_public}/msadata.dta;
 sort fipsmsa;
 save, replace;

 foreach v in ch jrAby jrAf1 jrAf2 {;
  use ${mywork_confidential}/nelsdata.dta;
  keep if `v'_fipsmsa~=.;
  rename `v'_leaid leaid;
  sort leaid;
  merge leaid using ${mywork_public}/distdata, uniqusing _merge(nels2sddb_`v');
  tab nels2sddb_`v';
  drop if nels2sddb_`v'==2;
  drop nels2sddb_`v' fipsmsa;
  rename `v'_fipsmsa fipsmsa;
  sort fipsmsa;
  merge fipsmsa using ${mywork_public}/msadata, uniqusing _merge(nels2msa_`v');
  tab nels2msa_`v';
  drop if nels2msa_`v'==2;
  drop nels2msa_`v';
  sort id;
  save ${mywork_confidential}/`v'sample.dta, replace;
  };
 foreach v in jrBby jrBf1 jrBf2 {;
  use ${mywork_confidential}/nelsdata.dta;
  keep if `v'_fipsmsa~=.;
  rename `v'_fipsmsa fipsmsa;
  sort fipsmsa;
  merge fipsmsa using ${mywork_public}/msadata, uniqusing _merge(nels2msa_`v');
  tab nels2msa_`v';
  drop if nels2msa_`v'==2;
  drop nels2msa_`v';
  sort id;
  save ${mywork_confidential}/`v'sample.dta, replace;
  };

log close;
